'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var vue = require('vue');
var vue$1 = require('@headlessui/vue');
var vue3Dropzone = require('vue3-dropzone');
var axios = require('axios');
var Popper = require('vue3-popper');
var inertiaVue3 = require('@inertiajs/inertia-vue3');
var vCalendar = require('v-calendar');
require('v-calendar/dist/style.css');
var macrameVue3 = require('@macramejs/macrame-vue3');
var Draggable = require('vuedraggable');
var vue3 = require('@tiptap/vue-3');
var StarterKit = require('@tiptap/starter-kit');
var Bold = require('@tiptap/extension-bold');
var Italic = require('@tiptap/extension-italic');
var Link = require('@tiptap/extension-link');
var Underline = require('@tiptap/extension-underline');
var Code = require('@tiptap/extension-code');
var Table = require('@tiptap/extension-table');
var TableRow = require('@tiptap/extension-table-row');
var TableCell = require('@tiptap/extension-table-cell');
var TableHeader = require('@tiptap/extension-table-header');
var adminVue3 = require('@macramejs/admin-vue3');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e["default"] : e; }

var axios__default = /*#__PURE__*/_interopDefaultLegacy(axios);
var Popper__default = /*#__PURE__*/_interopDefaultLegacy(Popper);
var Draggable__default = /*#__PURE__*/_interopDefaultLegacy(Draggable);
var StarterKit__default = /*#__PURE__*/_interopDefaultLegacy(StarterKit);
var Bold__default = /*#__PURE__*/_interopDefaultLegacy(Bold);
var Italic__default = /*#__PURE__*/_interopDefaultLegacy(Italic);
var Link__default = /*#__PURE__*/_interopDefaultLegacy(Link);
var Underline__default = /*#__PURE__*/_interopDefaultLegacy(Underline);
var Code__default = /*#__PURE__*/_interopDefaultLegacy(Code);
var Table__default = /*#__PURE__*/_interopDefaultLegacy(Table);
var TableRow__default = /*#__PURE__*/_interopDefaultLegacy(TableRow);
var TableCell__default = /*#__PURE__*/_interopDefaultLegacy(TableCell);
var TableHeader__default = /*#__PURE__*/_interopDefaultLegacy(TableHeader);

function getVariant(props, { DEFAULT = 'primary' }) {
    return vue.computed(() => {
        if (props.variant) {
            return props.variant;
        }

        if (props.primary) {
            return 'primary';
        }
        if (props.secondary) {
            return 'secondary';
        }
        if (props.round) {
            return 'round';
        }
        if (props.blue) {
            return 'blue';
        }
        if (props.gray) {
            return 'gray';
        }
        if (props.green) {
            return 'green';
        }
        if (props.success) {
            return 'success';
        }
        if (props.yellow) {
            return 'yellow';
        }
        if (props.warning) {
            return 'warning';
        }
        if (props.red) {
            return 'red';
        }
        if (props.danger) {
            return 'danger';
        }
        if (props.purple) {
            return 'purple';
        }
        if (props.orange) {
            return 'orange';
        }
        if (props.darkorange) {
            return 'darkorange';
        }
        if (props.lightorange) {
            return 'lightorange';
        }
        if (props.grasgreen) {
            return 'grasgreen';
        }
        if (props.turkise) {
            return 'turkise';
        }
        if (props.lightblue) {
            return 'lightblue';
        }
        if (props.pink) {
            return 'pink';
        }
        if (props.white) {
            return 'white';
        }
        if (props.black) {
            return 'black';
        }

        return DEFAULT;
    });
}

const variants = {
    variant: {
        type: String,
        default: null,
    },
    blue: {
        type: Boolean,
        default: false,
    },
    primary: {
        type: Boolean,
        default: false,
    },
    secondary: {
        type: Boolean,
        default: false,
    },
    gray: {
        type: Boolean,
        default: false,
    },
    green: {
        type: Boolean,
        default: false,
    },
    success: {
        type: Boolean,
        default: false,
    },
    yellow: {
        type: Boolean,
        default: false,
    },
    warning: {
        type: Boolean,
        default: false,
    },
    red: {
        type: Boolean,
        default: false,
    },
    danger: {
        type: Boolean,
        default: false,
    },
    orange: {
        type: Boolean,
        default: false,
    },
    purple: {
        type: Boolean,
        default: false,
    },
    darkorange: {
        type: Boolean,
        default: false,
    },
    lightorange: {
        type: Boolean,
        default: false,
    },
    grasgreen: {
        type: Boolean,
        default: false,
    },
    turkise: {
        type: Boolean,
        default: false,
    },
    lightblue: {
        type: Boolean,
        default: false,
    },
    pink: {
        type: Boolean,
        default: false,
    },
    white: {
        type: Boolean,
        default: false,
    },
    black: {
        type: Boolean,
        default: false,
    },
};

function getSize(props, { DEFAULT = 'md', only = ['sm', 'md', 'lg'] }) {
    return vue.computed(() => {
        if (props.size) {
            return props.size;
        }

        if (props.sm && only.includes('sm')) {
            return 'sm';
        }
        if (props.md && only.includes('md')) {
            return 'md';
        }
        if (props.lg && only.includes('lg')) {
            return 'lg';
        }

        return DEFAULT;
    });
}

const sizes = {
    size: {
        type: String,
        default: null,
    },
    sm: {
        type: Boolean,
        default: false,
    },
    md: {
        type: Boolean,
        default: false,
    },
    lg: {
        type: Boolean,
        default: false,
    },
};

var script$1k = vue.defineComponent({
    props: {
        disabled: {
            default: false,
            type: Boolean,
        },
        text: {
            default: false,
            type: Boolean,
        },
        square: {
            default: false,
            type: Boolean,
        },
        round: {
            default: false,
            type: Boolean,
        },
        outline: {
            default: false,
            type: Boolean,
        },
        ...variants,
        ...sizes,
    },
    setup(props, { attrs }) {
        const tag = 'href' in attrs ? 'a' : 'button';
        const variant_ = getVariant(props, {});
        const size_ = getSize(props, {});
        return { tag, variant_, size_ };
    },
});

function render$K(_ctx, _cache, $props, $setup, $data, $options) {
  return (vue.openBlock(), vue.createBlock(vue.resolveDynamicComponent(_ctx.tag), vue.mergeProps({
    class: ["relative inline-flex items-center justify-center text-sm uppercase transition-all duration-300 focus:ring focus:outline-none", {
            'focus:ring-transparent': _ctx.disabled,

            'w-[37px]': _ctx.square && _ctx.size_ == 'md',
            'w-[30px]': _ctx.square && _ctx.size_ == 'sm',

            'h-[37px] rounded': _ctx.size_ == 'md' && !_ctx.text && !_ctx.round,
            'h-[30px] rounded': _ctx.size_ == 'sm' && !_ctx.text && !_ctx.round,

            'px-5': _ctx.size_ == 'md' && !_ctx.square && !_ctx.text && !_ctx.round,
            'px-4': _ctx.size_ == 'sm' && !_ctx.square && !_ctx.text && !_ctx.round,

            'bg-gradient-to-r from-gradient-red-500 to-gradient-orange-500 hover:from-gradient-red-300 hover:to:gradient-orange-300 hover:scale-95 active:from-gradient-red-700 active:to-gradient-orange-700 text-white focus:ring-orange-100 shadow-orange shadow-primary':
                _ctx.variant_ == 'primary' && !_ctx.disabled,
            'bg-gray text-white cursor-not-allowed':
                _ctx.variant_ == 'primary' && _ctx.disabled,

            'bg-gradient-to-r w-[37px] h-[37px] rounded-full from-indigo-900 to-indigo-900 hover:from-gradient-red-500 hover:to-gradient-orange-500 hover:scale-95 active:from-indigo-500 active:to-indigo-500 text-white focus:ring-orange-100':
                _ctx.round && !_ctx.disabled,
            'bg-gray text-white rounded-full cursor-not-allowed':
                _ctx.round && _ctx.disabled,

            'bg-orange-500 bg-opacity-0 border border-indigo-900 hover:bg-opacity-20 hover:scale-95 active:bg-opacity-50 text-black focus:ring-orange-100':
                _ctx.variant_ == 'secondary' && !_ctx.disabled,
            'opacity-40 border border-indigo-900 cursor-not-allowed':
                _ctx.variant_ == 'secondary' && _ctx.disabled,

            'bg-gray-200 hover:bg-gray-500 h-[30px] active:bg-indigo-900 active:text-white text-black focus:ring-gray-300':
                _ctx.size_ == 'sm' && !_ctx.disabled,
            'opacity-40 cursor-not-allowed': _ctx.size_ == 'sm' && _ctx.disabled,

            'focus:rounded hover:border-indigo-500 h-[20px] py-3 px-2.5 after:absolute after:left-1/2 after:bottom-[3px] after:h-px after:w-[calc(100%-20px)] after:-translate-x-1/2 hover:after:bg-indigo-500 active:after:bg-indigo-500 text-black focus:ring-transparent focus:bg-orange-100':
                _ctx.text && !_ctx.disabled,
            'opacity-40 py-2 px-3 cursor-not-allowed': _ctx.text && _ctx.disabled,
        }],
    disabled: _ctx.disabled
  }, _ctx.$attrs), {
    default: vue.withCtx(() => [
      vue.renderSlot(_ctx.$slots, "default")
    ]),
    _: 3 /* FORWARDED */
  }, 16 /* FULL_PROPS */, ["class", "disabled"]))
}

script$1k.render = render$K;
script$1k.__file = "packages/admin-vue3/src/ui/Button.vue";

const _hoisted_1$14 = { class: "flex items-center justify-between w-full" };

function render$J(_ctx, _cache) {
  return (vue.openBlock(), vue.createElementBlock("div", _hoisted_1$14, [
    vue.renderSlot(_ctx.$slots, "default")
  ]))
}

const script$1j = {};


script$1j.render = render$J;
script$1j.__file = "packages/admin-vue3/src/ui/Header.vue";

var script$1i = /*#__PURE__*/ vue.defineComponent({
    props: {
        disabled: {
            default: false,
            type: Boolean,
        },
        outline: {
            default: false,
            type: Boolean,
        },
        ...variants,
        ...sizes,
    },
    setup(__props) {
        const props = __props;
        const attrs = vue.useAttrs();
        const tag = 'href' in attrs ? 'a' : 'button';
        const variant_ = getVariant(props, {});
        const size_ = getSize(props, {});
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createBlock(vue.resolveDynamicComponent(vue.unref(tag)), vue.mergeProps({
                class: ["relative inline-flex items-center justify-center text-sm uppercase transition-all duration-300 rounded-full focus:ring focus:outline-none", {
                        'h-[37px] w-[37px] ': vue.unref(size_) == 'md',
                        'h-[30px] w-[30px] ': vue.unref(size_) == 'sm',
                        'bg-gray text-white cursor-not-allowed': __props.disabled,
                        'bg-gradient-to-r from-gradient-red-500 to-gradient-orange-500 hover:from-gradient-red-300 hover:to:gradient-orange-300 hover:scale-95 active:from-gradient-red-700 active:to-gradient-orange-700 text-white focus:ring-orange-100 shadow-orange shadow-primary': vue.unref(variant_) == 'primary' && !__props.disabled,
                        'bg-white hover:from-gradient-red-300 hover:to:gradient-orange-300 hover:scale-95 active:from-gradient-red-700 active:to-gradient-orange-700 text-gray-900 focus:ring-orange-100 ': vue.unref(variant_) == 'white' && !__props.disabled,
                        'bg-black hover:from-gradient-red-300 hover:to:gradient-orange-300 hover:scale-95 active:from-gradient-red-700 active:to-gradient-orange-700 text-white focus:ring-orange-100 ': vue.unref(variant_) == 'black' && !__props.disabled,
                    }],
                disabled: __props.disabled
            }, _ctx.$attrs), {
                default: vue.withCtx(() => [
                    vue.renderSlot(_ctx.$slots, "default")
                ]),
                _: 3 /* FORWARDED */
            }, 16 /* FULL_PROPS */, ["class", "disabled"]));
        };
    }
});

script$1i.__file = "packages/admin-vue3/src/ui/ButtonRound.vue";

var script$1h = vue.defineComponent({
    props: {
        as: {
            type: String,
            default: 'div',
        },
        variant: variants.variant,
        white: {
            type: Boolean,
            default: false,
        },
        gray: variants.gray,
        size: sizes.size,
        sm: sizes.sm,
        md: sizes.md,
    },
    setup(props, { attrs }) {
        let variant_ = getVariant(props, { DEFAULT: 'white' });
        let size_ = getSize(props, { only: ['sm', 'md'] });
        return { variant_, size_ };
    },
});

function render$I(_ctx, _cache, $props, $setup, $data, $options) {
  return (vue.openBlock(), vue.createBlock(vue.resolveDynamicComponent(_ctx.as), {
    class: vue.normalizeClass(["p-6 rounded-sm", {
            'bg-white': _ctx.variant_ == 'white',
            'bg-gray-300': _ctx.variant_ == 'gray',
            'p-12': _ctx.size_ == 'md',
            'p-8': _ctx.size_ == 'sm',
        }])
  }, {
    default: vue.withCtx(() => [
      vue.renderSlot(_ctx.$slots, "default")
    ]),
    _: 3 /* FORWARDED */
  }, 8 /* PROPS */, ["class"]))
}

script$1h.render = render$I;
script$1h.__file = "packages/admin-vue3/src/ui/Card.vue";

var script$1g = {
    components: { Switch: vue$1.Switch, SwitchGroup: vue$1.SwitchGroup, SwitchLabel: vue$1.SwitchLabel },
    props: {
        label: {
            type: String,
            default: null,
        },
        disabled: {
            type: Boolean,
            default: false,
        },
        modelValue: {
            type: Boolean,
            default: false,
        },
        ...sizes,
        ...variants,
    },
    setup({ disabled, ...props }, { emit }) {
        const size_ = getSize(props, {});
        const variant_ = getVariant(props, {});
        const update = (value) => {
            if (disabled) {
                return;
            }
            emit('update:modelValue', value);
        };
        return { update, size_, variant_ };
    },
};

const _hoisted_1$13 = { class: "inline-flex flex-col" };

function render$H(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_SwitchLabel = vue.resolveComponent("SwitchLabel");
  const _component_Switch = vue.resolveComponent("Switch");
  const _component_SwitchGroup = vue.resolveComponent("SwitchGroup");

  return (vue.openBlock(), vue.createBlock(_component_SwitchGroup, null, {
    default: vue.withCtx(() => [
      vue.createElementVNode("div", _hoisted_1$13, [
        vue.createVNode(_component_SwitchLabel, { class: "mr-4" }, {
          default: vue.withCtx(() => [
            vue.renderSlot(_ctx.$slots, "default", {}, () => [
              vue.createTextVNode(vue.toDisplayString($props.label), 1 /* TEXT */)
            ])
          ]),
          _: 3 /* FORWARDED */
        }),
        vue.createVNode(_component_Switch, {
          modelValue: $props.modelValue,
          "onUpdate:modelValue": $setup.update,
          class: vue.normalizeClass([{
                    'bg-gray-500': !$props.modelValue,
                    'bg-green':
                        ($setup.variant_ == null && $props.modelValue) ||
                        ($setup.variant_ == 'primary' && $props.modelValue),

                    'text-lg': $setup.size_ == 'lg',
                    'text-base': $setup.size_ == 'md' || $setup.size_ == null,
                    'text-xs': $setup.size_ == 'sm',

                    'w-16': $setup.size_ == 'lg',
                    'w-[35px]': $setup.size_ == 'md' || $setup.size_ == null,
                    'w-8': $setup.size_ == 'sm',

                    'h-8 rounded-lg': $setup.size_ == 'lg',
                    'h-5 rounded-md': $setup.size_ == 'md' || $setup.size_ == null,
                    'h-4 rounded-sm': $setup.size_ == 'sm',
                }, "relative inline-flex items-center transition-all rounded-full focus:outline-none focus:ring-4 focus:ring-orange-100"])
        }, {
          default: vue.withCtx(() => [
            vue.createElementVNode("span", {
              class: vue.normalizeClass([{
                        'w-[26px] h-[26px]': $setup.size_ == 'lg',
                        'w-3.5 h-3.5': $setup.size_ == 'md',
                        'w-2.5 h-2.5': $setup.size_ == 'sm',

                        'translate-x-[34px]': $setup.size_ == 'lg' && $props.modelValue,
                        'translate-x-[4px]':
                            ($setup.size_ == 'md' && !$props.modelValue) ||
                            (!$props.modelValue),
                        'translate-x-[17px]': $setup.size_ == 'md' && $props.modelValue,
                        'translate-x-1': $setup.size_ == 'sm' && !$props.modelValue,
                        'translate-x-[18px]': $setup.size_ == 'sm' && $props.modelValue,
                    }, "inline-block transition-all transform bg-white rounded-full"])
            }, null, 2 /* CLASS */)
          ]),
          _: 1 /* STABLE */
        }, 8 /* PROPS */, ["modelValue", "onUpdate:modelValue", "class"])
      ])
    ]),
    _: 3 /* FORWARDED */
  }))
}

script$1g.render = render$H;
script$1g.__file = "packages/admin-vue3/src/ui/Toggle.vue";

var script$1f = {
    components: { Switch: vue$1.Switch, SwitchGroup: vue$1.SwitchGroup, SwitchLabel: vue$1.SwitchLabel },
    props: {
        label: {
            type: String,
            default: null,
        },
        disabled: {
            type: Boolean,
            default: false,
        },
        modelValue: {
            type: Boolean,
            default: false,
        },
    },
    setup({ disabled }, { emit }) {
        const update = value => {
            if (disabled) {
                return;
            }
            emit('update:modelValue', value);
        };
        return { update };
    },
};

const _hoisted_1$12 = ["disabled"];
const _hoisted_2$U = { class: "inline-block" };

function render$G(_ctx, _cache, $props, $setup, $data, $options) {
  return (vue.openBlock(), vue.createElementBlock("button", {
    onClick: _cache[0] || (_cache[0] = $event => ($setup.update(!$props.modelValue))),
    class: vue.normalizeClass(["h-[30px] px-3 py-2 flex items-center gap-2 transition-colors focus:outline-none duration-200 rounded-full leading-none text-sm", {
            'bg-gray-200 hover:bg-gray-300 text-gray-900 focus:bg-gray-300 active:bg-orange-100':
                !$props.modelValue && !$props.disabled,
            'bg-orange-100 text-orange-700': $props.modelValue && !$props.disabled,
            'bg-gray-100 text-gray-500 cursor-not-allowed': $props.disabled,
        }]),
    disabled: $props.disabled
  }, [
    vue.createElementVNode("span", _hoisted_2$U, vue.toDisplayString($props.label), 1 /* TEXT */)
  ], 10 /* CLASS, PROPS */, _hoisted_1$12))
}

script$1f.render = render$G;
script$1f.__file = "packages/admin-vue3/src/ui/Chip.vue";

const _hoisted_1$11 = {
  viewBox: "0 0 18 9",
  xmlns: "http://www.w3.org/2000/svg",
  "xml:space": "preserve"
};
const _hoisted_2$T = /*#__PURE__*/vue.createElementVNode("path", { d: "M18 7.597a1 1 0 0 0-1-1H1a1 1 0 0 0 0 2h16a1 1 0 0 0 1-1ZM18 1a1 1 0 0 0-1-1H1a1 1 0 0 0 0 2h16a1 1 0 0 0 1-1Z" }, null, -1 /* HOISTED */);
const _hoisted_3$G = [
  _hoisted_2$T
];

function render$F(_ctx, _cache) {
  return (vue.openBlock(), vue.createElementBlock("svg", _hoisted_1$11, _hoisted_3$G))
}

const script$1e = {};


script$1e.render = render$F;
script$1e.__file = "packages/admin-vue3/src/icons/IconDraggable.vue";

const _hoisted_1$10 = {
  width: "24",
  height: "24",
  viewBox: "0 0 24 24",
  "stroke-width": "1.5",
  fill: "none",
  xmlns: "http://www.w3.org/2000/svg"
};
const _hoisted_2$S = /*#__PURE__*/vue.createElementVNode("path", {
  d: "M19 11v9.4a.6.6 0 0 1-.6.6H5.6a.6.6 0 0 1-.6-.6V11M10 17v-6M14 17v-6M21 7h-5M3 7h5m0 0V3.6a.6.6 0 0 1 .6-.6h6.8a.6.6 0 0 1 .6.6V7M8 7h8",
  stroke: "currentColor",
  "stroke-linecap": "round",
  "stroke-linejoin": "round"
}, null, -1 /* HOISTED */);
const _hoisted_3$F = [
  _hoisted_2$S
];

function render$E(_ctx, _cache) {
  return (vue.openBlock(), vue.createElementBlock("svg", _hoisted_1$10, _hoisted_3$F))
}

const script$1d = {};


script$1d.render = render$E;
script$1d.__file = "packages/admin-vue3/src/icons/IconTrash.vue";

const _hoisted_1$$ = {
  width: "24",
  height: "24",
  "stroke-width": "1.5",
  viewBox: "0 0 24 24",
  fill: "none",
  xmlns: "http://www.w3.org/2000/svg"
};
const _hoisted_2$R = /*#__PURE__*/vue.createElementVNode("path", {
  d: "M18 12.5C18.2761 12.5 18.5 12.2761 18.5 12C18.5 11.7239 18.2761 11.5 18 11.5C17.7239 11.5 17.5 11.7239 17.5 12C17.5 12.2761 17.7239 12.5 18 12.5Z",
  fill: "currentColor",
  stroke: "currentColor",
  "stroke-linecap": "round",
  "stroke-linejoin": "round"
}, null, -1 /* HOISTED */);
const _hoisted_3$E = /*#__PURE__*/vue.createElementVNode("path", {
  d: "M12 12.5C12.2761 12.5 12.5 12.2761 12.5 12C12.5 11.7239 12.2761 11.5 12 11.5C11.7239 11.5 11.5 11.7239 11.5 12C11.5 12.2761 11.7239 12.5 12 12.5Z",
  fill: "currentColor",
  stroke: "currentColor",
  "stroke-linecap": "round",
  "stroke-linejoin": "round"
}, null, -1 /* HOISTED */);
const _hoisted_4$u = /*#__PURE__*/vue.createElementVNode("path", {
  d: "M6 12.5C6.27614 12.5 6.5 12.2761 6.5 12C6.5 11.7239 6.27614 11.5 6 11.5C5.72386 11.5 5.5 11.7239 5.5 12C5.5 12.2761 5.72386 12.5 6 12.5Z",
  fill: "currentColor",
  stroke: "currentColor",
  "stroke-linecap": "round",
  "stroke-linejoin": "round"
}, null, -1 /* HOISTED */);
const _hoisted_5$j = [
  _hoisted_2$R,
  _hoisted_3$E,
  _hoisted_4$u
];

function render$D(_ctx, _cache) {
  return (vue.openBlock(), vue.createElementBlock("svg", _hoisted_1$$, _hoisted_5$j))
}

const script$1c = {};


script$1c.render = render$D;
script$1c.__file = "packages/admin-vue3/src/icons/IconMoreHorizontal.vue";

const _hoisted_1$_ = {
  width: "12",
  height: "12",
  "stroke-width": "1.5",
  viewBox: "0 0 24 24",
  fill: "none",
  xmlns: "http://www.w3.org/2000/svg"
};
const _hoisted_2$Q = /*#__PURE__*/vue.createElementVNode("path", {
  d: "M13.0207 5.82839L15.8491 2.99996L20.7988 7.94971L17.9704 10.7781M13.0207 5.82839L3.41405 15.435C3.22652 15.6225 3.12116 15.8769 3.12116 16.1421V20.6776H7.65669C7.92191 20.6776 8.17626 20.5723 8.3638 20.3847L17.9704 10.7781M13.0207 5.82839L17.9704 10.7781",
  stroke: "currentColor",
  "stroke-linecap": "round",
  "stroke-linejoin": "round"
}, null, -1 /* HOISTED */);
const _hoisted_3$D = [
  _hoisted_2$Q
];

function render$C(_ctx, _cache) {
  return (vue.openBlock(), vue.createElementBlock("svg", _hoisted_1$_, _hoisted_3$D))
}

const script$1b = {};


script$1b.render = render$C;
script$1b.__file = "packages/admin-vue3/src/icons/IconEditPencil.vue";

const _hoisted_1$Z = {
  width: "24",
  height: "24",
  "stroke-width": "1.5",
  viewBox: "0 0 24 24",
  fill: "none",
  xmlns: "http://www.w3.org/2000/svg"
};
const _hoisted_2$P = /*#__PURE__*/vue.createElementVNode("path", {
  d: "M6 9L12 15L18 9",
  stroke: "currentColor",
  "stroke-linecap": "round",
  "stroke-linejoin": "round"
}, null, -1 /* HOISTED */);
const _hoisted_3$C = [
  _hoisted_2$P
];

function render$B(_ctx, _cache) {
  return (vue.openBlock(), vue.createElementBlock("svg", _hoisted_1$Z, _hoisted_3$C))
}

const script$1a = {};


script$1a.render = render$B;
script$1a.__file = "packages/admin-vue3/src/icons/IconCaret.vue";

const _hoisted_1$Y = {
  width: "24",
  height: "24",
  viewBox: "0 0 24 24",
  "stroke-width": "1",
  fill: "none",
  xmlns: "http://www.w3.org/2000/svg"
};
const _hoisted_2$O = /*#__PURE__*/vue.createElementVNode("path", {
  d: "M13 21H3.6a.6.6 0 0 1-.6-.6V3.6a.6.6 0 0 1 .6-.6h16.8a.6.6 0 0 1 .6.6V13",
  stroke: "currentColor",
  "stroke-linecap": "round",
  "stroke-linejoin": "round"
}, null, -1 /* HOISTED */);
const _hoisted_3$B = /*#__PURE__*/vue.createElementVNode("path", {
  d: "m3 16 7-3 5.5 2.5M16 10a2 2 0 1 1 0-4 2 2 0 0 1 0 4ZM16 19h3m3 0h-3m0 0v-3m0 3v3",
  stroke: "currentColor",
  "stroke-linecap": "round",
  "stroke-linejoin": "round"
}, null, -1 /* HOISTED */);
const _hoisted_4$t = [
  _hoisted_2$O,
  _hoisted_3$B
];

function render$A(_ctx, _cache) {
  return (vue.openBlock(), vue.createElementBlock("svg", _hoisted_1$Y, _hoisted_4$t))
}

const script$19 = {};


script$19.render = render$A;
script$19.__file = "packages/admin-vue3/src/icons/IconAddImage.vue";

const _hoisted_1$X = {
  width: "24",
  height: "24",
  viewBox: "0 0 24 24",
  "stroke-width": "1",
  fill: "none",
  xmlns: "http://www.w3.org/2000/svg"
};
const _hoisted_2$N = /*#__PURE__*/vue.createElementVNode("path", {
  d: "M5 19.5V5a2 2 0 0 1 2-2h11.4a.6.6 0 0 1 .6.6V21M9 7h6M6.5 15H19M6.5 18H19M6.5 21H19",
  stroke: "currentColor",
  "stroke-linecap": "round"
}, null, -1 /* HOISTED */);
const _hoisted_3$A = /*#__PURE__*/vue.createElementVNode("path", {
  d: "M6.5 18c-1 0-1.5-.672-1.5-1.5S5.5 15 6.5 15M6.5 21c-1 0-1.5-.672-1.5-1.5S5.5 18 6.5 18",
  stroke: "currentColor",
  "stroke-linecap": "round",
  "stroke-linejoin": "round"
}, null, -1 /* HOISTED */);
const _hoisted_4$s = [
  _hoisted_2$N,
  _hoisted_3$A
];

function render$z(_ctx, _cache) {
  return (vue.openBlock(), vue.createElementBlock("svg", _hoisted_1$X, _hoisted_4$s))
}

const script$18 = {};


script$18.render = render$z;
script$18.__file = "packages/admin-vue3/src/icons/IconBookStack.vue";

const _hoisted_1$W = {
  width: "24",
  height: "24",
  viewBox: "0 0 24 24",
  "stroke-width": "1.5",
  fill: "none",
  xmlns: "http://www.w3.org/2000/svg"
};
const _hoisted_2$M = /*#__PURE__*/vue.createElementVNode("path", {
  d: "M22 12.6V20.4C22 20.7314 21.7314 21 21.4 21H13.6C13.2686 21 13 20.7314 13 20.4V12.6C13 12.2686 13.2686 12 13.6 12H21.4C21.7314 12 22 12.2686 22 12.6Z",
  stroke: "currentColor",
  "stroke-linecap": "round",
  "stroke-linejoin": "round"
}, null, -1 /* HOISTED */);
const _hoisted_3$z = /*#__PURE__*/vue.createElementVNode("path", {
  d: "M19.5 14.51L19.51 14.4989",
  stroke: "currentColor",
  "stroke-linecap": "round",
  "stroke-linejoin": "round"
}, null, -1 /* HOISTED */);
const _hoisted_4$r = /*#__PURE__*/vue.createElementVNode("path", {
  d: "M13 18.2L16.5 17L22 19",
  stroke: "currentColor",
  "stroke-linecap": "round",
  "stroke-linejoin": "round"
}, null, -1 /* HOISTED */);
const _hoisted_5$i = /*#__PURE__*/vue.createElementVNode("path", {
  d: "M2 10V3.6C2 3.26863 2.26863 3 2.6 3H8.77805C8.92127 3 9.05977 3.05124 9.16852 3.14445L12.3315 5.85555C12.4402 5.94876 12.5787 6 12.722 6H21.4C21.7314 6 22 6.26863 22 6.6V9M2 10V18.4C2 18.7314 2.26863 19 2.6 19H10M2 10H10",
  stroke: "currentColor",
  "stroke-linecap": "round",
  "stroke-linejoin": "round"
}, null, -1 /* HOISTED */);
const _hoisted_6$a = [
  _hoisted_2$M,
  _hoisted_3$z,
  _hoisted_4$r,
  _hoisted_5$i
];

function render$y(_ctx, _cache) {
  return (vue.openBlock(), vue.createElementBlock("svg", _hoisted_1$W, _hoisted_6$a))
}

const script$17 = {};


script$17.render = render$y;
script$17.__file = "packages/admin-vue3/src/icons/IconMediaImageFolder.vue";

const _hoisted_1$V = {
  width: "24",
  height: "24",
  xmlns: "http://www.w3.org/2000/svg",
  viewBox: "-4.5 -4.5 24 24",
  fill: "currentColor"
};
const _hoisted_2$L = /*#__PURE__*/vue.createElementVNode("path", { d: "M8.9 6.9v-5a1 1 0 1 0-2 0v5h-5a1 1 0 1 0 0 2h5v5a1 1 0 1 0 2 0v-5h5a1 1 0 1 0 0-2h-5z" }, null, -1 /* HOISTED */);
const _hoisted_3$y = [
  _hoisted_2$L
];

function render$x(_ctx, _cache) {
  return (vue.openBlock(), vue.createElementBlock("svg", _hoisted_1$V, _hoisted_3$y))
}

const script$16 = {};


script$16.render = render$x;
script$16.__file = "packages/admin-vue3/src/icons/IconPlus.vue";

const _hoisted_1$U = {
  width: "24",
  height: "24",
  "stroke-width": "1.5",
  viewBox: "0 0 24 24",
  fill: "none",
  xmlns: "http://www.w3.org/2000/svg"
};
const _hoisted_2$K = /*#__PURE__*/vue.createElementVNode("path", {
  d: "M16 12H17.4C17.7314 12 18 12.2686 18 12.6V19.4C18 19.7314 17.7314 20 17.4 20H6.6C6.26863 20 6 19.7314 6 19.4V12.6C6 12.2686 6.26863 12 6.6 12H8M16 12V8C16 6.66667 15.2 4 12 4C8.8 4 8 6.66667 8 8V12M16 12H8",
  stroke: "currentColor",
  "stroke-linecap": "round",
  "stroke-linejoin": "round"
}, null, -1 /* HOISTED */);
const _hoisted_3$x = [
  _hoisted_2$K
];

function render$w(_ctx, _cache) {
  return (vue.openBlock(), vue.createElementBlock("svg", _hoisted_1$U, _hoisted_3$x))
}

const script$15 = {};


script$15.render = render$w;
script$15.__file = "packages/admin-vue3/src/icons/IconLocked.vue";

const _hoisted_1$T = {
  width: "24",
  height: "24",
  "stroke-width": "1.5",
  viewBox: "0 0 24 24",
  fill: "none",
  xmlns: "http://www.w3.org/2000/svg"
};
const _hoisted_2$J = /*#__PURE__*/vue.createStaticVNode("<path d=\"M11.5 12H6.6C6.26863 12 6 12.2686 6 12.6V19.4C6 19.7314 6.26863 20 6.6 20H17.4C17.7314 20 18 19.7314 18 19.4V18.5\" stroke=\"currentColor\" stroke-linecap=\"round\" stroke-linejoin=\"round\"></path><path d=\"M16 12V8C16 6.66667 15.2 4 12 4C11.2532 4 10.6371 4.14525 10.1313 4.38491\" stroke=\"currentColor\" stroke-linecap=\"round\" stroke-linejoin=\"round\"></path><path d=\"M16 12H17.4C17.7314 12 18 12.2686 18 12.6V13\" stroke=\"currentColor\" stroke-linecap=\"round\" stroke-linejoin=\"round\"></path><path d=\"M8 8V8.5V12\" stroke=\"currentColor\" stroke-linecap=\"round\" stroke-linejoin=\"round\"></path><path d=\"M3 3L21 21\" stroke=\"currentColor\" stroke-linecap=\"round\" stroke-linejoin=\"round\"></path>", 5);
const _hoisted_7$6 = [
  _hoisted_2$J
];

function render$v(_ctx, _cache) {
  return (vue.openBlock(), vue.createElementBlock("svg", _hoisted_1$T, _hoisted_7$6))
}

const script$14 = {};


script$14.render = render$v;
script$14.__file = "packages/admin-vue3/src/icons/IconUnlocked.vue";

const _hoisted_1$S = {
  width: "24",
  height: "24",
  "stroke-width": "1.5",
  viewBox: "0 0 24 24",
  fill: "none",
  xmlns: "http://www.w3.org/2000/svg"
};
const _hoisted_2$I = /*#__PURE__*/vue.createElementVNode("path", {
  d: "M7 2L16.5 2L21 6.5V19",
  stroke: "currentColor",
  "stroke-linecap": "round",
  "stroke-linejoin": "round"
}, null, -1 /* HOISTED */);
const _hoisted_3$w = /*#__PURE__*/vue.createElementVNode("path", {
  d: "M3 20.5V6.5C3 5.67157 3.67157 5 4.5 5H14.2515C14.4106 5 14.5632 5.06321 14.6757 5.17574L17.8243 8.32426C17.9368 8.43679 18 8.5894 18 8.74853V20.5C18 21.3284 17.3284 22 16.5 22H4.5C3.67157 22 3 21.3284 3 20.5Z",
  stroke: "currentColor",
  "stroke-linecap": "round",
  "stroke-linejoin": "round"
}, null, -1 /* HOISTED */);
const _hoisted_4$q = /*#__PURE__*/vue.createElementVNode("path", {
  d: "M14 8.4V5.35355C14 5.15829 14.1583 5 14.3536 5C14.4473 5 14.5372 5.03725 14.6036 5.10355L17.8964 8.39645C17.9628 8.46275 18 8.55268 18 8.64645C18 8.84171 17.8417 9 17.6464 9H14.6C14.2686 9 14 8.73137 14 8.4Z",
  fill: "currentColor",
  stroke: "currentColor",
  "stroke-linecap": "round",
  "stroke-linejoin": "round"
}, null, -1 /* HOISTED */);
const _hoisted_5$h = [
  _hoisted_2$I,
  _hoisted_3$w,
  _hoisted_4$q
];

function render$u(_ctx, _cache) {
  return (vue.openBlock(), vue.createElementBlock("svg", _hoisted_1$S, _hoisted_5$h))
}

const script$13 = {};


script$13.render = render$u;
script$13.__file = "packages/admin-vue3/src/icons/IconPages.vue";

const _hoisted_1$R = {
  width: "24",
  height: "24",
  "stroke-width": "1.5",
  viewBox: "0 0 24 24",
  fill: "none",
  xmlns: "http://www.w3.org/2000/svg"
};
const _hoisted_2$H = /*#__PURE__*/vue.createStaticVNode("<path d=\"M10 9H6\" stroke=\"currentColor\" stroke-linecap=\"round\" stroke-linejoin=\"round\"></path><path d=\"M15.5 11C14.1193 11 13 9.88071 13 8.5C13 7.11929 14.1193 6 15.5 6C16.8807 6 18 7.11929 18 8.5C18 9.88071 16.8807 11 15.5 11Z\" stroke=\"currentColor\" stroke-linecap=\"round\" stroke-linejoin=\"round\"></path><path d=\"M6 6H9\" stroke=\"currentColor\" stroke-linecap=\"round\" stroke-linejoin=\"round\"></path><path d=\"M18 18L13.5 15L11 17L6 13\" stroke=\"currentColor\" stroke-linecap=\"round\" stroke-linejoin=\"round\"></path><path d=\"M3 20.4V3.6C3 3.26863 3.26863 3 3.6 3H20.4C20.7314 3 21 3.26863 21 3.6V20.4C21 20.7314 20.7314 21 20.4 21H3.6C3.26863 21 3 20.7314 3 20.4Z\" stroke=\"currentColor\" stroke-width=\"1.5\"></path>", 5);
const _hoisted_7$5 = [
  _hoisted_2$H
];

function render$t(_ctx, _cache) {
  return (vue.openBlock(), vue.createElementBlock("svg", _hoisted_1$R, _hoisted_7$5))
}

const script$12 = {};


script$12.render = render$t;
script$12.__file = "packages/admin-vue3/src/icons/IconDashboard.vue";

const _hoisted_1$Q = {
  width: "24",
  height: "24",
  "stroke-width": "1.5",
  viewBox: "0 0 24 24",
  fill: "none",
  xmlns: "http://www.w3.org/2000/svg"
};
const _hoisted_2$G = /*#__PURE__*/vue.createStaticVNode("<path d=\"M8 6L20 6\" stroke=\"currentColor\" stroke-linecap=\"round\" stroke-linejoin=\"round\"></path><path d=\"M4 6.01L4.01 5.99889\" stroke=\"currentColor\" stroke-linecap=\"round\" stroke-linejoin=\"round\"></path><path d=\"M4 12.01L4.01 11.9989\" stroke=\"currentColor\" stroke-linecap=\"round\" stroke-linejoin=\"round\"></path><path d=\"M4 18.01L4.01 17.9989\" stroke=\"currentColor\" stroke-linecap=\"round\" stroke-linejoin=\"round\"></path><path d=\"M8 12L20 12\" stroke=\"currentColor\" stroke-linecap=\"round\" stroke-linejoin=\"round\"></path><path d=\"M8 18L20 18\" stroke=\"currentColor\" stroke-linecap=\"round\" stroke-linejoin=\"round\"></path>", 6);
const _hoisted_8$5 = [
  _hoisted_2$G
];

function render$s(_ctx, _cache) {
  return (vue.openBlock(), vue.createElementBlock("svg", _hoisted_1$Q, _hoisted_8$5))
}

const script$11 = {};


script$11.render = render$s;
script$11.__file = "packages/admin-vue3/src/icons/IconList.vue";

const _hoisted_1$P = {
  width: "24",
  height: "24",
  "stroke-width": "1.5",
  viewBox: "0 0 24 24",
  fill: "none",
  xmlns: "http://www.w3.org/2000/svg"
};
const _hoisted_2$F = /*#__PURE__*/vue.createElementVNode("path", {
  d: "M1.99219 19H4.99219M7.99219 19H4.99219M4.99219 19V16M4.99219 19V22",
  stroke: "currentColor",
  "stroke-linecap": "round",
  "stroke-linejoin": "round"
}, null, -1 /* HOISTED */);
const _hoisted_3$v = /*#__PURE__*/vue.createElementVNode("path", {
  d: "M7 2L16.5 2L21 6.5V19",
  stroke: "currentColor",
  "stroke-linecap": "round",
  "stroke-linejoin": "round"
}, null, -1 /* HOISTED */);
const _hoisted_4$p = /*#__PURE__*/vue.createElementVNode("path", {
  d: "M11 22H16.5C17.3284 22 18 21.3284 18 20.5V8.74853C18 8.5894 17.9368 8.43679 17.8243 8.32426L14.6757 5.17574C14.5632 5.06321 14.4106 5 14.2515 5H4.5C3.67157 5 3 5.67157 3 6.5V13",
  stroke: "currentColor",
  "stroke-linecap": "round",
  "stroke-linejoin": "round"
}, null, -1 /* HOISTED */);
const _hoisted_5$g = /*#__PURE__*/vue.createElementVNode("path", {
  d: "M14 8.4V5.35355C14 5.15829 14.1583 5 14.3536 5C14.4473 5 14.5372 5.03725 14.6036 5.10355L17.8964 8.39645C17.9628 8.46275 18 8.55268 18 8.64645C18 8.84171 17.8417 9 17.6464 9H14.6C14.2686 9 14 8.73137 14 8.4Z",
  fill: "currentColor",
  stroke: "currentColor",
  "stroke-linecap": "round",
  "stroke-linejoin": "round"
}, null, -1 /* HOISTED */);
const _hoisted_6$9 = [
  _hoisted_2$F,
  _hoisted_3$v,
  _hoisted_4$p,
  _hoisted_5$g
];

function render$r(_ctx, _cache) {
  return (vue.openBlock(), vue.createElementBlock("svg", _hoisted_1$P, _hoisted_6$9))
}

const script$10 = {};


script$10.render = render$r;
script$10.__file = "packages/admin-vue3/src/icons/IconDuplicatePage.vue";

const _hoisted_1$O = {
  width: "24",
  height: "24",
  "stroke-width": "1.5",
  viewBox: "0 0 24 24",
  fill: "none",
  xmlns: "http://www.w3.org/2000/svg"
};
const _hoisted_2$E = /*#__PURE__*/vue.createElementVNode("path", {
  d: "M12 15C13.6569 15 15 13.6569 15 12C15 10.3431 13.6569 9 12 9C10.3431 9 9 10.3431 9 12C9 13.6569 10.3431 15 12 15Z",
  stroke: "currentColor",
  "stroke-linecap": "round",
  "stroke-linejoin": "round"
}, null, -1 /* HOISTED */);
const _hoisted_3$u = /*#__PURE__*/vue.createElementVNode("path", {
  d: "M19.6224 10.3954L18.5247 7.7448L20 6L18 4L16.2647 5.48295L13.5578 4.36974L12.9353 2H10.981L10.3491 4.40113L7.70441 5.51596L6 4L4 6L5.45337 7.78885L4.3725 10.4463L2 11V13L4.40111 13.6555L5.51575 16.2997L4 18L6 20L7.79116 18.5403L10.397 19.6123L11 22H13L13.6045 19.6132L16.2551 18.5155C16.6969 18.8313 18 20 18 20L20 18L18.5159 16.2494L19.6139 13.598L21.9999 12.9772L22 11L19.6224 10.3954Z",
  stroke: "currentColor",
  "stroke-linecap": "round",
  "stroke-linejoin": "round"
}, null, -1 /* HOISTED */);
const _hoisted_4$o = [
  _hoisted_2$E,
  _hoisted_3$u
];

function render$q(_ctx, _cache) {
  return (vue.openBlock(), vue.createElementBlock("svg", _hoisted_1$O, _hoisted_4$o))
}

const script$$ = {};


script$$.render = render$q;
script$$.__file = "packages/admin-vue3/src/icons/IconSettings.vue";

const _hoisted_1$N = {
  width: "24",
  height: "24",
  "stroke-width": "1.5",
  viewBox: "0 0 24 24",
  fill: "none",
  xmlns: "http://www.w3.org/2000/svg"
};
const _hoisted_2$D = /*#__PURE__*/vue.createElementVNode("path", {
  d: "M12 12H19M19 12L16 15M19 12L16 9",
  stroke: "currentColor",
  "stroke-linecap": "round",
  "stroke-linejoin": "round"
}, null, -1 /* HOISTED */);
const _hoisted_3$t = /*#__PURE__*/vue.createElementVNode("path", {
  d: "M19 6V5C19 3.89543 18.1046 3 17 3H7C5.89543 3 5 3.89543 5 5V19C5 20.1046 5.89543 21 7 21H17C18.1046 21 19 20.1046 19 19V18",
  stroke: "currentColor",
  "stroke-linecap": "round",
  "stroke-linejoin": "round"
}, null, -1 /* HOISTED */);
const _hoisted_4$n = [
  _hoisted_2$D,
  _hoisted_3$t
];

function render$p(_ctx, _cache) {
  return (vue.openBlock(), vue.createElementBlock("svg", _hoisted_1$N, _hoisted_4$n))
}

const script$_ = {};


script$_.render = render$p;
script$_.__file = "packages/admin-vue3/src/icons/IconLogout.vue";

const _hoisted_1$M = {
  width: "24",
  height: "24",
  "stroke-width": "1.5",
  viewBox: "0 0 24 24",
  fill: "none",
  xmlns: "http://www.w3.org/2000/svg"
};
const _hoisted_2$C = /*#__PURE__*/vue.createElementVNode("path", {
  d: "M3.6 3H20.4C20.7314 3 21 3.26863 21 3.6V20.4C21 20.7314 20.7314 21 20.4 21H3.6C3.26863 21 3 20.7314 3 20.4V3.6C3 3.26863 3.26863 3 3.6 3Z",
  stroke: "currentColor",
  "stroke-width": "1.5"
}, null, -1 /* HOISTED */);
const _hoisted_3$s = /*#__PURE__*/vue.createElementVNode("path", {
  d: "M9.75 9.75V21",
  stroke: "currentColor",
  "stroke-width": "1.5"
}, null, -1 /* HOISTED */);
const _hoisted_4$m = /*#__PURE__*/vue.createElementVNode("path", {
  d: "M3 9.75H21",
  stroke: "currentColor",
  "stroke-width": "1.5"
}, null, -1 /* HOISTED */);
const _hoisted_5$f = [
  _hoisted_2$C,
  _hoisted_3$s,
  _hoisted_4$m
];

function render$o(_ctx, _cache) {
  return (vue.openBlock(), vue.createElementBlock("svg", _hoisted_1$M, _hoisted_5$f))
}

const script$Z = {};


script$Z.render = render$o;
script$Z.__file = "packages/admin-vue3/src/icons/IconPartials.vue";

const _hoisted_1$L = {
  width: "24",
  height: "24",
  "stroke-width": "1.5",
  viewBox: "0 0 24 24",
  fill: "none",
  xmlns: "http://www.w3.org/2000/svg"
};
const _hoisted_2$B = /*#__PURE__*/vue.createElementVNode("path", {
  d: "M3 7.4V3.6C3 3.26863 3.26863 3 3.6 3H9.4C9.73137 3 10 3.26863 10 3.6V7.4C10 7.73137 9.73137 8 9.4 8H3.6C3.26863 8 3 7.73137 3 7.4Z",
  stroke: "currentColor",
  "stroke-width": "1.5"
}, null, -1 /* HOISTED */);
const _hoisted_3$r = /*#__PURE__*/vue.createElementVNode("path", {
  d: "M14 20.4V16.6C14 16.2686 14.2686 16 14.6 16H20.4C20.7314 16 21 16.2686 21 16.6V20.4C21 20.7314 20.7314 21 20.4 21H14.6C14.2686 21 14 20.7314 14 20.4Z",
  stroke: "currentColor",
  "stroke-width": "1.5"
}, null, -1 /* HOISTED */);
const _hoisted_4$l = /*#__PURE__*/vue.createElementVNode("path", {
  d: "M14 12.4V3.6C14 3.26863 14.2686 3 14.6 3H20.4C20.7314 3 21 3.26863 21 3.6V12.4C21 12.7314 20.7314 13 20.4 13H14.6C14.2686 13 14 12.7314 14 12.4Z",
  stroke: "currentColor",
  "stroke-width": "1.5"
}, null, -1 /* HOISTED */);
const _hoisted_5$e = /*#__PURE__*/vue.createElementVNode("path", {
  d: "M3 20.4V11.6C3 11.2686 3.26863 11 3.6 11H9.4C9.73137 11 10 11.2686 10 11.6V20.4C10 20.7314 9.73137 21 9.4 21H3.6C3.26863 21 3 20.7314 3 20.4Z",
  stroke: "currentColor",
  "stroke-width": "1.5"
}, null, -1 /* HOISTED */);
const _hoisted_6$8 = [
  _hoisted_2$B,
  _hoisted_3$r,
  _hoisted_4$l,
  _hoisted_5$e
];

function render$n(_ctx, _cache) {
  return (vue.openBlock(), vue.createElementBlock("svg", _hoisted_1$L, _hoisted_6$8))
}

const script$Y = {};


script$Y.render = render$n;
script$Y.__file = "packages/admin-vue3/src/icons/IconBlocks.vue";

const _hoisted_1$K = { class: "w-full" };
const _hoisted_2$A = { class: "flex items-center flex-col justify-center" };
const _hoisted_3$q = { class: "text-orange" };
const _hoisted_4$k = {
    key: 0,
    class: "text-sm text-center uppercase"
};
const _hoisted_5$d = {
    key: 1,
    class: "text-sm text-center uppercase"
};
const _hoisted_6$7 = {
    key: 2,
    class: "text-sm text-center uppercase"
};
const _hoisted_7$4 = /*#__PURE__*/ vue.createTextVNode(" Drag & Drop");
const _hoisted_8$4 = /*#__PURE__*/ vue.createElementVNode("br", null, null, -1 /* HOISTED */);
const _hoisted_9$3 = /*#__PURE__*/ vue.createTextVNode("or ");
const _hoisted_10$2 = /*#__PURE__*/ vue.createElementVNode("span", { class: "underline" }, "browse", -1 /* HOISTED */);
const _hoisted_11$2 = [
    _hoisted_7$4,
    _hoisted_8$4,
    _hoisted_9$3,
    _hoisted_10$2
];
const _hoisted_12$2 = {
    key: 0,
    class: "ml-[18px]"
};
const _hoisted_13$1 = { class: "inline-block mt-1 text-xs text-red-signal" };
var script$X = /*#__PURE__*/ vue.defineComponent({
    props: {
        modelValue: Array,
        accept: {
            type: [Array, String],
            default: null,
        },
        disabled: {
            type: Boolean,
            default: false,
        },
        maxSize: {
            type: Number,
            default: 10,
        },
        maxFiles: {
            type: Number,
            default: 1,
        },
        url: {
            type: String,
            required: true,
        },
        multiple: {
            type: Boolean,
            default: false,
        },
    },
    emits: ['success', 'failed'],
    setup(__props, { emit }) {
        const props = __props;
        const busy = vue.ref(false);
        const saveFiles = files => {
            busy.value = true;
            const formData = new FormData(); // pass data as a form
            for (var x = 0; x < files.length; x++) {
                // append files as array to the form, feel free to change the array name
                formData.append('files[]', files[x]);
            }
            // post the formData to your backend where storage is processed. In the backend, you will need to loop through the array and save each file through the loop.
            axios__default
                .post(props.url, formData, {
                headers: {
                    'Content-Type': 'multipart/form-data',
                },
            })
                .then(response => {
                console.info(response.data);
                busy.value = false;
                if (response.status >= 200 && response.status < 300) {
                    emit('success');
                }
            })
                .catch(err => {
                const error = new Error(err);
                console.error(error);
                busy.value = false;
                emit('failed', error);
            });
        };
        function onDrop(acceptFiles, rejectReasons) {
            if (rejectReasons.length == 0) {
                saveFiles(acceptFiles);
            }
        }
        const maxSize = vue.computed(() => {
            return props.maxSize * (1024 * 1024);
        });
        const { getRootProps, getInputProps, fileRejections, isDragActive, isDragAccept, isDragReject, } = vue3Dropzone.useDropzone({
            onDrop,
            accept: props.accept,
            disabled: props.disabled,
            maxSize: maxSize.value,
            multiple: props.multiple,
            maxFiles: props.maxFiles,
        });
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createElementBlock(vue.Fragment, null, [
                vue.createElementVNode("div", _hoisted_1$K, [
                    vue.createElementVNode("div", vue.mergeProps({
                        class: ["flex items-center justify-center w-full transition-colors duration-300 border rounded cursor-pointer bg-gray-transparent focus:outline-none focus:border-orange aspect-square max-h-96", {
                                'border-red-signal': vue.unref(fileRejections).length > 0 || vue.unref(isDragReject),
                                'border-green': vue.unref(isDragAccept),
                                '!cursor-not-allowed': __props.disabled,
                                'border-gray-200': !vue.unref(isDragReject) &&
                                    !vue.unref(isDragAccept) &&
                                    vue.unref(fileRejections).length == 0,
                            }]
                    }, vue.unref(getRootProps)()), [
                        vue.createElementVNode("input", vue.normalizeProps(vue.guardReactiveProps(vue.unref(getInputProps)())), null, 16 /* FULL_PROPS */),
                        vue.createElementVNode("div", _hoisted_2$A, [
                            vue.createElementVNode("div", _hoisted_3$q, [
                                vue.createVNode(vue.unref(script$19))
                            ]),
                            (busy.value)
                                ? (vue.openBlock(), vue.createElementBlock("div", _hoisted_4$k, " Loading ... "))
                                : vue.createCommentVNode("v-if", true),
                            (!busy.value && vue.unref(isDragActive))
                                ? (vue.openBlock(), vue.createElementBlock("div", _hoisted_5$d, " Drop the files here ... "))
                                : vue.createCommentVNode("v-if", true),
                            (!busy.value && !vue.unref(isDragActive))
                                ? (vue.openBlock(), vue.createElementBlock("div", _hoisted_6$7, _hoisted_11$2))
                                : vue.createCommentVNode("v-if", true)
                        ])
                    ], 16 /* FULL_PROPS */)
                ]),
                (vue.unref(fileRejections).length > 0)
                    ? (vue.openBlock(), vue.createElementBlock("div", _hoisted_12$2, [
                        (vue.openBlock(true), vue.createElementBlock(vue.Fragment, null, vue.renderList(vue.unref(fileRejections)[0].errors, (error) => {
                            return (vue.openBlock(), vue.createElementBlock("span", _hoisted_13$1, vue.toDisplayString(error.message), 1 /* TEXT */));
                        }), 256 /* UNKEYED_FRAGMENT */))
                    ]))
                    : vue.createCommentVNode("v-if", true)
            ], 64 /* STABLE_FRAGMENT */));
        };
    }
});

script$X.__file = "packages/admin-vue3/src/ui/FileUpload.vue";

const _hoisted_1$J = { class: "h-[30px] px-3 py-2 flex w-fit items-center gap-2 transition-colors bg-orange-100 focus:outline-none text-orange duration-200 rounded-full leading-none text-sm" };
const _hoisted_2$z = { class: "inline-block" };
const _hoisted_3$p = ["onClick"];
const _hoisted_4$j = /*#__PURE__*/ vue.createElementVNode("path", { d: "M7.314 5.9l3.535-3.536A1 1 0 1 0 9.435.95L5.899 4.485 2.364.95A1 1 0 1 0 .95 2.364l3.535 3.535L.95 9.435a1 1 0 1 0 1.414 1.414l3.535-3.535 3.536 3.535a1 1 0 1 0 1.414-1.414L7.314 5.899z" }, null, -1 /* HOISTED */);
const _hoisted_5$c = [
    _hoisted_4$j
];
const _hoisted_6$6 = ["placeholder"];
var script$W = /*#__PURE__*/ vue.defineComponent({
    props: {
        modelValue: {
            type: Array,
            default: [],
        },
        placeholder: {
            type: String,
            default: 'Ihre Eingabe',
        },
        errors: {
            type: [Array, String],
            default: null,
        },
    },
    emits: ['update:modelValue'],
    setup(__props, { emit }) {
        const props = __props;
        const chips = vue.ref(props.modelValue);
        const currentInput = vue.ref('');
        const saveChip = () => {
            if (currentInput.value.length == 0) {
                return;
            }
            if (chips.value.find((chip) => chip === currentInput.value)) {
                return;
            }
            chips.value.push(currentInput.value);
            currentInput.value = '';
        };
        const deleteChip = (index) => {
            chips.value.splice(index, 1);
        };
        const backspaceDelete = () => {
            currentInput.value === ''
                ? chips.value.splice(chips.value.length - 1)
                : chips.value;
        };
        vue.watch(chips.value, () => {
            emit('update:modelValue', chips.value);
        });
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createElementBlock("div", {
                class: vue.normalizeClass(["relative flex flex-wrap gap-2 py-2.5 px-[18px] overflow-y-auto border rounded-sm max-h-[126px]", {
                        'border-red-signal': __props.errors?.length > 0 || !!__props.errors,
                        'border-gray-900': __props.errors?.length == 0 || !__props.errors,
                    }])
            }, [
                (vue.openBlock(true), vue.createElementBlock(vue.Fragment, null, vue.renderList(chips.value, (chip, i) => {
                    return (vue.openBlock(), vue.createElementBlock("div", _hoisted_1$J, [
                        vue.createElementVNode("span", _hoisted_2$z, vue.toDisplayString(chip), 1 /* TEXT */),
                        (vue.openBlock(), vue.createElementBlock("svg", {
                            onClick: ($event) => (deleteChip(i)),
                            class: "cursor-pointer",
                            xmlns: "http://www.w3.org/2000/svg",
                            viewBox: "-6 -6 24 24",
                            width: "16",
                            fill: "currentColor"
                        }, _hoisted_5$c, 8 /* PROPS */, _hoisted_3$p))
                    ]));
                }), 256 /* UNKEYED_FRAGMENT */)),
                vue.withDirectives(vue.createElementVNode("input", {
                    type: "text",
                    class: "w-full py-2.5 px-[18px] -my-2.5 -mx-[18px] bg-transparent text-base placeholder:text-gray-900 focus:outline-none",
                    placeholder: __props.placeholder,
                    "onUpdate:modelValue": _cache[0] || (_cache[0] = ($event) => ((currentInput).value = $event)),
                    onKeypress: _cache[1] || (_cache[1] = vue.withKeys(($event) => (saveChip()), ["enter"])),
                    onKeydown: _cache[2] || (_cache[2] = vue.withKeys(($event) => (backspaceDelete()), ["delete"]))
                }, null, 40 /* PROPS, HYDRATE_EVENTS */, _hoisted_6$6), [
                    [vue.vModelText, currentInput.value]
                ])
            ], 2 /* CLASS */));
        };
    }
});

script$W.__file = "packages/admin-vue3/src/ui/ChipInput.vue";

const _hoisted_1$I = { class: "relative flex justify-between w-full" };

function render$m(_ctx, _cache) {
  return (vue.openBlock(), vue.createElementBlock("div", _hoisted_1$I, [
    vue.renderSlot(_ctx.$slots, "default")
  ]))
}

const script$V = {};


script$V.render = render$m;
script$V.__file = "packages/admin-vue3/src/ui/Content.vue";

var script$U = /*#__PURE__*/ vue.defineComponent({
    props: {
        topPosition: {
            type: [String, Number],
            default: '110',
        },
    },
    setup(__props) {
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createElementBlock("div", {
                class: "flex-1 pt-6 pb-10 px-8 overflow-y-auto",
                style: vue.normalizeStyle(`height: calc(100vh - ${__props.topPosition}px); top: ${__props.topPosition}px;`)
            }, [
                vue.renderSlot(_ctx.$slots, "default")
            ], 4 /* STYLE */));
        };
    }
});

script$U.__file = "packages/admin-vue3/src/ui/ContentBody.vue";

const _hoisted_1$H = { class: "flex-1 w-full overflow-y-auto" };
const _hoisted_2$y = {
    key: 0,
    class: "w-full p-4 mt-4"
};
const _hoisted_3$o = { class: "flex items-center w-full gap-4 rotate-90" };
const _hoisted_4$i = { class: "flex items-center w-full px-4 py-2 mt-auto border-t border-gray-400" };
const _hoisted_5$b = /*#__PURE__*/ vue.createElementVNode("path", {
    d: "M18.5 12H6m0 0 6-6m-6 6 6 6",
    stroke: "currentColor",
    "stroke-linecap": "round",
    "stroke-linejoin": "round"
}, null, -1 /* HOISTED */);
const _hoisted_6$5 = [
    _hoisted_5$b
];
var script$T = /*#__PURE__*/ vue.defineComponent({
    props: {
        topPosition: {
            type: [String, Number],
            default: '110',
        },
        open: {
            type: Boolean,
            default: true,
        },
    },
    emits: ['update:open'],
    setup(__props, { emit }) {
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createElementBlock("div", {
                class: vue.normalizeClass(["sticky flex flex-col transition-all duration-300 bg-white shadow", {
                        'w-[233px]': __props.open,
                        'w-[60px]': !__props.open,
                    }]),
                style: vue.normalizeStyle(`height: calc(100vh - ${__props.topPosition}px); top: ${__props.topPosition}px;`)
            }, [
                vue.createElementVNode("div", _hoisted_1$H, [
                    vue.renderSlot(_ctx.$slots, "default"),
                    (!__props.open)
                        ? (vue.openBlock(), vue.createElementBlock("div", _hoisted_2$y, [
                            vue.createElementVNode("div", _hoisted_3$o, [
                                vue.renderSlot(_ctx.$slots, "title", {}, () => [
                                    vue.createTextVNode(vue.toDisplayString(_ctx.title), 1 /* TEXT */)
                                ])
                            ])
                        ]))
                        : vue.createCommentVNode("v-if", true)
                ]),
                vue.createElementVNode("div", _hoisted_4$i, [
                    vue.createElementVNode("button", {
                        class: "p-1 bg-gray-100 rounded",
                        onClick: _cache[0] || (_cache[0] = ($event) => (_ctx.$emit('update:open', !__props.open)))
                    }, [
                        (vue.openBlock(), vue.createElementBlock("svg", {
                            width: "24",
                            height: "24",
                            "stroke-width": "1.5",
                            fill: "none",
                            class: vue.normalizeClass(["transition-transform duration-300 scale-[0.8]", {
                                    'rotate-180': __props.open,
                                    'rotate-0': !__props.open,
                                }]),
                            xmlns: "http://www.w3.org/2000/svg"
                        }, _hoisted_6$5, 2 /* CLASS */))
                    ])
                ])
            ], 6 /* CLASS, STYLE */));
        };
    }
});

script$T.__file = "packages/admin-vue3/src/ui/ContentSidebar.vue";

const _hoisted_1$G = { class: "p-1 text-gray-100 hover:bg-black rounded-xs" };
const _hoisted_2$x = { class: "p-4 rounded-[8px] px-[14px] text-base py-[14px] min-w-[200px] bg-white shadow text-black" };
const _hoisted_3$n = { class: "flex flex-col" };
var script$S = /*#__PURE__*/ vue.defineComponent({
    props: {
        placement: {
            type: String,
            default: 'bottom',
        },
    },
    setup(__props) {
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createBlock(vue.unref(Popper__default), vue.mergeProps(_ctx.$attrs, {
                placement: __props.placement,
                arrow: "",
                class: "popper-wrapper"
            }), {
                content: vue.withCtx(() => [
                    vue.createElementVNode("div", _hoisted_2$x, [
                        vue.createElementVNode("div", _hoisted_3$n, [
                            vue.renderSlot(_ctx.$slots, "default")
                        ])
                    ])
                ]),
                default: vue.withCtx(() => [
                    vue.renderSlot(_ctx.$slots, "button", {}, () => [
                        vue.createElementVNode("button", _hoisted_1$G, [
                            vue.createVNode(script$1c, { class: "w-4 h-4" })
                        ])
                    ])
                ]),
                _: 3 /* FORWARDED */
            }, 16 /* FULL_PROPS */, ["placement"]));
        };
    }
});

var e=[],t=[];function n(n,r){if(n&&"undefined"!=typeof document){var a,s=!0===r.prepend?"prepend":"append",d=!0===r.singleTag,i="string"==typeof r.container?document.querySelector(r.container):document.getElementsByTagName("head")[0];if(d){var u=e.indexOf(i);-1===u&&(u=e.push(i)-1,t[u]={}),a=t[u]&&t[u][s]?t[u][s]:t[u][s]=c();}else a=c();65279===n.charCodeAt(0)&&(n=n.substring(1)),a.styleSheet?a.styleSheet.cssText+=n:a.appendChild(document.createTextNode(n));}function c(){var e=document.createElement("style");if(e.setAttribute("type","text/css"),r.attributes)for(var t=Object.keys(r.attributes),n=0;n<t.length;n++)e.setAttribute(t[n],r.attributes[t[n]]);var a="prepend"===s?"afterbegin":"beforeend";return i.insertAdjacentElement(a,e),e}}

var css$6 = "\n#arrow::before {\n    background-color: white !important;\n}\n/* This centers the button which is always wrapperd in a trigger div */\n.popper-wrapper > div:not(.popper) {\n    display: flex;\n}\n.popper {\n    z-index: 20 !important;\n}\n";
n(css$6,{});

script$S.__file = "packages/admin-vue3/src/ui/ContextMenu.vue";

const _hoisted_1$F = { class: "bg-gray-500 w-full my-1.5 h-px" };

function render$l(_ctx, _cache) {
  return (vue.openBlock(), vue.createElementBlock("div", _hoisted_1$F))
}

const script$R = {};


script$R.render = render$l;
script$R.__file = "packages/admin-vue3/src/ui/ContextMenuDivider.vue";

var script$Q = /*#__PURE__*/ vue.defineComponent({
    props: {
        label: {
            type: String,
            required: false,
        },
    },
    setup(__props) {
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createElementBlock("button", {
                class: vue.normalizeClass(["w-full py-2.5 px-[14px] text-left hover:bg-gray-100 rounded-[8px]", {
                        'flex items-center gap-2': _ctx.$slots.icon,
                    }])
            }, [
                vue.renderSlot(_ctx.$slots, "icon"),
                vue.renderSlot(_ctx.$slots, "default", {}, () => [
                    vue.createTextVNode(vue.toDisplayString(__props.label), 1 /* TEXT */)
                ])
            ], 2 /* CLASS */));
        };
    }
});

script$Q.__file = "packages/admin-vue3/src/ui/ContextMenuItem.vue";

const _hoisted_1$E = { class: "flex items-center justify-center w-6 h-6 bg-transparent rounded hover:bg-gray-800 group hover:text-white" };
const _hoisted_2$w = /*#__PURE__*/ vue.createStaticVNode("<svg class=\"w-3 h-3 group-hover:fill-white\" viewBox=\"0 0 24 24\" xmlns=\"http://www.w3.org/2000/svg\" xml:space=\"preserve\"><path style=\"fill:none;\" d=\"M0 0h24v24H0z\"></path><g transform=\"translate(.113 -1.351)\"><circle cx=\"4.678\" cy=\"13.351\" r=\"1.475\"></circle><circle cx=\"4.678\" cy=\"13.351\" r=\"1.475\" transform=\"translate(7.209)\"></circle><circle cx=\"4.678\" cy=\"13.351\" r=\"1.475\" transform=\"translate(14.418)\"></circle></g></svg>", 1);
const _hoisted_3$m = [
    _hoisted_2$w
];
var script$P = /*#__PURE__*/ vue.defineComponent({
    setup(__props) {
        //
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createElementBlock("button", _hoisted_1$E, _hoisted_3$m));
        };
    }
});

script$P.__file = "packages/admin-vue3/src/ui/ContextButton.vue";

var script$O = vue.defineComponent({
    props: {
        ...variants,
    },
    setup(props, { attrs }) {
        const tag = 'href' in attrs ? 'a' : 'div';
        const variant_ = getVariant(props, {});
        return { tag, variant_ };
    },
});

function render$k(_ctx, _cache, $props, $setup, $data, $options) {
  return (vue.openBlock(), vue.createBlock(vue.resolveDynamicComponent(_ctx.tag), {
    class: vue.normalizeClass(["inline-flex items-center justify-center px-3 py-2 text-xs font-medium rounded-full", {
            'bg-gradient-to-r from-red-500 to-orange-500 text-white ':
                _ctx.variant_ == 'primary',
            'bg-gray-800 text-gray': _ctx.variant_ == 'gray',
            'bg-darkorange text-darkorange bg-opacity-30':
                _ctx.variant_ == 'darkorange' || _ctx.variant_ == 'orange',
            'bg-lightorange text-lightorange bg-opacity-30':
                _ctx.variant_ == 'lightorange',
            'bg-grasgreen text-grasgreen bg-opacity-30':
                _ctx.variant_ == 'grasgreen' || _ctx.variant_ == 'green',
            'bg-turkise text-turkise bg-opacity-30': _ctx.variant_ == 'turkise',
            'bg-lightblue text-lightblue bg-opacity-30':
                _ctx.variant_ == 'lightblue',
            'bg-blue text-blue bg-opacity-30': _ctx.variant_ == 'blue',
            'bg-red-signal text-red-signal bg-opacity-30': _ctx.variant_ == 'red',
            'bg-purple text-purple bg-opacity-30': _ctx.variant_ == 'purple',
            'bg-pink text-pink bg-opacity-30': _ctx.variant_ == 'pink',
        }])
  }, {
    default: vue.withCtx(() => [
      vue.renderSlot(_ctx.$slots, "default")
    ]),
    _: 3 /* FORWARDED */
  }, 8 /* PROPS */, ["class"]))
}

script$O.render = render$k;
script$O.__file = "packages/admin-vue3/src/ui/Badge.vue";

const _hoisted_1$D = { class: "text-sm font-medium" };
const _hoisted_2$v = ["innerHTML"];
var script$N = /*#__PURE__*/ vue.defineComponent({
    props: {
        color: {
            type: String,
            default: 'purple',
        },
        title: {
            type: String,
            required: true,
        },
        hint: {
            type: String,
            default: null,
        },
        preview: {
            type: Boolean,
            default: false,
        },
    },
    setup(__props) {
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createElementBlock("div", {
                class: vue.normalizeClass(["flex bg-white cursor-pointer hover:ring-2", {
                        'hover:ring-purple ': __props.color == 'purple',
                        'hover:ring-green ': __props.color == 'green',
                        'hover:ring-orange ': __props.color == 'orange',
                        'hover:ring-red ': __props.color == 'red',
                        'hover:ring-blue ': __props.color == 'blue',
                        'pointer-events-none p-2 rounded': __props.preview,
                        'mb-3 rounded-xs': !__props.preview
                    }])
            }, [
                vue.createElementVNode("div", {
                    class: vue.normalizeClass(["flex items-center justify-center w-12 h-auto mr-3 bg-opacity-10 rounded-xs", {
                            'text-purple bg-purple ': __props.color == 'purple',
                            'text-green bg-green ': __props.color == 'green',
                            'text-orange bg-orange ': __props.color == 'orange',
                            'text-red bg-red ': __props.color == 'red',
                            'text-blue bg-blue ': __props.color == 'blue',
                        }])
                }, [
                    vue.renderSlot(_ctx.$slots, "default")
                ], 2 /* CLASS */),
                vue.createElementVNode("div", _hoisted_1$D, [
                    vue.createTextVNode(vue.toDisplayString(__props.title) + " ", 1 /* TEXT */),
                    (__props.hint)
                        ? (vue.openBlock(), vue.createElementBlock("div", {
                            key: 0,
                            class: "-mt-[2px] text-sm font-normal text-gray",
                            innerHTML: __props.hint
                        }, null, 8 /* PROPS */, _hoisted_2$v))
                        : vue.createCommentVNode("v-if", true)
                ])
            ], 2 /* CLASS */));
        };
    }
});

script$N.__file = "packages/admin-vue3/src/ui/Drawer.vue";

const _hoisted_1$C = { class: "w-full py-4 border-b border-gray-400" };
const _hoisted_2$u = ["innerHTML"];
var script$M = /*#__PURE__*/ vue.defineComponent({
    props: {
        title: {
            type: String,
            required: true,
        },
    },
    setup(__props) {
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createElementBlock("div", _hoisted_1$C, [
                vue.createVNode(vue.unref(vue$1.Disclosure), { defaultOpen: "" }, {
                    default: vue.withCtx(({ open }) => [
                        vue.createVNode(vue.unref(vue$1.DisclosureButton), { class: "flex items-center justify-between w-full px-4 text-sm font-medium" }, {
                            default: vue.withCtx(() => [
                                vue.createElementVNode("div", { innerHTML: __props.title }, null, 8 /* PROPS */, _hoisted_2$u),
                                vue.createElementVNode("div", {
                                    class: vue.normalizeClass({
                                        'rotate-180': !open,
                                    })
                                }, [
                                    vue.createVNode(vue.unref(script$1a), { class: "w-3 h-3" })
                                ], 2 /* CLASS */)
                            ]),
                            _: 2 /* DYNAMIC */
                        }, 1024 /* DYNAMIC_SLOTS */),
                        vue.createVNode(vue.unref(vue$1.DisclosurePanel), { class: "px-4 pt-3" }, {
                            default: vue.withCtx(() => [
                                vue.renderSlot(_ctx.$slots, "default")
                            ]),
                            _: 3 /* FORWARDED */
                        })
                    ]),
                    _: 3 /* FORWARDED */
                })
            ]));
        };
    }
});

script$M.__file = "packages/admin-vue3/src/ui/DrawerSection.vue";

var script$L = /*#__PURE__*/ vue.defineComponent({
    props: {
        disabled: {
            type: Boolean,
            default: false,
        },
        href: {
            type: String,
            required: false,
        },
    },
    setup(__props) {
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createBlock(vue.unref(vue$1.Tab), vue.mergeProps({
                disabled: __props.disabled,
                as: 'template',
                class: "flex focus:outline-none"
            }, _ctx.$attrs), {
                default: vue.withCtx(({ selected, active }) => [
                    (vue.openBlock(), vue.createBlock(vue.resolveDynamicComponent(__props.href ? vue.unref(inertiaVue3.Link) : 'button'), {
                        href: __props.href,
                        class: vue.normalizeClass(["px-3 py-1 text-sm tracking-widest uppercase transition-colors duration-200 cursor-pointer focus:outline-none flex items-center", {
                                'text-black bg-gray-200 border-b border-indigo-900': selected && !__props.disabled,
                                'bg-gray-50 border-b border-transparent focus:bg-gray-200 hover:bg-gray-200': !selected && !__props.disabled,
                                'bg-gray-50 border-b border-transparent text-gray-300 cursor-not-allowed': __props.disabled,
                            }])
                    }, {
                        default: vue.withCtx(() => [
                            vue.renderSlot(_ctx.$slots, "default")
                        ]),
                        _: 2 /* DYNAMIC */
                    }, 1032 /* PROPS, DYNAMIC_SLOTS */, ["href", "class"]))
                ]),
                _: 3 /* FORWARDED */
            }, 16 /* FULL_PROPS */, ["disabled"]));
        };
    }
});

script$L.__file = "packages/admin-vue3/src/ui/Tab.vue";

const _hoisted_1$B = { class: "flex-1 w-full overflow-y-auto" };
const _hoisted_2$t = {
    key: 1,
    class: "w-full p-4 mt-4"
};
const _hoisted_3$l = { class: "flex items-center w-full gap-4 rotate-90" };
const _hoisted_4$h = { class: "flex items-center w-full px-4 py-2 mt-auto border-t border-gray-400" };
const _hoisted_5$a = /*#__PURE__*/ vue.createElementVNode("path", {
    d: "M18.5 12H6m0 0 6-6m-6 6 6 6",
    stroke: "currentColor",
    "stroke-linecap": "round",
    "stroke-linejoin": "round"
}, null, -1 /* HOISTED */);
const _hoisted_6$4 = [
    _hoisted_5$a
];
var script$K = /*#__PURE__*/ vue.defineComponent({
    props: {
        hasSidebar: {
            type: Boolean,
            default: false,
        },
        sidebarTopPosition: {
            type: String,
            default: '110',
        },
    },
    setup(__props) {
        const sidebarActive = vue.ref(true);
        const toggleSidebar = () => {
            if (sidebarActive.value) {
                sidebarActive.value = false;
                return;
            }
            sidebarActive.value = true;
        };
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createBlock(vue.unref(vue$1.TabPanel), { class: "relative flex justify-between w-full" }, {
                default: vue.withCtx(() => [
                    vue.createElementVNode("div", {
                        class: "flex-1 px-10 overflow-y-auto",
                        style: vue.normalizeStyle(`height: calc(100vh - ${__props.sidebarTopPosition}px); top: ${__props.sidebarTopPosition}px;`)
                    }, [
                        vue.renderSlot(_ctx.$slots, "default")
                    ], 4 /* STYLE */),
                    (__props.hasSidebar)
                        ? (vue.openBlock(), vue.createElementBlock("div", {
                            key: 0,
                            class: vue.normalizeClass(["sticky flex flex-col transition-all duration-300 bg-white shadow", {
                                    'w-[233px]': sidebarActive.value,
                                    'w-[60px]': !sidebarActive.value,
                                }]),
                            style: vue.normalizeStyle(`height: calc(100vh - ${__props.sidebarTopPosition}px); top: ${__props.sidebarTopPosition}px;`)
                        }, [
                            vue.createElementVNode("div", _hoisted_1$B, [
                                (sidebarActive.value)
                                    ? vue.renderSlot(_ctx.$slots, "sidebar", { key: 0 })
                                    : vue.createCommentVNode("v-if", true),
                                (!sidebarActive.value)
                                    ? (vue.openBlock(), vue.createElementBlock("div", _hoisted_2$t, [
                                        vue.createElementVNode("div", _hoisted_3$l, [
                                            vue.renderSlot(_ctx.$slots, "sidebarTitle")
                                        ])
                                    ]))
                                    : vue.createCommentVNode("v-if", true)
                            ]),
                            vue.createElementVNode("div", _hoisted_4$h, [
                                vue.createElementVNode("button", {
                                    onClick: _cache[0] || (_cache[0] = ($event) => (toggleSidebar())),
                                    class: "p-1 bg-gray-100 rounded"
                                }, [
                                    (vue.openBlock(), vue.createElementBlock("svg", {
                                        width: "24",
                                        height: "24",
                                        "stroke-width": "1.5",
                                        fill: "none",
                                        class: vue.normalizeClass(["transition-transform duration-300 scale-[0.8]", {
                                                'rotate-180': sidebarActive.value,
                                                'rotate-0': !sidebarActive.value,
                                            }]),
                                        xmlns: "http://www.w3.org/2000/svg"
                                    }, _hoisted_6$4, 2 /* CLASS */))
                                ])
                            ])
                        ], 6 /* CLASS, STYLE */))
                        : vue.createCommentVNode("v-if", true)
                ]),
                _: 3 /* FORWARDED */
            }));
        };
    }
});

script$K.__file = "packages/admin-vue3/src/ui/TabPanel.vue";

var script$J = /*#__PURE__*/ vue.defineComponent({
    setup(__props) {
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createBlock(vue.unref(vue$1.TabGroup), vue.mergeProps(_ctx.$attrs, {
                class: "w-full",
                as: "div"
            }), {
                default: vue.withCtx(() => [
                    vue.renderSlot(_ctx.$slots, "default")
                ]),
                _: 3 /* FORWARDED */
            }, 16 /* FULL_PROPS */));
        };
    }
});

script$J.__file = "packages/admin-vue3/src/ui/TabGroup.vue";

var script$I = /*#__PURE__*/ vue.defineComponent({
    setup(__props) {
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createBlock(vue.unref(vue$1.TabList), { class: "flex flex-wrap sticky z-[5] bg-gray-50 top-[80px] h-[30px] w-full px-10 border-b border-gray-200" }, {
                default: vue.withCtx(() => [
                    vue.renderSlot(_ctx.$slots, "default")
                ]),
                _: 3 /* FORWARDED */
            }));
        };
    }
});

script$I.__file = "packages/admin-vue3/src/ui/TabList.vue";

var script$H = /*#__PURE__*/ vue.defineComponent({
    setup(__props) {
        //
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createElementBlock("form", vue.normalizeProps(vue.guardReactiveProps(_ctx.$attrs)), [
                vue.renderSlot(_ctx.$slots, "default")
            ], 16 /* FULL_PROPS */));
        };
    }
});

script$H.__file = "packages/admin-vue3/src/ui/Form.vue";

const _hoisted_1$A = { class: "inline-block mb-[14px] font-semibold" };
var script$G = /*#__PURE__*/ vue.defineComponent({
    props: {
        label: {
            type: String,
        },
    },
    setup(__props) {
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createElementBlock("div", _hoisted_1$A, [
                vue.renderSlot(_ctx.$slots, "default", {}, () => [
                    vue.createTextVNode(vue.toDisplayString(__props.label), 1 /* TEXT */)
                ])
            ]));
        };
    }
});

script$G.__file = "packages/admin-vue3/src/ui/FormFieldLabel.vue";

const _hoisted_1$z = { class: "todo" };
const _hoisted_2$s = {
    key: 1,
    class: "mt-1 text-xs text-right text-gray-500"
};
const _hoisted_3$k = {
    key: 2,
    class: "text-right"
};
var script$F = /*#__PURE__*/ vue.defineComponent({
    props: {
        label: {
            type: String,
        },
        errors: {
            type: [Array, String],
            default: null,
        },
        hint: {
            type: String,
        },
        noLabel: {
            type: Boolean,
            default: false,
        },
    },
    setup(__props) {
        const props = __props;
        const errorList = vue.computed(() => {
            if (!props.errors) {
                return [];
            }
            if (Array.isArray(props.errors)) {
                return props.errors;
            }
            return [props.errors];
        });
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createElementBlock("div", _hoisted_1$z, [
                (!__props.noLabel)
                    ? vue.renderSlot(_ctx.$slots, "label", { key: 0 }, () => [
                        vue.createVNode(script$G, { label: __props.label }, null, 8 /* PROPS */, ["label"])
                    ])
                    : vue.createCommentVNode("v-if", true),
                vue.renderSlot(_ctx.$slots, "default"),
                (__props.hint && !__props.errors)
                    ? (vue.openBlock(), vue.createElementBlock("div", _hoisted_2$s, vue.toDisplayString(__props.hint), 1 /* TEXT */))
                    : vue.createCommentVNode("v-if", true),
                (__props.errors)
                    ? (vue.openBlock(), vue.createElementBlock("div", _hoisted_3$k, [
                        (vue.openBlock(true), vue.createElementBlock(vue.Fragment, null, vue.renderList(vue.unref(errorList), (error, key) => {
                            return (vue.openBlock(), vue.createElementBlock("span", {
                                key: key,
                                class: "inline-block mt-1 text-xs text-red"
                            }, vue.toDisplayString(error), 1 /* TEXT */));
                        }), 128 /* KEYED_FRAGMENT */))
                    ]))
                    : vue.createCommentVNode("v-if", true)
            ]));
        };
    }
});

script$F.__file = "packages/admin-vue3/src/ui/FormField.vue";

const _hoisted_1$y = { class: "fixed inset-0 z-50 overflow-y-auto" };
const _hoisted_2$r = { class: "min-h-screen px-4 text-center" };
const _hoisted_3$j = /*#__PURE__*/ vue.createElementVNode("span", {
    class: "inline-block h-screen align-middle",
    "aria-hidden": "true"
}, " ​ ", -1 /* HOISTED */);
const _hoisted_4$g = { class: "flex justify-end pt-4 space-x-3" };
var script$E = /*#__PURE__*/ vue.defineComponent({
    props: {
        open: {
            type: Boolean,
            default: false,
        },
        title: {
            type: [String, Number],
            default: null,
        },
        ...sizes,
    },
    emits: ['close', 'update:open'],
    setup(__props, { emit }) {
        const props = __props;
        const size_ = getSize(props, { DEFAULT: null });
        const close = (closing) => {
            emit('close', closing);
            emit('update:open', !closing);
        };
        const closeHandler = evt => {
            if (evt.key == 'Escape') {
                close(true);
            }
        };
        vue.onMounted(() => {
            document.addEventListener('keyup', closeHandler);
        });
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createBlock(vue.unref(vue$1.TransitionRoot), {
                appear: "",
                show: __props.open,
                as: "template"
            }, {
                default: vue.withCtx(() => [
                    vue.createVNode(vue.unref(vue$1.Dialog), {
                        as: "div",
                        open: __props.open
                    }, {
                        default: vue.withCtx(() => [
                            vue.createElementVNode("div", _hoisted_1$y, [
                                vue.createElementVNode("div", _hoisted_2$r, [
                                    vue.createVNode(vue.unref(vue$1.TransitionChild), {
                                        as: "template",
                                        enter: "duration-300 ease-out",
                                        "enter-from": "opacity-0",
                                        "enter-to": "opacity-100",
                                        leave: "duration-200 ease-in",
                                        "leave-from": "opacity-100",
                                        "leave-to": "opacity-0"
                                    }, {
                                        default: vue.withCtx(() => [
                                            vue.createVNode(vue.unref(vue$1.DialogOverlay), {
                                                class: "fixed inset-0 bg-gray-800 bg-opacity-75 backdrop-filter backdrop-blur-sm",
                                                onClick: _cache[0] || (_cache[0] = ($event) => (close(true)))
                                            })
                                        ]),
                                        _: 1 /* STABLE */
                                    }),
                                    _hoisted_3$j,
                                    vue.createVNode(vue.unref(vue$1.TransitionChild), {
                                        as: "template",
                                        enter: "duration-300 ease-out",
                                        "enter-from": "opacity-0 scale-95",
                                        "enter-to": "opacity-100 scale-100",
                                        leave: "duration-200 ease-in",
                                        "leave-from": "opacity-100 scale-100",
                                        "leave-to": "opacity-0 scale-95"
                                    }, {
                                        default: vue.withCtx(() => [
                                            vue.createElementVNode("div", {
                                                class: vue.normalizeClass(["inline-block w-full p-6 my-8 text-left align-middle transition-all transform bg-white rounded shadow-xl", {
                                                        'max-w-full': !vue.unref(size_),
                                                        'max-w-3xl': vue.unref(size_) == 'lg',
                                                        'max-w-2xl': vue.unref(size_) == 'md',
                                                        'max-w-xl': vue.unref(size_) == 'sm',
                                                    }])
                                            }, [
                                                (__props.title)
                                                    ? (vue.openBlock(), vue.createBlock(vue.unref(vue$1.DialogTitle), {
                                                        key: 0,
                                                        as: "h3",
                                                        class: "mb-6 text-xl font-medium leading-6 text-gray-800"
                                                    }, {
                                                        default: vue.withCtx(() => [
                                                            vue.createTextVNode(vue.toDisplayString(__props.title), 1 /* TEXT */)
                                                        ]),
                                                        _: 1 /* STABLE */
                                                    }))
                                                    : vue.createCommentVNode("v-if", true),
                                                vue.renderSlot(_ctx.$slots, "default"),
                                                vue.createElementVNode("div", _hoisted_4$g, [
                                                    vue.renderSlot(_ctx.$slots, "footer")
                                                ])
                                            ], 2 /* CLASS */)
                                        ]),
                                        _: 3 /* FORWARDED */
                                    })
                                ])
                            ])
                        ]),
                        _: 3 /* FORWARDED */
                    }, 8 /* PROPS */, ["open"])
                ]),
                _: 3 /* FORWARDED */
            }, 8 /* PROPS */, ["show"]));
        };
    }
});

script$E.__file = "packages/admin-vue3/src/ui/Modal.vue";

var script$D = vue.defineComponent({
    components: { Switch: vue$1.Switch },
    props: {
        label: {
            type: String,
            default: null,
        },
        disabled: {
            type: Boolean,
            default: false,
        },
        modelValue: {
            type: Boolean,
            default: false,
        },
        ...sizes,
        ...variants,
    },
    setup({ disabled, ...props }, { emit }) {
        const size_ = getSize(props, {});
        const variant_ = getVariant(props, {});
        const update = value => {
            if (disabled) {
                return;
            }
            emit('update:modelValue', value);
        };
        return { update, size_, variant_ };
    },
});

const _hoisted_1$x = { class: "inline-flex items-center cursor-pointer" };
const _hoisted_2$q = /*#__PURE__*/vue.createElementVNode("path", {
  d: "M16.576.414a1.386 1.386 0 010 1.996l-9.404 9.176A1.461 1.461 0 016.149 12c-.37 0-.74-.139-1.023-.414L.424 6.998a1.386 1.386 0 010-1.996 1.47 1.47 0 012.046 0l3.68 3.59L14.53.414a1.47 1.47 0 012.046 0z",
  fill: "#120F30",
  "fill-rule": "nonzero"
}, null, -1 /* HOISTED */);
const _hoisted_3$i = [
  _hoisted_2$q
];
const _hoisted_4$f = { class: "pt-1 pl-2 cursor-pointer" };

function render$j(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_Switch = vue.resolveComponent("Switch");

  return (vue.openBlock(), vue.createBlock(_component_Switch, {
    modelValue: _ctx.modelValue,
    "onUpdate:modelValue": _ctx.update,
    as: "template",
    class: "focus:outline-none"
  }, {
    default: vue.withCtx(({ checked }) => [
      vue.createElementVNode("div", _hoisted_1$x, [
        vue.createElementVNode("div", {
          class: vue.normalizeClass([
                    checked
                        ? 'bg-orange border-orange'
                        : 'bg-transparent border-indigo-900'
                , "z-0 flex items-center justify-center flex-shrink-0 w-[18px] h-[18px] mr-2 border rounded-xs focus:outline-none focus:ring-2 focus:ring-gray-300"])
        }, [
          (vue.openBlock(), vue.createElementBlock("svg", {
            class: vue.normalizeClass([checked ? 'block' : 'hidden', "z-0 w-2.5 h-2.5 text-gray-500 pointer-events-none fill-gray-500"]),
            viewBox: "0 0 17 12",
            xmlns: "http://www.w3.org/2000/svg"
          }, _hoisted_3$i, 2 /* CLASS */))
        ], 2 /* CLASS */),
        vue.createElementVNode("label", _hoisted_4$f, [
          vue.renderSlot(_ctx.$slots, "default", {}, () => [
            vue.createTextVNode(vue.toDisplayString(_ctx.label), 1 /* TEXT */)
          ])
        ])
      ])
    ]),
    _: 3 /* FORWARDED */
  }, 8 /* PROPS */, ["modelValue", "onUpdate:modelValue"]))
}

script$D.render = render$j;
script$D.__file = "packages/admin-vue3/src/ui/CheckboxSwitch.vue";

const _withScopeId$2 = n => (vue.pushScopeId("data-v-c595bb9a"), n = n(), vue.popScopeId(), n);
const _hoisted_1$w = { class: "flex items-center cursor-pointer max-w-max" };
const _hoisted_2$p = ["checked", "id"];
const _hoisted_3$h = /*#__PURE__*/ _withScopeId$2(() => /*#__PURE__*/ vue.createElementVNode("path", {
    d: "M16.576.414a1.386 1.386 0 010 1.996l-9.404 9.176A1.461 1.461 0 016.149 12c-.37 0-.74-.139-1.023-.414L.424 6.998a1.386 1.386 0 010-1.996 1.47 1.47 0 012.046 0l3.68 3.59L14.53.414a1.47 1.47 0 012.046 0z",
    fill: "#120F30",
    "fill-rule": "nonzero"
}, null, -1 /* HOISTED */));
const _hoisted_4$e = [
    _hoisted_3$h
];
const _hoisted_5$9 = { class: "pl-1 cursor-pointer" };
var script$C = /*#__PURE__*/ vue.defineComponent({
    props: {
        value: {
            type: String,
            required: true,
        },
        label: {
            type: String,
        },
        fieldId: {
            type: String,
            required: true,
        },
        modelValue: {
            type: Array,
            required: true,
        },
    },
    emits: ['update:modelValue'],
    setup(__props, { emit }) {
        const props = __props;
        const checked = vue.computed(() => {
            if (Array.isArray(props.modelValue)) {
                return props.modelValue.includes(props.value);
            }
            return props.modelValue;
        });
        const check = () => {
            let updatedNames = [...props.modelValue];
            // remove name if checked, else add name
            if (checked.value) {
                updatedNames.splice(updatedNames.indexOf(props.value), 1);
            }
            else {
                updatedNames.push(props.value);
            }
            // emit the updated names
            emit('update:modelValue', updatedNames);
        };
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createElementBlock("label", _hoisted_1$w, [
                vue.createElementVNode("input", vue.mergeProps({
                    onInput: _cache[0] || (_cache[0] = ($event) => (check())),
                    type: "checkbox",
                    checked: vue.unref(checked),
                    id: __props.fieldId,
                    class: "absolute mr-2 opacity-0"
                }, _ctx.$attrs), null, 16 /* FULL_PROPS */, _hoisted_2$p),
                vue.createElementVNode("div", {
                    class: vue.normalizeClass([
                        vue.unref(checked)
                            ? 'bg-orange border-orange'
                            : 'bg-transparent border-indigo-900',
                        "z-0 flex items-center justify-center flex-shrink-0 w-[18px] h-[18px] mr-2 border rounded-xs"
                    ])
                }, [
                    (vue.openBlock(), vue.createElementBlock("svg", {
                        class: vue.normalizeClass([vue.unref(checked) ? 'block' : 'hidden', "z-0 w-2.5 h-2.5 text-gray-500 pointer-events-none fill-gray-500"]),
                        viewBox: "0 0 17 12",
                        xmlns: "http://www.w3.org/2000/svg"
                    }, _hoisted_4$e, 2 /* CLASS */))
                ], 2 /* CLASS */),
                vue.createElementVNode("div", _hoisted_5$9, [
                    vue.renderSlot(_ctx.$slots, "default", {}, () => [
                        vue.createTextVNode(vue.toDisplayString(__props.label ?? __props.value), 1 /* TEXT */)
                    ])
                ])
            ]));
        };
    }
});

var css$5 = "\ninput:focus + div[data-v-c595bb9a] {\n    box-shadow: 0px 0 0 4px #d6d8e2;\n}\n";
n(css$5,{});

script$C.__scopeId = "data-v-c595bb9a";
script$C.__file = "packages/admin-vue3/src/ui/Checkbox.vue";

const _withScopeId$1 = n => (vue.pushScopeId("data-v-a4e231ec"), n = n(), vue.popScopeId(), n);
const _hoisted_1$v = { class: "relative" };
const _hoisted_2$o = { class: "absolute top-0 left-0 right-0 flex w-full h-full max-w-full pointer-events-none" };
const _hoisted_3$g = /*#__PURE__*/ _withScopeId$1(() => /*#__PURE__*/ vue.createElementVNode("div", { class: "border-l input-section-1 border-t border-b border-gray-900 w-[16px] h-full rounded-l-[8px]" }, null, -1 /* HOISTED */));
const _hoisted_4$d = /*#__PURE__*/ _withScopeId$1(() => /*#__PURE__*/ vue.createElementVNode("div", { class: "border-r border-t input-section-3 border-b focus:border-orange border-gray-900 flex-grow rounded-r-[8px] h-full" }, null, -1 /* HOISTED */));
const __default__ = {
    inheritAttrs: false,
    customOptions: {},
};
var script$B = /*#__PURE__*/ vue.defineComponent({
    ...__default__,
    props: {
        label: {
            type: String,
            default: null,
        },
        hint: {
            type: String,
            default: null,
        },
        disabled: {
            type: Boolean,
            default: false,
        },
        errors: {
            type: Array,
            default: [],
        },
    },
    setup(__props) {
        const focused = vue.ref(false);
        const id = `mcr-input-${Math.random() * 1000000}`;
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createElementBlock("div", _hoisted_1$v, [
                vue.createVNode(vue.unref(macrameVue3.Input), vue.mergeProps(_ctx.$attrs, {
                    id: id,
                    disabled: __props.disabled,
                    onFocus: _cache[0] || (_cache[0] = ($event) => (focused.value = true)),
                    onBlur: _cache[1] || (_cache[1] = ($event) => (focused.value = false)),
                    class: ["px-[18px] z-10 w-full transition-colors duration-200 bg-transparent focus:outline-none focus:input-focused text-indigo-900 py-2.5", {
                            'cursor-not-allowed': __props.disabled,
                            'has-errors': __props.errors.length > 0 && !__props.disabled,
                        }]
                }), null, 16 /* FULL_PROPS */, ["disabled", "class"]),
                vue.createElementVNode("div", _hoisted_2$o, [
                    _hoisted_3$g,
                    vue.createElementVNode("div", {
                        class: vue.normalizeClass(["relative h-full px-1 border-t border-b border-gray-900 input-width input-section-2", {
                                '!border-t-transparent': (_ctx.$attrs.modelValue?.length > 0 && __props.label) ||
                                    (focused.value && __props.label),
                                'border-t-gray-900': _ctx.$attrs.modelValue?.length == 0 || !_ctx.$attrs.modelValue,
                            }])
                    }, [
                        vue.createElementVNode("label", {
                            class: vue.normalizeClass(["relative inline-block text-sm transition duration-200 origin-left whitespace-nowrap will-change-auto h-fit top-1/2", {
                                    'text-ellipsis !-translate-y-[35px] !scale-100 text-indigo-900': _ctx.$attrs.modelValue?.length > 0 || focused.value,
                                    'max-w-full -translate-y-[13px] scale-[1.34] text-gray-900': _ctx.$attrs.modelValue?.length == 0 ||
                                        !_ctx.$attrs.modelValue,
                                    '!text-red-signal': (_ctx.$attrs.modelValue?.length > 0 &&
                                        __props.errors.length > 0 &&
                                        !__props.disabled) ||
                                        (focused.value && __props.errors.length > 0 && !__props.disabled),
                                }]),
                            for: id
                        }, vue.toDisplayString(__props.label), 3 /* TEXT, CLASS */)
                    ], 2 /* CLASS */),
                    _hoisted_4$d
                ])
            ]));
        };
    }
});

var css$4 = "\ninput:focus + div > .input-section-1[data-v-a4e231ec] {\n    border-color: #fead5e;\n}\ninput:focus + div > .input-section-2[data-v-a4e231ec] {\n    border-bottom-color: #fead5e;\n    border-top-color: #fead5e;\n}\ninput:focus + div > .input-section-2 > label[data-v-a4e231ec] {\n    color: #fead5e;\n}\ninput:focus + div > .input-section-3[data-v-a4e231ec] {\n    border-color: #fead5e;\n}\n.input-width[data-v-a4e231ec] {\n    flex: 0 0 auto;\n    max-width: calc(100% - 12px * 2);\n}\n.input-width-focused[data-v-a4e231ec] {\n    max-width: calc(100% * 0.75);\n}\ninput.has-errors + div > .input-section-1[data-v-a4e231ec] {\n    border-color: #f74b6d;\n}\ninput.has-errors + div > .input-section-2[data-v-a4e231ec] {\n    border-bottom-color: #f74b6d;\n    border-top-color: #f74b6d;\n}\ninput.has-errors + div > .input-section-3[data-v-a4e231ec] {\n    border-color: #f74b6d;\n}\n";
n(css$4,{});

script$B.__scopeId = "data-v-a4e231ec";
script$B.__file = "packages/admin-vue3/src/ui/Input.vue";

var script$A = /*#__PURE__*/ vue.defineComponent({
    props: {
        label: {
            type: String,
            default: null,
        },
        hint: {
            type: String,
            default: null,
        },
        disabled: {
            type: Boolean,
            default: false,
        },
        errors: {
            type: Array,
            default: [],
        },
    },
    setup(__props) {
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createBlock(vue.unref(vCalendar.DatePicker), vue.mergeProps(_ctx.$attrs, {
                class: "relative",
                "is-dark": "",
                color: "orange"
            }), {
                default: vue.withCtx(({ inputValue, inputEvents }) => [
                    vue.createVNode(script$B, vue.mergeProps({ modelValue: inputValue }, vue.toHandlers(inputEvents), {
                        errors: __props.errors,
                        label: __props.label
                    }), null, 16 /* FULL_PROPS */, ["modelValue", "errors", "label"])
                ]),
                _: 1 /* STABLE */
            }, 16 /* FULL_PROPS */));
        };
    }
});

script$A.__file = "packages/admin-vue3/src/ui/DatePicker.vue";

const _hoisted_1$u = { class: "flex items-center justify-center w-full" };
const _hoisted_2$n = { class: "relative w-full" };
const _hoisted_3$f = /*#__PURE__*/ vue.createElementVNode("svg", {
    class: "w-4 h-4 mx-2",
    fill: "none",
    viewBox: "0 0 24 24",
    stroke: "currentColor"
}, [
    /*#__PURE__*/ vue.createElementVNode("path", {
        "stroke-linecap": "round",
        "stroke-linejoin": "round",
        "stroke-width": "2",
        d: "M14 5l7 7m0 0l-7 7m7-7H3"
    })
], -1 /* HOISTED */);
const _hoisted_4$c = { class: "relative w-full" };
var script$z = /*#__PURE__*/ vue.defineComponent({
    props: {
        label: {
            type: String,
            default: null,
        },
        hint: {
            type: String,
            default: null,
        },
        disabled: {
            type: Boolean,
            default: false,
        },
        errors: {
            type: Array,
            default: [],
        },
    },
    setup(__props) {
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createBlock(vue.unref(vCalendar.DatePicker), vue.mergeProps(_ctx.$attrs, {
                columns: 2,
                "is-range": "",
                "is-dark": "",
                color: "orange",
                class: "z-10 w-full"
            }), {
                default: vue.withCtx(({ inputValue, inputEvents }) => [
                    vue.createElementVNode("div", _hoisted_1$u, [
                        vue.createElementVNode("div", _hoisted_2$n, [
                            vue.createVNode(script$B, vue.mergeProps({
                                modelValue: inputValue.start,
                                errors: __props.errors
                            }, vue.toHandlers(inputEvents.start), { label: "Start" }), null, 16 /* FULL_PROPS */, ["modelValue", "errors"])
                        ]),
                        _hoisted_3$f,
                        vue.createElementVNode("div", _hoisted_4$c, [
                            vue.createVNode(script$B, vue.mergeProps({
                                modelValue: inputValue.end,
                                errors: __props.errors
                            }, vue.toHandlers(inputEvents.end), { label: "Ende" }), null, 16 /* FULL_PROPS */, ["modelValue", "errors"])
                        ])
                    ])
                ]),
                _: 1 /* STABLE */
            }, 16 /* FULL_PROPS */));
        };
    }
});

script$z.__file = "packages/admin-vue3/src/ui/DateRange.vue";

var script$y = vue.defineComponent({
    components: { RadioGroup: vue$1.RadioGroup, RadioGroupLabel: vue$1.RadioGroupLabel, RadioGroupOption: vue$1.RadioGroupOption },
    props: {
        labelKey: {
            type: String,
            default: null,
        },
        valueKey: {
            type: String,
            default: null,
        },
        disabledKey: {
            type: String,
            default: null,
        },
        options: {
            type: Array,
            default: () => [],
        },
        modelValue: {
            type: [String, Number],
            default: null,
        },
    },
    setup(props, { attrs }) {
        const optionValue = (option) => {
            if (props.valueKey === null) {
                return option;
            }
            return option[props.valueKey];
        };
        const optionLabel = (option) => {
            if (props.labelKey === null) {
                return option;
            }
            return option[props.labelKey];
        };
        const isDisabled = (option) => {
            if (props.disabledKey === null) {
                return false;
            }
            return option[props.disabledKey] == true;
        };
        return { optionValue, optionLabel, isDisabled };
    },
});

const _hoisted_1$t = { class: "flex gap-2" };
const _hoisted_2$m = { class: "flex" };

function render$i(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_RadioGroupLabel = vue.resolveComponent("RadioGroupLabel");
  const _component_RadioGroupOption = vue.resolveComponent("RadioGroupOption");
  const _component_RadioGroup = vue.resolveComponent("RadioGroup", true);

  return (vue.openBlock(), vue.createBlock(_component_RadioGroup, {
    modelValue: _ctx.modelValue,
    "onUpdate:modelValue": _cache[0] || (_cache[0] = $event => (_ctx.$emit('update:modelValue', $event)))
  }, {
    default: vue.withCtx(() => [
      vue.createCommentVNode(" <RadioGroupLabel>Plan</RadioGroupLabel> "),
      (vue.openBlock(true), vue.createElementBlock(vue.Fragment, null, vue.renderList(_ctx.options, (option) => {
        return (vue.openBlock(), vue.createBlock(_component_RadioGroupOption, {
          as: "template",
          class: "mb-3 rounded focus:outline-none max-w-max focus:ring-4 focus:ring-orange-100",
          key: _ctx.optionValue(option),
          value: _ctx.optionValue(option),
          disabled: _ctx.isDisabled(option)
        }, {
          default: vue.withCtx(({ checked, disabled }) => [
            vue.createElementVNode("div", _hoisted_1$t, [
              vue.createElementVNode("div", _hoisted_2$m, [
                vue.createElementVNode("div", {
                  class: vue.normalizeClass(["flex items-center justify-center bg-white w-[18px] h-[18px] border rounded-lg", {
                            'border-orange': checked && !disabled,
                            'border-indigo-900': !checked && !disabled,
                            'border-gray-500': disabled,
                        }])
                }, [
                  vue.createElementVNode("div", {
                    class: vue.normalizeClass(["w-2.5 h-2.5 rounded-full", {
                                'bg-orange': checked,
                                'bg-white': !checked,
                            }])
                  }, null, 2 /* CLASS */)
                ], 2 /* CLASS */)
              ]),
              vue.createVNode(_component_RadioGroupLabel, {
                as: "p",
                class: vue.normalizeClass(["flex-1 mt-0.5 leading-none cursor-pointer", { 'text-gray-500': disabled }])
              }, {
                default: vue.withCtx(() => [
                  vue.createTextVNode(vue.toDisplayString(_ctx.optionLabel(option)), 1 /* TEXT */)
                ]),
                _: 2 /* DYNAMIC */
              }, 1032 /* PROPS, DYNAMIC_SLOTS */, ["class"])
            ])
          ]),
          _: 2 /* DYNAMIC */
        }, 1032 /* PROPS, DYNAMIC_SLOTS */, ["value", "disabled"]))
      }), 128 /* KEYED_FRAGMENT */))
    ]),
    _: 1 /* STABLE */
  }, 8 /* PROPS */, ["modelValue"]))
}

script$y.render = render$i;
script$y.__file = "packages/admin-vue3/src/ui/RadioGroup.vue";

var script$x = vue.defineComponent({
    components: { Button: script$1k },
    props: {
        table: {
            type: Object,
            required: true,
        },
    },
});

const _hoisted_1$s = { class: "flex justify-around" };
const _hoisted_2$l = { class: "flex items-stretch space-x-2" };
const _hoisted_3$e = /*#__PURE__*/vue.createElementVNode("svg", {
  class: "absolute fill-current left-1",
  xmlns: "http://www.w3.org/2000/svg",
  viewBox: "0 0 24 24",
  width: "24",
  height: "24"
}, [
  /*#__PURE__*/vue.createElementVNode("path", {
    fill: "none",
    d: "M0 0h24v24H0z"
  }),
  /*#__PURE__*/vue.createElementVNode("path", { d: "M10.828 12l4.95 4.95-1.414 1.414L8 12l6.364-6.364 1.414 1.414z" })
], -1 /* HOISTED */);
const _hoisted_4$b = /*#__PURE__*/vue.createElementVNode("svg", {
  class: "absolute fill-current right-1",
  xmlns: "http://www.w3.org/2000/svg",
  viewBox: "0 0 24 24",
  width: "24",
  height: "24"
}, [
  /*#__PURE__*/vue.createElementVNode("path", {
    fill: "none",
    d: "M0 0h24v24H0z"
  }),
  /*#__PURE__*/vue.createElementVNode("path", { d: "M10.828 12l4.95 4.95-1.414 1.414L8 12l6.364-6.364 1.414 1.414z" })
], -1 /* HOISTED */);
const _hoisted_5$8 = /*#__PURE__*/vue.createElementVNode("svg", {
  class: "fill-current",
  xmlns: "http://www.w3.org/2000/svg",
  viewBox: "0 0 24 24",
  width: "24",
  height: "24"
}, [
  /*#__PURE__*/vue.createElementVNode("path", {
    fill: "none",
    d: "M0 0h24v24H0z"
  }),
  /*#__PURE__*/vue.createElementVNode("path", { d: "M10.828 12l4.95 4.95-1.414 1.414L8 12l6.364-6.364 1.414 1.414z" })
], -1 /* HOISTED */);
const _hoisted_6$3 = { class: "flex items-center px-4 space-x-6 text-gray" };
const _hoisted_7$3 = {
  key: 0,
  class: "text-lg"
};
const _hoisted_8$3 = { class: "text-lg font-bold text-blue" };
const _hoisted_9$2 = {
  key: 5,
  class: "text-lg cursor-pointer"
};
const _hoisted_10$1 = /*#__PURE__*/vue.createElementVNode("svg", {
  class: "fill-current",
  xmlns: "http://www.w3.org/2000/svg",
  viewBox: "0 0 24 24",
  width: "24",
  height: "24"
}, [
  /*#__PURE__*/vue.createElementVNode("path", {
    fill: "none",
    d: "M0 0h24v24H0z"
  }),
  /*#__PURE__*/vue.createElementVNode("path", { d: "M13.172 12l-4.95-4.95 1.414-1.414L16 12l-6.364 6.364-1.414-1.414z" })
], -1 /* HOISTED */);
const _hoisted_11$1 = /*#__PURE__*/vue.createElementVNode("svg", {
  class: "absolute fill-current right-1",
  xmlns: "http://www.w3.org/2000/svg",
  viewBox: "0 0 24 24",
  width: "24",
  height: "24"
}, [
  /*#__PURE__*/vue.createElementVNode("path", {
    fill: "none",
    d: "M0 0h24v24H0z"
  }),
  /*#__PURE__*/vue.createElementVNode("path", { d: "M13.172 12l-4.95-4.95 1.414-1.414L16 12l-6.364 6.364-1.414-1.414z" })
], -1 /* HOISTED */);
const _hoisted_12$1 = /*#__PURE__*/vue.createElementVNode("svg", {
  class: "absolute fill-current left-1",
  xmlns: "http://www.w3.org/2000/svg",
  viewBox: "0 0 24 24",
  width: "24",
  height: "24"
}, [
  /*#__PURE__*/vue.createElementVNode("path", {
    fill: "none",
    d: "M0 0h24v24H0z"
  }),
  /*#__PURE__*/vue.createElementVNode("path", { d: "M13.172 12l-4.95-4.95 1.414-1.414L16 12l-6.364 6.364-1.414-1.414z" })
], -1 /* HOISTED */);

function render$h(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_Button = vue.resolveComponent("Button");

  return (vue.openBlock(), vue.createElementBlock("div", _hoisted_1$s, [
    vue.createElementVNode("div", _hoisted_2$l, [
      vue.createVNode(_component_Button, {
        secondary: "",
        square: "",
        class: "relative",
        onClick: _cache[0] || (_cache[0] = $event => (_ctx.table.setPage(1))),
        disabled: _ctx.table.currentPage == 1
      }, {
        default: vue.withCtx(() => [
          _hoisted_3$e,
          _hoisted_4$b
        ]),
        _: 1 /* STABLE */
      }, 8 /* PROPS */, ["disabled"]),
      vue.createVNode(_component_Button, {
        secondary: "",
        square: "",
        disabled: _ctx.table.currentPage == 1,
        onClick: _cache[1] || (_cache[1] = $event => (_ctx.table.setPage(_ctx.table.currentPage - 1)))
      }, {
        default: vue.withCtx(() => [
          _hoisted_5$8
        ]),
        _: 1 /* STABLE */
      }, 8 /* PROPS */, ["disabled"]),
      vue.createElementVNode("div", _hoisted_6$3, [
        (_ctx.table.currentPage > 2)
          ? (vue.openBlock(), vue.createElementBlock("span", _hoisted_7$3, " ... "))
          : vue.createCommentVNode("v-if", true),
        (
                        _ctx.table.currentPage == _ctx.table.getLastPage() &&
                        _ctx.table.currentPage > 2
                    )
          ? (vue.openBlock(), vue.createElementBlock("span", {
              key: 1,
              class: "text-lg cursor-pointer",
              onClick: _cache[2] || (_cache[2] = $event => (_ctx.table.setPage(_ctx.table.currentPage - 2)))
            }, vue.toDisplayString(_ctx.table.currentPage - 2), 1 /* TEXT */))
          : vue.createCommentVNode("v-if", true),
        (_ctx.table.currentPage > 1)
          ? (vue.openBlock(), vue.createElementBlock("span", {
              key: 2,
              class: "text-lg cursor-pointer",
              onClick: _cache[3] || (_cache[3] = $event => (_ctx.table.setPage(_ctx.table.currentPage - 1)))
            }, vue.toDisplayString(_ctx.table.currentPage - 1), 1 /* TEXT */))
          : vue.createCommentVNode("v-if", true),
        vue.createElementVNode("span", _hoisted_8$3, vue.toDisplayString(_ctx.table.currentPage), 1 /* TEXT */),
        (_ctx.table.currentPage < _ctx.table.getLastPage())
          ? (vue.openBlock(), vue.createElementBlock("span", {
              key: 3,
              class: "text-lg cursor-pointer",
              onClick: _cache[4] || (_cache[4] = $event => (_ctx.table.setPage(_ctx.table.currentPage + 1)))
            }, vue.toDisplayString(_ctx.table.currentPage + 1), 1 /* TEXT */))
          : vue.createCommentVNode("v-if", true),
        (_ctx.table.currentPage == 1 && _ctx.table.getLastPage() > 2)
          ? (vue.openBlock(), vue.createElementBlock("span", {
              key: 4,
              class: "text-lg cursor-pointer",
              onClick: _cache[5] || (_cache[5] = $event => (_ctx.table.setPage(_ctx.table.currentPage + 2)))
            }, vue.toDisplayString(_ctx.table.currentPage + 2), 1 /* TEXT */))
          : vue.createCommentVNode("v-if", true),
        (_ctx.table.currentPage < _ctx.table.getLastPage() - 1)
          ? (vue.openBlock(), vue.createElementBlock("span", _hoisted_9$2, " ... "))
          : vue.createCommentVNode("v-if", true)
      ]),
      vue.createVNode(_component_Button, {
        secondary: "",
        square: "",
        disabled: !(_ctx.table.currentPage < _ctx.table.getLastPage()),
        onClick: _cache[6] || (_cache[6] = $event => (_ctx.table.setPage(_ctx.table.currentPage + 1)))
      }, {
        default: vue.withCtx(() => [
          _hoisted_10$1
        ]),
        _: 1 /* STABLE */
      }, 8 /* PROPS */, ["disabled"]),
      vue.createVNode(_component_Button, {
        secondary: "",
        square: "",
        class: "relative",
        onClick: _cache[7] || (_cache[7] = $event => (_ctx.table.lastPage())),
        disabled: !(_ctx.table.currentPage < _ctx.table.getLastPage())
      }, {
        default: vue.withCtx(() => [
          _hoisted_11$1,
          _hoisted_12$1
        ]),
        _: 1 /* STABLE */
      }, 8 /* PROPS */, ["disabled"])
    ])
  ]))
}

script$x.render = render$h;
script$x.__file = "packages/admin-vue3/src/ui/Pagination.vue";

var script$w = vue.defineComponent({
    components: { BaseInput: macrameVue3.Input },
    props: {
        table: {
            type: Object,
            required: true,
        },
        placeholder: {
            type: String,
        },
    },
    setup() {
        //
    },
});

const _hoisted_1$r = { class: "flex items-center h-full max-w-sm mb-6 overflow-hidden text-gray-800 border border-gray-500 rounded focus-within:text-blue" };
const _hoisted_2$k = /*#__PURE__*/vue.createElementVNode("div", { class: "flex items-center justify-center w-10 h-10 text-gray-800 bg-gray-300" }, [
  /*#__PURE__*/vue.createElementVNode("svg", {
    xmlns: "http://www.w3.org/2000/svg",
    viewBox: "-2.5 -2.5 24 24",
    width: "16",
    height: "16",
    preserveAspectRatio: "xMinYMin",
    class: "fill-gray-800 icon__icon"
  }, [
    /*#__PURE__*/vue.createElementVNode("path", { d: "M8 14A6 6 0 1 0 8 2a6 6 0 0 0 0 12zm6.32-1.094l3.58 3.58a1 1 0 1 1-1.415 1.413l-3.58-3.58a8 8 0 1 1 1.414-1.414z" })
  ])
], -1 /* HOISTED */);

function render$g(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_BaseInput = vue.resolveComponent("BaseInput");

  return (vue.openBlock(), vue.createElementBlock("div", _hoisted_1$r, [
    _hoisted_2$k,
    vue.createVNode(_component_BaseInput, {
      modelValue: _ctx.table.search,
      "onUpdate:modelValue": _cache[0] || (_cache[0] = $event => ((_ctx.table.search) = $event)),
      modelModifiers: { debounce: true },
      class: "w-full h-full pl-6 text-gray-800 bg-transparent outline-none placeholder:text-gray-500",
      placeholder: _ctx.placeholder
    }, null, 8 /* PROPS */, ["modelValue", "placeholder"])
  ]))
}

script$w.render = render$g;
script$w.__file = "packages/admin-vue3/src/ui/Search.vue";

var script$v = vue.defineComponent({
    components: {
        Pagination: script$x,
        Search: script$w,
    },
    props: {
        table: {
            type: Object,
            required: true,
        },
        searchPlaceholder: {
            type: String,
        },
        isTable: {
            type: Boolean,
            default: true,
        },
    },
    setup({}, {}) {
        //
        return {};
    },
});

const _hoisted_1$q = { class: "inline-flex justify-end w-full pt-4 pr-6 text-gray" };

function render$f(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_Search = vue.resolveComponent("Search");
  const _component_Pagination = vue.resolveComponent("Pagination");

  return (vue.openBlock(), vue.createElementBlock("div", null, [
    vue.renderSlot(_ctx.$slots, "search", {}, () => [
      vue.createVNode(_component_Search, {
        table: _ctx.table,
        placeholder: _ctx.searchPlaceholder
      }, null, 8 /* PROPS */, ["table", "placeholder"])
    ]),
    vue.createElementVNode("div", {
      class: vue.normalizeClass(["w-full pt-9", { 'bg-white shadow rounded-md': _ctx.isTable }])
    }, [
      vue.renderSlot(_ctx.$slots, "default"),
      vue.renderSlot(_ctx.$slots, "footer", {}, () => [
        (_ctx.isTable || _ctx.table.totalItems >= _ctx.table.perPage)
          ? (vue.openBlock(), vue.createElementBlock("div", {
              key: 0,
              class: vue.normalizeClass(["w-full pt-8 pb-4", { 'border-t border-gray-300': _ctx.isTable }])
            }, [
              vue.createVNode(_component_Pagination, { table: _ctx.table }, null, 8 /* PROPS */, ["table"]),
              vue.createElementVNode("div", _hoisted_1$q, vue.toDisplayString(_ctx.table.fromItem) + "-" + vue.toDisplayString(_ctx.table.toItem) + "/" + vue.toDisplayString(_ctx.table.totalItems), 1 /* TEXT */)
            ], 2 /* CLASS */))
          : vue.createCommentVNode("v-if", true)
      ])
    ], 2 /* CLASS */),
    vue.renderSlot(_ctx.$slots, "pagination")
  ]))
}

script$v.render = render$f;
script$v.__file = "packages/admin-vue3/src/ui/Index.vue";

var script$u = /*#__PURE__*/ vue.defineComponent({
    props: {
        gray: {
            type: Boolean,
            default: false,
        },
    },
    setup(__props) {
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createElementBlock("div", {
                class: vue.normalizeClass(["flex items-center justify-center w-8 h-8 overflow-hidden rounded", {
                        'bg-white hover:bg-gray-200 text-black': !__props.gray,
                        'bg-gray-200 hover:bg-gray-500 text-black': __props.gray,
                    }])
            }, [
                vue.renderSlot(_ctx.$slots, "default")
            ], 2 /* CLASS */));
        };
    }
});

script$u.__file = "packages/admin-vue3/src/ui/InteractionButton.vue";

const _hoisted_1$p = { class: "py-1 pl-2 draggable-wrapper" };
var script$t = /*#__PURE__*/ vue.defineComponent({
    props: {
        tree: {
            required: true,
            type: Object,
        },
    },
    setup(__props) {
        return (_ctx, _cache) => {
            return (__props.tree)
                ? (vue.openBlock(), vue.createBlock(vue.unref(Draggable__default), {
                    key: 0,
                    tag: "div",
                    list: __props.tree.items,
                    handle: ".handle",
                    "item-key": "uuid"
                }, {
                    item: vue.withCtx(({ element }) => [
                        vue.createElementVNode("div", _hoisted_1$p, [
                            vue.renderSlot(_ctx.$slots, "default", {
                                item: element.value,
                                children: element.children
                            })
                        ])
                    ]),
                    _: 3 /* FORWARDED */
                }, 8 /* PROPS */, ["list"]))
                : vue.createCommentVNode("v-if", true);
        };
    }
});

script$t.__file = "packages/admin-vue3/src/ui/Tree.vue";

const _hoisted_1$o = { class: "flex items-center justify-between w-full group" };
const _hoisted_2$j = { class: "flex items-center w-8" };
var script$s = /*#__PURE__*/ vue.defineComponent({
    props: {
        item: {
            required: true,
        },
        children: {
            required: true,
        },
        isActive: {
            type: Boolean,
            default: false,
        },
        background: {
            type: Boolean,
            default: false,
        },
        outline: {
            type: Boolean,
            default: false,
        },
    },
    setup(__props) {
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createBlock(vue.unref(vue$1.Disclosure), { defaultOpen: "" }, {
                default: vue.withCtx(({ open }) => [
                    vue.createElementVNode("div", _hoisted_1$o, [
                        vue.createElementVNode("div", {
                            class: vue.normalizeClass(["flex justify-between flex-1 pl-3 pr-2 rounded", {
                                    'bg-gray-500': __props.isActive && __props.background,
                                    'border-gray border': __props.outline,
                                    'hover:bg-gray-500 hover:bg-opacity-20 bg-opacity-10': __props.background,
                                }])
                        }, [
                            vue.createElementVNode("div", {
                                class: vue.normalizeClass(["flex items-center pr-3 cursor-move handle", {
                                        'text-gray-100': __props.background,
                                    }])
                            }, [
                                vue.createVNode(vue.unref(script$1e), {
                                    class: vue.normalizeClass(["w-2.5 h-2.5", {
                                            'fill-gray': __props.background,
                                        }])
                                }, null, 8 /* PROPS */, ["class"])
                            ], 2 /* CLASS */),
                            vue.createElementVNode("div", {
                                class: vue.normalizeClass(["flex items-center justify-between flex-1", {
                                        'text-gray-100': __props.background,
                                    }])
                            }, [
                                vue.renderSlot(_ctx.$slots, "default")
                            ], 2 /* CLASS */)
                        ], 2 /* CLASS */),
                        vue.createElementVNode("div", _hoisted_2$j, [
                            (__props.children?.items.length > 0)
                                ? (vue.openBlock(), vue.createBlock(vue.unref(vue$1.DisclosureButton), {
                                    key: 0,
                                    class: vue.normalizeClass(["p-1 hover:bg-black rounded-xs", {
                                            'text-gray-100': __props.background,
                                            'rotate-180': !open,
                                        }])
                                }, {
                                    default: vue.withCtx(() => [
                                        vue.createVNode(vue.unref(script$1a), { class: "w-3 h-3" })
                                    ]),
                                    _: 2 /* DYNAMIC */
                                }, 1032 /* PROPS, DYNAMIC_SLOTS */, ["class"]))
                                : vue.createCommentVNode("v-if", true)
                        ])
                    ]),
                    vue.createVNode(vue.unref(vue$1.DisclosurePanel), { class: "pl-2" }, {
                        default: vue.withCtx(() => [
                            vue.renderSlot(_ctx.$slots, "disclosure")
                        ]),
                        _: 3 /* FORWARDED */
                    })
                ]),
                _: 3 /* FORWARDED */
            }));
        };
    }
});

script$s.__file = "packages/admin-vue3/src/ui/TreeItem.vue";

const _withScopeId = n => (vue.pushScopeId("data-v-51936cec"), n = n(), vue.popScopeId(), n);
const _hoisted_1$n = { class: "relative" };
const _hoisted_2$i = { class: "absolute top-0 left-0 right-0 flex w-full h-full max-w-full pointer-events-none" };
const _hoisted_3$d = /*#__PURE__*/ _withScopeId(() => /*#__PURE__*/ vue.createElementVNode("div", { class: "border-l input-section-1 border-t border-b border-gray-900 w-[16px] h-full rounded-l-[8px]" }, null, -1 /* HOISTED */));
const _hoisted_4$a = /*#__PURE__*/ _withScopeId(() => /*#__PURE__*/ vue.createElementVNode("div", { class: "border-r border-t input-section-3 border-b focus:border-orange border-gray-900 flex-grow rounded-r-[8px] h-full" }, null, -1 /* HOISTED */));
const _hoisted_5$7 = {
    key: 0,
    class: "absolute inline-block -translate-y-1/2 left-5"
};
const _hoisted_6$2 = { class: "absolute inline-block -translate-y-1/2 mcr-select-arrow right-5" };
const _hoisted_7$2 = /*#__PURE__*/ _withScopeId(() => /*#__PURE__*/ vue.createElementVNode("path", { d: "M7.071 5.314l4.95-4.95a1 1 0 1 1 1.414 1.414L7.778 7.435a1 1 0 0 1-1.414 0L.707 1.778A1 1 0 1 1 2.121.364l4.95 4.95z" }, null, -1 /* HOISTED */));
const _hoisted_8$2 = [
    _hoisted_7$2
];
var script$r = /*#__PURE__*/ vue.defineComponent({
    props: {
        modelValue: {},
        options: {
            type: Array,
            required: true,
        },
        label: {
            type: String,
            default: null,
        },
        labelKey: {
            type: String,
            default: 'label',
        },
        valueKey: {
            type: String,
            default: 'value',
        },
        errors: {
            type: [Array, String],
            default: null,
        },
        placeholder: {
            type: String,
            default: 'Wählen Sie eine Option',
        },
        disabled: {
            type: Boolean,
            default: false,
        },
    },
    emits: ['update:modelValue', 'change'],
    setup(__props, { emit }) {
        const props = __props;
        const getItemValue = (item) => {
            if (props.valueKey) {
                return item[props.valueKey];
            }
            return item;
        };
        const getItemLabel = (item) => {
            if (props.labelKey) {
                return item[props.labelKey];
            }
            return item;
        };
        const itemLabel = vue.computed(() => {
            if (!props.modelValue) {
                return props.placeholder;
            }
            if (props.valueKey) {
                let selectedOption = props.options.find((option) => option[props.valueKey] == props.modelValue);
                return selectedOption
                    ? selectedOption[props.labelKey]
                    : props.modelValue;
            }
            return props.modelValue;
        });
        const selectedItem = vue.ref(props.modelValue);
        vue.watch(selectedItem, () => {
            emit('update:modelValue', selectedItem.value);
            emit('change');
        });
        return (_ctx, _cache) => {
            return (vue.unref(itemLabel))
                ? (vue.openBlock(), vue.createBlock(vue.unref(vue$1.Listbox), {
                    key: 0,
                    disabled: __props.disabled,
                    modelValue: selectedItem.value,
                    "onUpdate:modelValue": _cache[0] || (_cache[0] = ($event) => ((selectedItem).value = $event))
                }, {
                    default: vue.withCtx(({ open }) => [
                        vue.createElementVNode("div", _hoisted_1$n, [
                            vue.createVNode(vue.unref(vue$1.ListboxButton), {
                                class: vue.normalizeClass(["px-[18px] mcr-select-button z-10 w-full transition-colors duration-200 bg-transparent focus:outline-none focus:input-focused text-indigo-900 py-[22px]", {
                                        'cursor-not-allowed': __props.disabled,
                                        'has-errors': __props.errors?.length > 0 && !__props.disabled,
                                    }])
                            }, {
                                default: vue.withCtx(() => [
                                    vue.createElementVNode("div", _hoisted_2$i, [
                                        _hoisted_3$d,
                                        vue.createElementVNode("div", {
                                            class: vue.normalizeClass(["relative h-full px-1 border-t border-b border-gray-900 input-width input-section-2", {
                                                    '!border-t-transparent': selectedItem.value,
                                                    'border-t-gray-900': !selectedItem.value,
                                                }])
                                        }, [
                                            vue.createElementVNode("label", {
                                                class: vue.normalizeClass(["relative inline-block text-sm transition duration-200 origin-left whitespace-nowrap will-change-auto h-fit top-1/2", {
                                                        'text-ellipsis !-translate-y-[35px] !scale-100 text-indigo-900': selectedItem.value,
                                                        'max-w-full -translate-y-[13px] scale-[1.34] text-gray-500': !selectedItem.value,
                                                        '!text-red-signal': selectedItem.value &&
                                                            __props.errors?.length > 0 &&
                                                            !__props.disabled,
                                                    }]),
                                                ref: "inputLabel"
                                            }, vue.toDisplayString(__props.label), 3 /* TEXT, CLASS */)
                                        ], 2 /* CLASS */),
                                        _hoisted_4$a
                                    ]),
                                    (selectedItem.value)
                                        ? (vue.openBlock(), vue.createElementBlock("span", _hoisted_5$7, vue.toDisplayString(vue.unref(itemLabel)), 1 /* TEXT */))
                                        : vue.createCommentVNode("v-if", true),
                                    vue.createElementVNode("span", _hoisted_6$2, [
                                        (vue.openBlock(), vue.createElementBlock("svg", {
                                            class: vue.normalizeClass(["transition-transform duration-200", { 'rotate-180': open }]),
                                            xmlns: "http://www.w3.org/2000/svg",
                                            viewBox: "-5 -8 24 24",
                                            width: "16",
                                            fill: "currentColor"
                                        }, _hoisted_8$2, 2 /* CLASS */))
                                    ])
                                ]),
                                _: 2 /* DYNAMIC */
                            }, 1032 /* PROPS, DYNAMIC_SLOTS */, ["class"]),
                            vue.createVNode(vue.Transition, {
                                "leave-active-class": "transition duration-200 ease-in",
                                "leave-from-class": "opacity-100",
                                "leave-to-class": "opacity-0"
                            }, {
                                default: vue.withCtx(() => [
                                    vue.createVNode(vue.unref(vue$1.ListboxOptions), { class: "absolute z-40 w-full mt-2 py-2.5 overflow-auto rounded-[8px] bg-white shadow max-h-48 focus:outline-none" }, {
                                        default: vue.withCtx(() => [
                                            (vue.openBlock(true), vue.createElementBlock(vue.Fragment, null, vue.renderList(__props.options, (item, key) => {
                                                return (vue.openBlock(), vue.createBlock(vue.unref(vue$1.ListboxOption), {
                                                    value: getItemValue(item),
                                                    as: "template",
                                                    key: key
                                                }, {
                                                    default: vue.withCtx(({ active, selected }) => [
                                                        vue.createElementVNode("li", {
                                                            class: vue.normalizeClass([
                                                                selected ? 'bg-gray-100' : 'hover:bg-gray-100',
                                                                active ? 'bg-gray-100' : 'hover:bg-gray-100',
                                                                'cursor-pointer select-none relative',
                                                            ])
                                                        }, [
                                                            vue.createElementVNode("span", {
                                                                class: vue.normalizeClass([
                                                                    selected
                                                                        ? 'text-indigo-900'
                                                                        : 'text-gray-500',
                                                                    'block truncate py-[5px] px-4',
                                                                ])
                                                            }, vue.toDisplayString(getItemLabel(item)), 3 /* TEXT, CLASS */)
                                                        ], 2 /* CLASS */)
                                                    ]),
                                                    _: 2 /* DYNAMIC */
                                                }, 1032 /* PROPS, DYNAMIC_SLOTS */, ["value"]));
                                            }), 128 /* KEYED_FRAGMENT */))
                                        ]),
                                        _: 1 /* STABLE */
                                    })
                                ]),
                                _: 1 /* STABLE */
                            })
                        ])
                    ]),
                    _: 1 /* STABLE */
                }, 8 /* PROPS */, ["disabled", "modelValue"]))
                : vue.createCommentVNode("v-if", true);
        };
    }
});

var css$3 = "\n.mcr-select-button:focus > div > .input-section-1[data-v-51936cec] {\n    border-color: #fead5e;\n}\n.mcr-select-button:focus > div > .input-section-2[data-v-51936cec] {\n    border-bottom-color: #fead5e;\n    border-top-color: #fead5e;\n}\n.mcr-select-button:focus > div > .input-section-2 > label[data-v-51936cec] {\n    color: #fead5e;\n}\n.mcr-select-button:focus > div > .input-section-3[data-v-51936cec] {\n    border-color: #fead5e;\n}\n.mcr-select-button:focus .mcr-select-arrow[data-v-51936cec] {\n    color: #fead5e;\n}\n.input-width[data-v-51936cec] {\n    flex: 0 0 auto;\n    max-width: calc(100% - 12px * 2);\n}\n.input-width-focused[data-v-51936cec] {\n    max-width: calc(100% * 0.75);\n}\n.mcr-select-button.has-errors .mcr-select-arrow[data-v-51936cec] {\n    color: #f74b6d;\n}\n.mcr-select-button.has-errors > div > .input-section-1[data-v-51936cec] {\n    border-color: #f74b6d;\n}\n.mcr-select-button.has-errors > div > .input-section-2[data-v-51936cec] {\n    border-bottom-color: #f74b6d;\n    border-top-color: #f74b6d;\n    color: #f74b6d;\n}\n.mcr-select-button.has-errors > div > .input-section-3[data-v-51936cec] {\n    border-color: #f74b6d;\n}\n";
n(css$3,{});

script$r.__scopeId = "data-v-51936cec";
script$r.__file = "packages/admin-vue3/src/ui/Select.vue";

const _hoisted_1$m = /*#__PURE__*/ vue.createElementVNode("div", { class: "w-full h-full bg-white rounded-sm" }, null, -1 /* HOISTED */);
const _hoisted_2$h = [
    _hoisted_1$m
];
const _hoisted_3$c = { class: "relative z-10 flex items-center" };
const _hoisted_4$9 = { class: "text-lg font-medium" };
const _hoisted_5$6 = { class: "z-10 flex items-center space-x-2" };
const _hoisted_6$1 = /*#__PURE__*/ vue.createElementVNode("span", null, "Delete", -1 /* HOISTED */);
const _hoisted_7$1 = {
    key: 0,
    class: "flex"
};
const _hoisted_8$1 = /*#__PURE__*/ vue.createElementVNode("div", { class: "flex justify-center w-8 mr-3" }, [
    /*#__PURE__*/ vue.createElementVNode("div", { class: "w-[1px] h-full border-r border-gray-300" })
], -1 /* HOISTED */);
const _hoisted_9$1 = { class: "flex-1 mt-3 mb-6" };
var script$q = /*#__PURE__*/ vue.defineComponent({
    props: {
        title: {
            type: String,
            default: null,
        },
    },
    emits: ['destroy'],
    setup(__props, { emit }) {
        const collapsed = vue.ref(false);
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createElementBlock("section", null, [
                vue.createElementVNode("div", {
                    class: vue.normalizeClass(["relative flex justify-between", { 'mb-3': collapsed.value }])
                }, [
                    vue.createElementVNode("div", {
                        class: vue.normalizeClass(["absolute w-[0%] h-full ml-2 transition-all duration-300 pl-11", {
                                '!w-full': collapsed.value,
                            }])
                    }, _hoisted_2$h, 2 /* CLASS */),
                    vue.createElementVNode("div", _hoisted_3$c, [
                        vue.createVNode(script$u, { class: "cursor-move handle mr-3" }, {
                            default: vue.withCtx(() => [
                                vue.createVNode(script$1e, { class: "w-2.5 h-2.5 fill-gray-700" })
                            ]),
                            _: 1 /* STABLE */
                        }),
                        vue.createElementVNode("div", {
                            onClick: _cache[0] || (_cache[0] = ($event) => (collapsed.value = !collapsed.value)),
                            class: "cursor-pointer"
                        }, [
                            vue.renderSlot(_ctx.$slots, "title", {}, () => [
                                vue.createElementVNode("span", _hoisted_4$9, vue.toDisplayString(__props.title), 1 /* TEXT */)
                            ])
                        ])
                    ]),
                    vue.createElementVNode("div", _hoisted_5$6, [
                        vue.createVNode(script$S, { placement: "left" }, {
                            button: vue.withCtx(() => [
                                vue.createVNode(script$u, {
                                    class: "cursor-pointer",
                                    gray: ""
                                }, {
                                    default: vue.withCtx(() => [
                                        vue.createVNode(script$1c, { class: "w-4 h-4" })
                                    ]),
                                    _: 1 /* STABLE */
                                })
                            ]),
                            default: vue.withCtx(() => [
                                vue.createVNode(script$Q, {
                                    class: "hover:bg-red-signal text-red-signal",
                                    onClick: _cache[1] || (_cache[1] = ($event) => (emit('destroy')))
                                }, {
                                    icon: vue.withCtx(() => [
                                        vue.createVNode(script$1d, { class: "origin-left scale-75" })
                                    ]),
                                    default: vue.withCtx(() => [
                                        _hoisted_6$1
                                    ]),
                                    _: 1 /* STABLE */
                                })
                            ]),
                            _: 1 /* STABLE */
                        }),
                        vue.createVNode(script$u, {
                            class: "cursor-pointer",
                            gray: "",
                            onClick: _cache[2] || (_cache[2] = ($event) => (collapsed.value = !collapsed.value))
                        }, {
                            default: vue.withCtx(() => [
                                vue.createVNode(script$1a, {
                                    class: vue.normalizeClass(["w-4 h-4", {
                                            ' rotate-180': collapsed.value,
                                        }])
                                }, null, 8 /* PROPS */, ["class"])
                            ]),
                            _: 1 /* STABLE */
                        })
                    ])
                ], 2 /* CLASS */),
                (!collapsed.value)
                    ? (vue.openBlock(), vue.createElementBlock("div", _hoisted_7$1, [
                        _hoisted_8$1,
                        vue.createElementVNode("div", _hoisted_9$1, [
                            vue.renderSlot(_ctx.$slots, "default")
                        ])
                    ]))
                    : vue.createCommentVNode("v-if", true)
            ]));
        };
    }
});

script$q.__file = "packages/admin-vue3/src/ui/Section.vue";

const _hoisted_1$l = {
    key: 0,
    class: "absolute top-0 flex items-center justify-center w-full h-full text-gray"
};
const _hoisted_2$g = /*#__PURE__*/ vue.createTextVNode(" Drag your content here ");
var script$p = /*#__PURE__*/ vue.defineComponent({
    setup(__props) {
        const attrs = vue.useAttrs();
        const hasChildren = vue.computed(() => {
            return Object.keys(attrs.modelValue).length > 0;
        });
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createElementBlock("div", {
                class: vue.normalizeClass(["min-h-[20px] space-y-2 rounded relative", {
                        'outline-dashed outline-3 outline-gray': !vue.unref(hasChildren),
                    }]),
                style: { "min-height": "calc(100vh - 150px)" }
            }, [
                (!vue.unref(hasChildren))
                    ? (vue.openBlock(), vue.createElementBlock("div", _hoisted_1$l, [
                        vue.renderSlot(_ctx.$slots, "drag-text", {}, () => [
                            _hoisted_2$g
                        ])
                    ]))
                    : vue.createCommentVNode("v-if", true),
                vue.createVNode(vue.unref(macrameVue3.Sections), vue.mergeProps(_ctx.$attrs, { style: { "min-height": "calc(100vh - 150px)" } }), null, 16 /* FULL_PROPS */)
            ], 2 /* CLASS */));
        };
    }
});

script$p.__file = "packages/admin-vue3/src/ui/Sections.vue";

var script$o = vue.defineComponent({
    components: {
        TransitionRoot: vue$1.TransitionRoot,
        TransitionChild: vue$1.TransitionChild,
        Dialog: vue$1.Dialog,
        DialogOverlay: vue$1.DialogOverlay,
        DialogTitle: vue$1.DialogTitle,
    },
    props: {
        open: {
            type: Boolean,
            required: true,
        },
    },
});

const _hoisted_1$k = { class: "fixed top-0 right-0 z-10 w-64 h-full mt-6 bg-gray-800 border-l border-gray-300 shadow pt-14" };
const _hoisted_2$f = { class: "min-h-screen text-center" };
const _hoisted_3$b = { class: "inline-block w-full max-w-md overflow-y-scroll text-left transition-all transform" };
const _hoisted_4$8 = /*#__PURE__*/vue.createElementVNode("svg", {
  xmlns: "http://www.w3.org/2000/svg",
  viewBox: "0 0 24 24",
  width: "24",
  height: "24"
}, [
  /*#__PURE__*/vue.createElementVNode("path", {
    fill: "none",
    d: "M0 0h24v24H0z"
  }),
  /*#__PURE__*/vue.createElementVNode("path", { d: "M7.828 11H20v2H7.828l5.364 5.364-1.414 1.414L4 12l7.778-7.778 1.414 1.414z" })
], -1 /* HOISTED */);
const _hoisted_5$5 = [
  _hoisted_4$8
];

function render$e(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_DialogOverlay = vue.resolveComponent("DialogOverlay");
  const _component_TransitionChild = vue.resolveComponent("TransitionChild");
  const _component_Dialog = vue.resolveComponent("Dialog");
  const _component_TransitionRoot = vue.resolveComponent("TransitionRoot");

  return (vue.openBlock(), vue.createBlock(_component_TransitionRoot, {
    show: _ctx.open,
    as: "template",
    enter: "transition-all duration-75",
    "enter-to": "opacity-100",
    leave: "transition-all duration-150",
    "enter-from": "transform translate-x-full",
    "leave-from": "transformtranslate-x-full",
    "leave-to": "transform translate-x-full"
  }, {
    default: vue.withCtx(() => [
      vue.createVNode(_component_Dialog, vue.mergeProps({ as: "div" }, _ctx.$attrs, { open: _ctx.open }), {
        default: vue.withCtx(() => [
          vue.createElementVNode("div", _hoisted_1$k, [
            vue.createElementVNode("aside", _hoisted_2$f, [
              vue.createVNode(_component_TransitionChild, {
                as: "template",
                enter: "duration-300 ease-out",
                "enter-from": "opacity-0",
                "enter-to": "opacity-100",
                leave: "duration-200 ease-in",
                "leave-from": "opacity-100",
                "leave-to": "opacity-0"
              }, {
                default: vue.withCtx(() => [
                  vue.createVNode(_component_DialogOverlay, { class: "fixed inset-0" })
                ]),
                _: 1 /* STABLE */
              }),
              vue.createVNode(_component_TransitionChild, {
                as: "template",
                enter: "duration-300 ease-out",
                "enter-from": "opacity-0 scale-95",
                "enter-to": "opacity-100 scale-100",
                leave: "duration-200 ease-in",
                "leave-from": "opacity-100 scale-100",
                "leave-to": "opacity-0 scale-95"
              }, {
                default: vue.withCtx(() => [
                  vue.createElementVNode("div", _hoisted_3$b, [
                    vue.createElementVNode("button", {
                      onClick: _cache[0] || (_cache[0] = $event => (_ctx.$emit('close', false)))
                    }, _hoisted_5$5),
                    vue.renderSlot(_ctx.$slots, "default")
                  ])
                ]),
                _: 3 /* FORWARDED */
              })
            ])
          ])
        ]),
        _: 3 /* FORWARDED */
      }, 16 /* FULL_PROPS */, ["open"])
    ]),
    _: 3 /* FORWARDED */
  }, 8 /* PROPS */, ["show"]))
}

script$o.render = render$e;
script$o.__file = "packages/admin-vue3/src/ui/Sidebar.vue";

var script$n = /*#__PURE__*/ vue.defineComponent({
    props: {
        title: {
            type: String,
            required: true,
        },
        href: {
            type: String,
        },
        hideTitle: {
            type: Boolean,
            default: false,
        },
        secondary: {
            type: Boolean,
            default: false,
        },
        active: {
            type: Boolean,
            default: undefined,
        },
    },
    setup(__props) {
        const props = __props;
        const isActive = vue.computed(() => {
            if (props.active !== undefined) {
                return props.active;
            }
            if (props.href?.split('/').length ==
                window.location.pathname.split('/').length) {
                return window.location.pathname == props.href;
            }
            if (props.href?.split('/').length > 2) {
                return window.location.pathname.includes(props.href);
            }
            return window.location.pathname == props.href;
        });
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createBlock(vue.unref(inertiaVue3.Link), {
                href: __props.href,
                class: vue.normalizeClass([{
                        'bg-black bg-opacity-75 hover:bg-opacity-100 hover:text-orange': vue.unref(isActive) && !__props.secondary,
                        'hover:bg-gray-100 hover:bg-opacity-10': !vue.unref(isActive) && !__props.secondary,
                        'hover:bg-gray-50 hover:bg-opacity-20 items-center h-[36px] flex-auto': __props.secondary,
                        'h-[44px]': !__props.secondary,
                        'bg-gray-50 bg-opacity-10': vue.unref(isActive) && __props.secondary,
                    }, "flex items-center text-base font-light rounded group"])
            }, {
                default: vue.withCtx(() => [
                    (_ctx.$slots.icon)
                        ? (vue.openBlock(), vue.createElementBlock("div", {
                            key: 0,
                            class: vue.normalizeClass(["w-[44px] min-w-[44px] h-[44px] rounded flex items-center justify-center", {
                                    ' text-orange': vue.unref(isActive) && !__props.secondary,
                                    ' text-gray-100': !vue.unref(isActive),
                                }])
                        }, [
                            vue.renderSlot(_ctx.$slots, "icon")
                        ], 2 /* CLASS */))
                        : vue.createCommentVNode("v-if", true),
                    (!__props.hideTitle)
                        ? (vue.openBlock(), vue.createElementBlock("div", {
                            key: 1,
                            class: vue.normalizeClass(["flex-1 pl-3 tracking-wider text-gray-100", {
                                    'group-hover:text-orange': vue.unref(isActive) && !__props.secondary,
                                }])
                        }, [
                            vue.renderSlot(_ctx.$slots, "default", {}, () => [
                                vue.createTextVNode(vue.toDisplayString(__props.title), 1 /* TEXT */)
                            ])
                        ], 2 /* CLASS */))
                        : vue.createCommentVNode("v-if", true)
                ]),
                _: 3 /* FORWARDED */
            }, 8 /* PROPS */, ["href", "class"]));
        };
    }
});

script$n.__file = "packages/admin-vue3/src/ui/SidebarLink.vue";

const _hoisted_1$j = { class: "p-4 space-y-2" };
const _hoisted_2$e = { class: "inline-block" };
const _hoisted_3$a = /*#__PURE__*/ vue.createElementVNode("path", { d: "M7.071 5.314l4.95-4.95a1 1 0 1 1 1.414 1.414L7.778 7.435a1 1 0 0 1-1.414 0L.707 1.778A1 1 0 1 1 2.121.364l4.95 4.95z" }, null, -1 /* HOISTED */);
const _hoisted_4$7 = [
    _hoisted_3$a
];
var script$m = /*#__PURE__*/ vue.defineComponent({
    props: {
        title: {
            type: String,
            required: false,
        },
        expanded: {
            type: Boolean,
            default: false,
        },
        expandable: {
            type: Boolean,
            default: false,
        },
    },
    setup(__props) {
        const props = __props;
        const isExpanded = vue.computed(() => !props.expandable || props.expanded);
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createBlock(vue.resolveDynamicComponent(__props.expandable ? vue.unref(vue$1.Disclosure) : 'div'), { defaultOpen: "" }, {
                default: vue.withCtx(() => [
                    vue.createElementVNode("section", _hoisted_1$j, [
                        (__props.title)
                            ? (vue.openBlock(), vue.createBlock(vue.resolveDynamicComponent(__props.expandable ? vue.unref(vue$1.DisclosureButton) : 'div'), {
                                key: 0,
                                class: vue.normalizeClass(["flex items-center justify-between w-full mb-3 text-sm tracking-widest uppercase transition-opacity text-gray", {
                                        'opacity-100': vue.unref(isExpanded),
                                        'opacity-0': !vue.unref(isExpanded),
                                    }])
                            }, {
                                default: vue.withCtx((slot) => [
                                    vue.createElementVNode("span", _hoisted_2$e, vue.toDisplayString(__props.title), 1 /* TEXT */),
                                    (__props.expandable)
                                        ? (vue.openBlock(), vue.createElementBlock("svg", {
                                            key: 0,
                                            xmlns: "http://www.w3.org/2000/svg",
                                            viewBox: "-5 -8 24 24",
                                            width: "24",
                                            class: vue.normalizeClass(["w-3 h-3 fill-gray-800", { 'rotate-180': !slot?.open }])
                                        }, _hoisted_4$7, 2 /* CLASS */))
                                        : vue.createCommentVNode("v-if", true)
                                ]),
                                _: 1 /* STABLE */
                            }, 8 /* PROPS */, ["class"]))
                            : vue.createCommentVNode("v-if", true),
                        (vue.openBlock(), vue.createBlock(vue.resolveDynamicComponent(__props.expandable ? vue.unref(vue$1.DisclosurePanel) : 'div'), { class: "flex flex-col space-y-2" }, {
                            default: vue.withCtx(() => [
                                vue.renderSlot(_ctx.$slots, "default")
                            ]),
                            _: 3 /* FORWARDED */
                        }))
                    ])
                ]),
                _: 3 /* FORWARDED */
            }));
        };
    }
});

script$m.__file = "packages/admin-vue3/src/ui/SidebarSection.vue";

var script$l = /*#__PURE__*/ vue.defineComponent({
    props: {
        expanded: {
            type: Boolean,
            requried: true,
        },
        modelValue: {
            type: Boolean,
            required: true,
        },
    },
    emits: ['update:modelValue'],
    setup(__props, { emit }) {
        const props = __props;
        const toggle = () => {
            emit('update:modelValue', !props.modelValue);
            localStorage.setItem('sideBarLocked', !props.modelValue);
        };
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createBlock(script$n, {
                expanded: __props.expanded,
                hideTitle: !__props.expanded,
                class: "mt-auto",
                onClick: toggle
            }, {
                icon: vue.withCtx(() => [
                    (__props.modelValue)
                        ? (vue.openBlock(), vue.createBlock(vue.unref(script$15), {
                            key: 0,
                            class: "w-4 h-4"
                        }))
                        : vue.createCommentVNode("v-if", true),
                    (!__props.modelValue)
                        ? (vue.openBlock(), vue.createBlock(vue.unref(script$14), {
                            key: 1,
                            class: "w-4 h-4"
                        }))
                        : vue.createCommentVNode("v-if", true)
                ]),
                default: vue.withCtx(() => [
                    vue.createTextVNode(" " + vue.toDisplayString(__props.modelValue ? 'Unlock' : 'Lock') + " Sidebar ", 1 /* TEXT */)
                ]),
                _: 1 /* STABLE */
            }, 8 /* PROPS */, ["expanded", "hideTitle"]));
        };
    }
});

script$l.__file = "packages/admin-vue3/src/ui/SidebarPrimary/components/LockSidebar.vue";

const _hoisted_1$i = { class: "flex items-center justify-between h-[80px] px-4 py-7" };
const _hoisted_2$d = { class: "relative flex items-center w-full h-10 overflow-hidden" };
const _hoisted_3$9 = { class: "w-[154px]" };
const _hoisted_4$6 = { class: "flex-1 flex flex-col" };
const _hoisted_5$4 = { class: "p-4 space-y-2" };
var script$k = /*#__PURE__*/ vue.defineComponent({
    props: {
        locked: {
            type: Boolean,
            default: false,
        },
    },
    setup(__props) {
        const props = __props;
        const expanded = vue.ref(false);
        const locked = vue.ref(props.locked);
        const showSidebar = vue.computed(() => {
            return expanded.value || locked.value;
        });
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createElementBlock("div", {
                class: vue.normalizeClass(["flex flex-col justify-between h-screen transition-all bg-gray-900 border-r border-gray-700", {
                        'w-[77px]': !vue.unref(showSidebar),
                        'w-[250px] show-sidebar': vue.unref(showSidebar),
                    }]),
                onMouseover: _cache[1] || (_cache[1] = ($event) => (expanded.value = true)),
                onMouseleave: _cache[2] || (_cache[2] = ($event) => (expanded.value = false))
            }, [
                vue.createElementVNode("header", _hoisted_1$i, [
                    vue.createElementVNode("div", _hoisted_2$d, [
                        vue.createVNode(vue.unref(inertiaVue3.Link), { href: "/admin" }, {
                            default: vue.withCtx(() => [
                                vue.createElementVNode("div", _hoisted_3$9, [
                                    vue.renderSlot(_ctx.$slots, "logo")
                                ])
                            ]),
                            _: 3 /* FORWARDED */
                        })
                    ])
                ]),
                vue.createElementVNode("nav", _hoisted_4$6, [
                    vue.renderSlot(_ctx.$slots, "default", { expanded: vue.unref(showSidebar) })
                ]),
                vue.renderSlot(_ctx.$slots, "footer", {}, () => [
                    vue.createElementVNode("footer", _hoisted_5$4, [
                        vue.createVNode(script$l, {
                            modelValue: locked.value,
                            "onUpdate:modelValue": _cache[0] || (_cache[0] = ($event) => ((locked).value = $event)),
                            expanded: vue.unref(showSidebar)
                        }, null, 8 /* PROPS */, ["modelValue", "expanded"])
                    ])
                ])
            ], 34 /* CLASS, HYDRATE_EVENTS */));
        };
    }
});

script$k.__file = "packages/admin-vue3/src/ui/SidebarPrimary/SidebarPrimary.vue";

const _hoisted_1$h = { class: "flex flex-col justify-between h-screen bg-gray-800 w-[320px] border-r border-gray-700" };
const _hoisted_2$c = { class: "flex items-center justify-between h-[80px] px-5 text-gray-100" };
const _hoisted_3$8 = { class: "flex-1 max-h-[calc(100vh - 80px)] overflow-y-auto" };

function render$d(_ctx, _cache) {
  return (vue.openBlock(), vue.createElementBlock("div", _hoisted_1$h, [
    vue.createElementVNode("header", _hoisted_2$c, [
      vue.renderSlot(_ctx.$slots, "header")
    ]),
    vue.createElementVNode("nav", _hoisted_3$8, [
      vue.renderSlot(_ctx.$slots, "default")
    ])
  ]))
}

const script$j = {};


script$j.render = render$d;
script$j.__file = "packages/admin-vue3/src/ui/SidebarSecondary.vue";

const _hoisted_1$g = { class: "inline-block text-xl font-medium" };
var script$i = /*#__PURE__*/ vue.defineComponent({
    props: {
        title: {
            type: String,
            required: true,
        },
    },
    setup(__props) {
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createBlock(script$1j, null, {
                default: vue.withCtx(() => [
                    vue.createElementVNode("span", _hoisted_1$g, vue.toDisplayString(__props.title), 1 /* TEXT */),
                    vue.renderSlot(_ctx.$slots, "default")
                ]),
                _: 3 /* FORWARDED */
            }));
        };
    }
});

script$i.__file = "packages/admin-vue3/src/ui/SidebarSecondaryHeader.vue";

const _hoisted_1$f = { class: "flex flex-col gap-1 p-2 border-b border-gray-700 text-gray-100" };

function render$c(_ctx, _cache) {
  return (vue.openBlock(), vue.createElementBlock("div", _hoisted_1$f, [
    vue.renderSlot(_ctx.$slots, "default")
  ]))
}

const script$h = {};


script$h.render = render$c;
script$h.__file = "packages/admin-vue3/src/ui/SidebarSecondarySection.vue";

const _hoisted_1$e = { key: 0 };
const _hoisted_2$b = { key: 1 };
var script$g = /*#__PURE__*/ vue.defineComponent({
    props: {
        table: {
            type: Object,
            required: false,
        },
        sortBy: {
            type: String,
            required: false,
        },
    },
    setup(__props) {
        const props = __props;
        const isSortable = vue.computed(() => !!props.sortBy && !!props.table);
        const applySort = () => {
            if (!isSortable) {
                return;
            }
            if (!props.table.isSortedBy(props.sortBy)) {
                console.log('Add new (asc)');
                props.table.addSortBy(props.sortBy);
            }
            else if (props.table.isSortedBy(props.sortBy, 'asc')) {
                console.log('Change new (desc)');
                props.table.addSortBy(props.sortBy, 'desc');
            }
            else {
                console.log('Remove');
                props.table.removeSortBy(props.sortBy);
            }
        };
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createElementBlock("th", {
                class: vue.normalizeClass(["pb-2 pl-6 font-light bg-white border-b text-gray border-gray slim", {
                        'cursor-pointer': vue.unref(isSortable),
                    }]),
                onClick: _cache[0] || (_cache[0] = ($event) => (applySort()))
            }, [
                vue.renderSlot(_ctx.$slots, "default"),
                (vue.unref(isSortable))
                    ? (vue.openBlock(), vue.createElementBlock(vue.Fragment, { key: 0 }, [
                        (__props.table.isSortedBy(__props.sortBy, 'desc'))
                            ? (vue.openBlock(), vue.createElementBlock("span", _hoisted_1$e, " DESC "))
                            : vue.createCommentVNode("v-if", true),
                        (__props.table.isSortedBy(__props.sortBy, 'asc'))
                            ? (vue.openBlock(), vue.createElementBlock("span", _hoisted_2$b, " ASC "))
                            : vue.createCommentVNode("v-if", true)
                    ], 64 /* STABLE_FRAGMENT */))
                    : vue.createCommentVNode("v-if", true)
            ], 2 /* CLASS */));
        };
    }
});

script$g.__file = "packages/admin-vue3/src/ui/Th.vue";

var script$f = vue.defineComponent({
    props: {
        slim: {
            type: Boolean,
            default: false,
        },
    },
});

function render$b(_ctx, _cache, $props, $setup, $data, $options) {
  return (vue.openBlock(), vue.createElementBlock("td", {
    class: vue.normalizeClass(["py-5 pl-6 pr-6", { slim: _ctx.slim }])
  }, [
    vue.renderSlot(_ctx.$slots, "default")
  ], 2 /* CLASS */))
}

script$f.render = render$b;
script$f.__file = "packages/admin-vue3/src/ui/Td.vue";

var script$e = vue.defineComponent({
    components: { Th: script$g, Td: script$f },
    props: {
        selectable: {
            type: Boolean,
            default: false,
        },
        table: {
            type: Object,
            required: true,
        },
        schema: {
            type: Array,
            required: false,
        },
    },
});

const _hoisted_1$d = { class: "table w-full" };
const _hoisted_2$a = { class: "sticky top-0 text-left text-gray-800 bg-white thead" };

function render$a(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_Th = vue.resolveComponent("Th");
  const _component_Td = vue.resolveComponent("Td");
  const _component_Tr = vue.resolveComponent("Tr");

  return (vue.openBlock(), vue.createElementBlock("table", _hoisted_1$d, [
    vue.createElementVNode("thead", _hoisted_2$a, [
      vue.renderSlot(_ctx.$slots, "thead", {}, () => [
        vue.createElementVNode("tr", null, [
          (vue.openBlock(true), vue.createElementBlock(vue.Fragment, null, vue.renderList(_ctx.schema, (column, thKey) => {
            return (vue.openBlock(), vue.createBlock(_component_Th, {
              key: `th-${thKey}`,
              column: column,
              class: "pr-4 text-xs font-normal bg-white h-7"
            }, null, 8 /* PROPS */, ["column"]))
          }), 128 /* KEYED_FRAGMENT */))
        ])
      ])
    ]),
    vue.createElementVNode("tbody", null, [
      vue.renderSlot(_ctx.$slots, "tbody", {
        items: _ctx.table.items
      }, () => [
        (vue.openBlock(true), vue.createElementBlock(vue.Fragment, null, vue.renderList(_ctx.table.items, (item, trKey) => {
          return (vue.openBlock(), vue.createBlock(_component_Tr, {
            key: `th-${trKey}`
          }, {
            default: vue.withCtx(() => [
              (vue.openBlock(true), vue.createElementBlock(vue.Fragment, null, vue.renderList(_ctx.schema, (column, tdKey) => {
                return (vue.openBlock(), vue.createBlock(_component_Td, {
                  key: `td-${tdKey}`,
                  column: column,
                  item: item,
                  class: "py-4 pr-4"
                }, null, 8 /* PROPS */, ["column", "item"]))
              }), 128 /* KEYED_FRAGMENT */))
            ]),
            _: 2 /* DYNAMIC */
          }, 1024 /* DYNAMIC_SLOTS */))
        }), 128 /* KEYED_FRAGMENT */))
      ])
    ])
  ]))
}

var css$2 = "\n.table .slim {\n    width: 1%;\n    white-space: nowrap;\n}\n.table .thead {\n    box-shadow: inset 0px -1px 0px #e5eaef;\n}\n";
n(css$2,{});

script$e.render = render$a;
script$e.__file = "packages/admin-vue3/src/ui/Table.vue";

const _hoisted_1$c = ["value"];
var script$d = /*#__PURE__*/ vue.defineComponent({
    props: {
        modelValue: String,
        errors: {
            type: Array,
            default: [],
        },
        hint: {
            type: String,
            default: null,
        },
    },
    emits: ['update:modelValue'],
    setup(__props, { emit: emits }) {
        const updateValue = event => {
            emits('update:modelValue', event.target.value);
        };
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createElementBlock("textarea", vue.mergeProps(_ctx.$attrs, {
                class: ["bg-white border w-full transition-colors duration-300 focus:outline-none placeholder:text-gray-900 h-[118px] overflow-y-scroll overflow-x-hidden rounded-[8px] px-[18px] py-3", {
                        'border-red-signal': __props.errors.length > 0,
                        'border-gray-900 focus:border-orange': __props.errors.length == 0,
                    }],
                value: __props.modelValue,
                onInput: updateValue
            }), null, 16 /* FULL_PROPS */, _hoisted_1$c));
        };
    }
});

script$d.__file = "packages/admin-vue3/src/ui/Textarea.vue";

var script$c = vue.defineComponent({
//
});

const _hoisted_1$b = { class: "hover:bg-gray-200 odd:bg-gray-50" };

function render$9(_ctx, _cache, $props, $setup, $data, $options) {
  return (vue.openBlock(), vue.createElementBlock("tr", _hoisted_1$b, [
    vue.renderSlot(_ctx.$slots, "default")
  ]))
}

script$c.render = render$9;
script$c.__file = "packages/admin-vue3/src/ui/Tr.vue";

const _hoisted_1$a = {
    key: 0,
    class: "flex flex-wrap gap-3 mb-5"
};
const _hoisted_2$9 = { class: "relative min-w-[101px]" };
const _hoisted_3$7 = { class: "inline-block" };
const _hoisted_4$5 = /*#__PURE__*/ vue.createElementVNode("svg", {
    xmlns: "http://www.w3.org/2000/svg",
    viewBox: "-5 -8 24 24",
    width: "16",
    fill: "currentColor"
}, [
    /*#__PURE__*/ vue.createElementVNode("path", { d: "M7.071 5.314l4.95-4.95a1 1 0 1 1 1.414 1.414L7.778 7.435a1 1 0 0 1-1.414 0L.707 1.778A1 1 0 1 1 2.121.364l4.95 4.95z" })
], -1 /* HOISTED */);
const _hoisted_5$3 = /*#__PURE__*/ vue.createElementVNode("svg", {
    xmlns: "http://www.w3.org/2000/svg",
    viewBox: "-7.5 -7 24 24",
    width: "24",
    fill: "currentColor"
}, [
    /*#__PURE__*/ vue.createElementVNode("path", { d: "M2.273 8l1.95-6H3a1 1 0 1 1 0-2h5a1 1 0 1 1 0 2H6.326l-1.95 6H6a1 1 0 1 1 0 2H1a1 1 0 1 1 0-2h1.273z" })
], -1 /* HOISTED */);
const _hoisted_6 = [
    _hoisted_5$3
];
const _hoisted_7 = /*#__PURE__*/ vue.createElementVNode("svg", {
    xmlns: "http://www.w3.org/2000/svg",
    viewBox: "-8.5 -7 24 24",
    width: "24",
    fill: "currentColor"
}, [
    /*#__PURE__*/ vue.createElementVNode("path", { d: "M2 5.455v2.727h1.5c.828 0 1.5-.61 1.5-1.364 0-.753-.672-1.363-1.5-1.363H2zm3.514-1.24C6.413 4.793 7 5.744 7 6.819 7 8.575 5.433 10 3.5 10H0V.91C0 .406.448 0 1 0h2c1.657 0 3 1.221 3 2.727 0 .55-.179 1.06-.486 1.489zM2 1.819v1.818h1c.552 0 1-.407 1-.909s-.448-.909-1-.909H2z" })
], -1 /* HOISTED */);
const _hoisted_8 = [
    _hoisted_7
];
const _hoisted_9 = /*#__PURE__*/ vue.createElementVNode("svg", {
    xmlns: "http://www.w3.org/2000/svg",
    viewBox: "-2 -4 24 24",
    width: "16",
    fill: "currentColor"
}, [
    /*#__PURE__*/ vue.createElementVNode("path", { d: "M12.7361611,0.063952038 C13.2551391,0.263360331 13.5227261,0.869148905 13.3338336,1.41701869 L8.54555162,15.3051026 C8.35665911,15.8529724 7.78281676,16.1354563 7.26383885,15.936048 C6.74486095,15.7366397 6.47727387,15.1308511 6.66616638,14.5829813 L11.4544484,0.694897379 C11.6433409,0.147027596 12.2171832,-0.135456255 12.7361611,0.063952038 Z M2.41421356,8.25614867 L5.94974747,11.9885083 C6.34027176,12.4007734 6.34027176,13.0691871 5.94974747,13.4814522 C5.55922318,13.8937173 4.9260582,13.8937173 4.53553391,13.4814522 L0.292893219,9.0026206 C-0.0976310729,8.59035554 -0.0976310729,7.9219418 0.292893219,7.50967674 L4.53553391,3.03084515 C4.9260582,2.61858008 5.55922318,2.61858008 5.94974747,3.03084515 C6.34027176,3.44311021 6.34027176,4.11152395 5.94974747,4.52378901 L2.41421356,8.25614867 Z M17.5857864,8.25614867 L14.0502525,4.52378901 C13.6597282,4.11152395 13.6597282,3.44311021 14.0502525,3.03084515 C14.4407768,2.61858008 15.0739418,2.61858008 15.4644661,3.03084515 L19.7071068,7.50967674 C20.0976311,7.9219418 20.0976311,8.59035554 19.7071068,9.0026206 L15.4644661,13.4814522 C15.0739418,13.8937173 14.4407768,13.8937173 14.0502525,13.4814522 C13.6597282,13.0691871 13.6597282,12.4007734 14.0502525,11.9885083 L17.5857864,8.25614867 Z" })
], -1 /* HOISTED */);
const _hoisted_10 = [
    _hoisted_9
];
const _hoisted_11 = /*#__PURE__*/ vue.createElementVNode("svg", {
    xmlns: "http://www.w3.org/2000/svg",
    viewBox: "-3 -3 24 24",
    width: "16",
    fill: "currentColor"
}, [
    /*#__PURE__*/ vue.createElementVNode("path", { d: "M3.19 9.345a.97.97 0 0 1 1.37 0 .966.966 0 0 1 0 1.367l-2.055 2.052a1.932 1.932 0 0 0 0 2.735 1.94 1.94 0 0 0 2.74 0l4.794-4.787a.966.966 0 0 0 0-1.367.966.966 0 0 1 0-1.368.97.97 0 0 1 1.37 0 2.898 2.898 0 0 1 0 4.103l-4.795 4.787a3.879 3.879 0 0 1-5.48 0 3.864 3.864 0 0 1 0-5.47L3.19 9.344zm11.62-.69a.97.97 0 0 1-1.37 0 .966.966 0 0 1 0-1.367l2.055-2.052a1.932 1.932 0 0 0 0-2.735 1.94 1.94 0 0 0-2.74 0L7.962 7.288a.966.966 0 0 0 0 1.367.966.966 0 0 1 0 1.368.97.97 0 0 1-1.37 0 2.898 2.898 0 0 1 0-4.103l4.795-4.787a3.879 3.879 0 0 1 5.48 0 3.864 3.864 0 0 1 0 5.47L14.81 8.656z" })
], -1 /* HOISTED */);
const _hoisted_12 = [
    _hoisted_11
];
const _hoisted_13 = /*#__PURE__*/ vue.createElementVNode("svg", {
    xmlns: "http://www.w3.org/2000/svg",
    viewBox: "-5 -7 24 24",
    width: "24",
    fill: "currentColor"
}, [
    /*#__PURE__*/ vue.createElementVNode("path", { d: "M4 0h9a1 1 0 0 1 0 2H4a1 1 0 1 1 0-2zm0 8h9a1 1 0 0 1 0 2H4a1 1 0 1 1 0-2zm0-4h9a1 1 0 0 1 0 2H4a1 1 0 1 1 0-2zM1 0a1 1 0 1 1 0 2 1 1 0 0 1 0-2zm0 8a1 1 0 1 1 0 2 1 1 0 0 1 0-2zm0-4a1 1 0 1 1 0 2 1 1 0 0 1 0-2z" })
], -1 /* HOISTED */);
const _hoisted_14 = [
    _hoisted_13
];
const _hoisted_15 = /*#__PURE__*/ vue.createElementVNode("svg", {
    xmlns: "http://www.w3.org/2000/svg",
    viewBox: "-7 -6.5 24 24",
    width: "24",
    fill: "currentColor"
}, [
    /*#__PURE__*/ vue.createElementVNode("path", { d: "M1.5 10h7a.5.5 0 1 1 0 1h-7a.5.5 0 1 1 0-1zM7 2a1 1 0 1 1 0-2h2a1 1 0 1 1 0 2v3a4 4 0 1 1-8 0V2a1 1 0 1 1 0-2h2a1 1 0 1 1 0 2v3a2 2 0 1 0 4 0V2z" })
], -1 /* HOISTED */);
const _hoisted_16 = [
    _hoisted_15
];
const _hoisted_17 = /*#__PURE__*/ vue.createElementVNode("svg", {
    xmlns: "http://www.w3.org/2000/svg",
    viewBox: "-5 -5 24 24",
    width: "16",
    fill: "currentColor"
}, [
    /*#__PURE__*/ vue.createElementVNode("path", { d: "M2,6 L6,6 L6,2 L2,2 L2,6 Z M2,8 L2,12 L6,12 L6,8 L2,8 Z M12,6 L12,2 L8,2 L8,6 L12,6 Z M12,8 L8,8 L8,12 L12,12 L12,8 Z M2,0 L12,0 C13.1045695,0 14,0.8954305 14,2 L14,12 C14,13.1045695 13.1045695,14 12,14 L2,14 C0.8954305,14 0,13.1045695 0,12 L0,2 C0,0.8954305 0.8954305,0 2,0 Z" })
], -1 /* HOISTED */);
const _hoisted_18 = [
    _hoisted_17
];
const _hoisted_19 = {
    key: 0,
    class: "min-w-max bg-gray-100 grid grid-cols-5 gap-2 rounded-[8px]"
};
const _hoisted_20 = /*#__PURE__*/ vue.createElementVNode("svg", {
    xmlns: "http://www.w3.org/2000/svg",
    viewBox: "-5 -5 24 24",
    width: "16",
    fill: "currentColor"
}, [
    /*#__PURE__*/ vue.createElementVNode("path", { d: "M2,6 L6,6 L6,2 L2,2 L2,6 Z M2,8 L2,12 L6,12 L6,8 L2,8 Z M12,6 L12,2 L8,2 L8,6 L12,6 Z M12,8 L8,8 L8,12 L12,12 L12,8 Z M2,0 L12,0 C13.1045695,0 14,0.8954305 14,2 L14,12 C14,13.1045695 13.1045695,14 12,14 L2,14 C0.8954305,14 0,13.1045695 0,12 L0,2 C0,0.8954305 0.8954305,0 2,0 Z" })
], -1 /* HOISTED */);
const _hoisted_21 = [
    _hoisted_20
];
const _hoisted_22 = /*#__PURE__*/ vue.createElementVNode("svg", {
    xmlns: "http://www.w3.org/2000/svg",
    viewBox: "-5 -5 24 24",
    width: "16",
    fill: "currentColor"
}, [
    /*#__PURE__*/ vue.createElementVNode("path", { d: "M8,12 L8,2 L2,2 L2,3 C2,3.55228475 1.55228475,4 1,4 C0.44771525,4 0,3.55228475 0,3 L0,2 C0,0.8954305 0.8954305,0 2,0 L12,0 C13.1045695,0 14,0.8954305 14,2 L14,12 C14,13.1045695 13.1045695,14 12,14 L2,14 C0.8954305,14 0,13.1045695 0,12 L0,11 C0,10.4477153 0.44771525,10 1,10 C1.55228475,10 2,10.4477153 2,11 L2,12 L8,12 Z M10,12 L12,12 L12,10 L10,10 L10,12 Z M12,8 L12,6 L10,6 L10,8 L12,8 Z M12,4 L12,2 L10,2 L10,4 L12,4 Z M3,6 L3,5 C3,4.44771525 3.44771525,4 4,4 C4.55228475,4 5,4.44771525 5,5 L5,6 L6,6 C6.55228475,6 7,6.44771525 7,7 C7,7.55228475 6.55228475,8 6,8 L5,8 L5,9 C5,9.55228475 4.55228475,10 4,10 C3.44771525,10 3,9.55228475 3,9 L3,8 L2,8 C1.44771525,8 1,7.55228475 1,7 C1,6.44771525 1.44771525,6 2,6 L3,6 Z" })
], -1 /* HOISTED */);
const _hoisted_23 = [
    _hoisted_22
];
const _hoisted_24 = /*#__PURE__*/ vue.createElementVNode("svg", {
    xmlns: "http://www.w3.org/2000/svg",
    viewBox: "-5 -5 24 24",
    width: "16",
    fill: "currentColor"
}, [
    /*#__PURE__*/ vue.createElementVNode("path", { d: "M12,0 C13.1045695,0 14,0.8954305 14,2 L14,3 C14,3.55228475 13.5522847,4 13,4 C12.4477153,4 12,3.55228475 12,3 L12,2 L6,2 L6,12 L12,12 L12,11 C12,10.4477153 12.4477153,10 13,10 C13.5522847,10 14,10.4477153 14,11 L14,12 C14,13.1045695 13.1045695,14 12,14 L2,14 C0.8954305,14 0,13.1045695 0,12 L0,2 C0,0.8954305 0.8954305,0 2,0 L12,0 Z M4,10 L2,10 L2,12 L4,12 L4,10 Z M10,4 C10.5522847,4 11,4.44771525 11,5 L11,6 L12,6 C12.5522847,6 13,6.44771525 13,7 C13,7.55228475 12.5522847,8 12,8 L11,8 L11,9 C11,9.55228475 10.5522847,10 10,10 C9.44771525,10 9,9.55228475 9,9 L9,8 L8,8 C7.44771525,8 7,7.55228475 7,7 C7,6.44771525 7.44771525,6 8,6 L9,6 L9,5 C9,4.44771525 9.44771525,4 10,4 Z M4,6 L2,6 L2,8 L4,8 L4,6 Z M4,2 L2,2 L2,4 L4,4 L4,2 Z" })
], -1 /* HOISTED */);
const _hoisted_25 = [
    _hoisted_24
];
const _hoisted_26 = /*#__PURE__*/ vue.createElementVNode("svg", {
    xmlns: "http://www.w3.org/2000/svg",
    viewBox: "-5 -5 24 24",
    width: "16",
    fill: "currentColor"
}, [
    /*#__PURE__*/ vue.createElementVNode("path", { d: "M12,8 L12,2 L11,2 C10.4477153,2 10,1.55228475 10,1 C10,0.44771525 10.4477153,0 11,0 L12,0 C13.1045695,0 14,0.8954305 14,2 L14,12 C14,13.1045695 13.1045695,14 12,14 L2,14 C0.8954305,14 0,13.1045695 0,12 L0,2 C0,0.8954305 0.8954305,0 2,0 L3,0 C3.55228475,0 4,0.44771525 4,1 C4,1.55228475 3.55228475,2 3,2 L2,2 L2,8 L12,8 Z M12,10 L10,10 L10,12 L12,12 L12,10 Z M8,12 L8,10 L6,10 L6,12 L8,12 Z M4,12 L4,10 L2,10 L2,12 L4,12 Z M6,3 L6,2 C6,1.44771525 6.44771525,1 7,1 C7.55228475,1 8,1.44771525 8,2 L8,3 L9,3 C9.55228475,3 10,3.44771525 10,4 C10,4.55228475 9.55228475,5 9,5 L8,5 L8,6 C8,6.55228475 7.55228475,7 7,7 C6.44771525,7 6,6.55228475 6,6 L6,5 L5,5 C4.44771525,5 4,4.55228475 4,4 C4,3.44771525 4.44771525,3 5,3 L6,3 Z" })
], -1 /* HOISTED */);
const _hoisted_27 = [
    _hoisted_26
];
const _hoisted_28 = /*#__PURE__*/ vue.createElementVNode("svg", {
    xmlns: "http://www.w3.org/2000/svg",
    viewBox: "-5 -5 24 24",
    width: "16",
    fill: "currentColor"
}, [
    /*#__PURE__*/ vue.createElementVNode("path", { d: "M2,6 L2,12 L3,12 C3.55228475,12 4,12.4477153 4,13 C4,13.5522847 3.55228475,14 3,14 L2,14 C0.8954305,14 0,13.1045695 0,12 L0,2 C0,0.8954305 0.8954305,0 2,0 L12,0 C13.1045695,0 14,0.8954305 14,2 L14,12 C14,13.1045695 13.1045695,14 12,14 L11,14 C10.4477153,14 10,13.5522847 10,13 C10,12.4477153 10.4477153,12 11,12 L12,12 L12,6 L2,6 Z M2,4 L4,4 L4,2 L2,2 L2,4 Z M6,2 L6,4 L8,4 L8,2 L6,2 Z M10,2 L10,4 L12,4 L12,2 L10,2 Z M8,11 L8,12 C8,12.5522847 7.55228475,13 7,13 C6.44771525,13 6,12.5522847 6,12 L6,11 L5,11 C4.44771525,11 4,10.5522847 4,10 C4,9.44771525 4.44771525,9 5,9 L6,9 L6,8 C6,7.44771525 6.44771525,7 7,7 C7.55228475,7 8,7.44771525 8,8 L8,9 L9,9 C9.55228475,9 10,9.44771525 10,10 C10,10.5522847 9.55228475,11 9,11 L8,11 Z" })
], -1 /* HOISTED */);
const _hoisted_29 = [
    _hoisted_28
];
const _hoisted_30 = /*#__PURE__*/ vue.createElementVNode("svg", {
    xmlns: "http://www.w3.org/2000/svg",
    viewBox: "-5 -5 24 24",
    width: "16",
    fill: "currentColor"
}, [
    /*#__PURE__*/ vue.createElementVNode("path", { d: "M2,0 L12,0 C13.1045695,0 14,0.8954305 14,2 L14,12 C14,13.1045695 13.1045695,14 12,14 L2,14 C0.8954305,14 0,13.1045695 0,12 L0,2 C0,0.8954305 0.8954305,0 2,0 Z M2,4 L2,12 L12,12 L12,4 L2,4 Z M7,9.41421356 L5.58578644,10.8284271 C5.19526215,11.2189514 4.56209717,11.2189514 4.17157288,10.8284271 C3.78104858,10.4379028 3.78104858,9.80473785 4.17157288,9.41421356 L5.58578644,8 L4.17157288,6.58578644 C3.78104858,6.19526215 3.78104858,5.56209717 4.17157288,5.17157288 C4.56209717,4.78104858 5.19526215,4.78104858 5.58578644,5.17157288 L7,6.58578644 L8.41421356,5.17157288 C8.80473785,4.78104858 9.43790283,4.78104858 9.82842712,5.17157288 C10.2189514,5.56209717 10.2189514,6.19526215 9.82842712,6.58578644 L8.41421356,8 L9.82842712,9.41421356 C10.2189514,9.80473785 10.2189514,10.4379028 9.82842712,10.8284271 C9.43790283,11.2189514 8.80473785,11.2189514 8.41421356,10.8284271 L7,9.41421356 Z" })
], -1 /* HOISTED */);
const _hoisted_31 = [
    _hoisted_30
];
const _hoisted_32 = /*#__PURE__*/ vue.createElementVNode("svg", {
    xmlns: "http://www.w3.org/2000/svg",
    viewBox: "-5 -5 24 24",
    width: "16",
    fill: "currentColor"
}, [
    /*#__PURE__*/ vue.createElementVNode("path", { d: "M12,0 C13.1045695,0 14,0.8954305 14,2 L14,3 C14,3.55228475 13.5522847,4 13,4 C12.4477153,4 12,3.55228475 12,3 L12,2 L6,2 L6,12 L12,12 L12,11 C12,10.4477153 12.4477153,10 13,10 C13.5522847,10 14,10.4477153 14,11 L14,12 C14,13.1045695 13.1045695,14 12,14 L2,14 C0.8954305,14 0,13.1045695 0,12 L0,2 C0,0.8954305 0.8954305,0 2,0 L12,0 Z M4,10 L2,10 L2,12 L4,12 L4,10 Z M10,4 C10.5522847,4 11,4.44771525 11,5 L11,6 L12,6 C12.5522847,6 13,6.44771525 13,7 C13,7.55228475 12.5522847,8 12,8 L11,8 L11,9 C11,9.55228475 10.5522847,10 10,10 C9.44771525,10 9,9.55228475 9,9 L9,8 L8,8 C7.44771525,8 7,7.55228475 7,7 C7,6.44771525 7.44771525,6 8,6 L9,6 L9,5 C9,4.44771525 9.44771525,4 10,4 Z M4,6 L2,6 L2,8 L4,8 L4,6 Z M4,2 L2,2 L2,4 L4,4 L4,2 Z" })
], -1 /* HOISTED */);
const _hoisted_33 = [
    _hoisted_32
];
const _hoisted_34 = /*#__PURE__*/ vue.createElementVNode("svg", {
    xmlns: "http://www.w3.org/2000/svg",
    viewBox: "-5 -5 24 24",
    width: "16",
    fill: "currentColor"
}, [
    /*#__PURE__*/ vue.createElementVNode("path", { d: "M2,6 L2,12 L3,12 C3.55228475,12 4,12.4477153 4,13 C4,13.5522847 3.55228475,14 3,14 L2,14 C0.8954305,14 0,13.1045695 0,12 L0,2 C0,0.8954305 0.8954305,0 2,0 L12,0 C13.1045695,0 14,0.8954305 14,2 L14,12 C14,13.1045695 13.1045695,14 12,14 L11,14 C10.4477153,14 10,13.5522847 10,13 C10,12.4477153 10.4477153,12 11,12 L12,12 L12,6 L2,6 Z M2,4 L4,4 L4,2 L2,2 L2,4 Z M6,2 L6,4 L8,4 L8,2 L6,2 Z M10,2 L10,4 L12,4 L12,2 L10,2 Z M8,11 L8,12 C8,12.5522847 7.55228475,13 7,13 C6.44771525,13 6,12.5522847 6,12 L6,11 L5,11 C4.44771525,11 4,10.5522847 4,10 C4,9.44771525 4.44771525,9 5,9 L6,9 L6,8 C6,7.44771525 6.44771525,7 7,7 C7.55228475,7 8,7.44771525 8,8 L8,9 L9,9 C9.55228475,9 10,9.44771525 10,10 C10,10.5522847 9.55228475,11 9,11 L8,11 Z" })
], -1 /* HOISTED */);
const _hoisted_35 = [
    _hoisted_34
];
var script$b = /*#__PURE__*/ vue.defineComponent({
    props: {
        modelValue: {
            type: String,
            default: '',
        },
        errors: {
            type: Array,
            default: [],
        },
        hint: {
            type: String,
            default: null,
        },
    },
    emits: ['update:modelValue'],
    setup(__props, { emit }) {
        const props = __props;
        const editor = vue3.useEditor({
            content: props.modelValue,
            extensions: [
                StarterKit__default,
                Bold__default,
                Italic__default,
                Underline__default,
                Code__default,
                Table__default.configure({
                    resizable: true,
                }),
                TableRow__default,
                TableCell__default,
                TableHeader__default,
                Link__default.configure({
                    openOnClick: false,
                }),
            ],
            onUpdate: () => {
                emit('update:modelValue', editor.value.getHTML());
            },
        });
        const openTableMenu = vue.ref(false);
        const headings = [
            { name: 'Paragraph', value: null },
            { name: 'Headline 1', value: 1 },
            { name: 'Headline 2', value: 2 },
            { name: 'Headline 3', value: 3 },
        ];
        const selectedHeading = vue.ref(headings[0]);
        const activeStyle = vue.computed(() => {
            if (editor.value.isActive('paragraph')) {
                return 'Paragraph';
            }
            if (editor.value.isActive('heading', { level: 1 })) {
                return 'Headline 1';
            }
            if (editor.value.isActive('heading', { level: 2 })) {
                return 'Headline 2';
            }
            if (editor.value.isActive('heading', { level: 3 })) {
                return 'Headline 3';
            }
        });
        const setLink = () => {
            const previousUrl = editor.value.getAttributes('link').href;
            const url = window.prompt('URL', previousUrl);
            // cancelled
            if (url === null) {
                return;
            }
            // empty
            if (url === '') {
                editor.value.chain().focus().extendMarkRange('link').unsetLink().run();
                return;
            }
            // update link
            editor.value
                .chain()
                .focus()
                .extendMarkRange('link')
                .setLink({ href: url })
                .run();
        };
        vue.watch(selectedHeading, () => {
            if (selectedHeading.value.value == 1) {
                editor.value.commands.setHeading({ level: 1 });
                return;
            }
            if (selectedHeading.value.value == 2) {
                editor.value.commands.setHeading({ level: 2 });
                return;
            }
            if (selectedHeading.value.value == 3) {
                editor.value.commands.setHeading({ level: 3 });
                return;
            }
            editor.value.commands.setParagraph();
        });
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createElementBlock("div", null, [
                (vue.unref(editor))
                    ? (vue.openBlock(), vue.createElementBlock("div", _hoisted_1$a, [
                        vue.createVNode(vue.unref(vue$1.Listbox), {
                            modelValue: selectedHeading.value,
                            "onUpdate:modelValue": _cache[0] || (_cache[0] = ($event) => ((selectedHeading).value = $event))
                        }, {
                            default: vue.withCtx(() => [
                                vue.createElementVNode("div", _hoisted_2$9, [
                                    vue.createVNode(vue.unref(vue$1.ListboxButton), { class: "px-3 py-2 text-sm w-full focus:outline-none focus:ring-4 focus:ring-orange-100 flex items-center gap-2 bg-gray-100 hover:bg-gray-200 rounded-[8px]" }, {
                                        default: vue.withCtx(() => [
                                            vue.createElementVNode("span", _hoisted_3$7, vue.toDisplayString(vue.unref(activeStyle)), 1 /* TEXT */),
                                            _hoisted_4$5
                                        ]),
                                        _: 1 /* STABLE */
                                    }),
                                    vue.createVNode(vue.unref(vue$1.ListboxOptions), { class: "absolute z-20 mt-2 w-full focus:outline-none focus:ring-4 focus:ring-orange-100 rounded-[8px] overflow-auto bg-gray-100 max-h-40" }, {
                                        default: vue.withCtx(() => [
                                            (vue.openBlock(), vue.createElementBlock(vue.Fragment, null, vue.renderList(headings, (heading) => {
                                                return vue.createVNode(vue.unref(vue$1.ListboxOption), {
                                                    key: heading.value,
                                                    value: heading
                                                }, {
                                                    default: vue.withCtx(() => [
                                                        vue.createElementVNode("li", {
                                                            class: vue.normalizeClass(["px-3 py-2 text-sm cursor-pointer focus:bg-gray-200 hover:bg-gray-200", {
                                                                    'bg-gray-300': vue.unref(activeStyle) == heading.name,
                                                                }])
                                                        }, vue.toDisplayString(heading.name), 3 /* TEXT, CLASS */)
                                                    ]),
                                                    _: 2 /* DYNAMIC */
                                                }, 1032 /* PROPS, DYNAMIC_SLOTS */, ["value"]);
                                            }), 64 /* STABLE_FRAGMENT */))
                                        ]),
                                        _: 1 /* STABLE */
                                    })
                                ])
                            ]),
                            _: 1 /* STABLE */
                        }, 8 /* PROPS */, ["modelValue"]),
                        vue.createElementVNode("button", {
                            onClick: _cache[1] || (_cache[1] = ($event) => (vue.unref(editor).chain().focus().toggleItalic().run())),
                            class: vue.normalizeClass(["p-1 flex items-center focus:outline-none focus:ring-4 focus:ring-orange-100 justify-center w-8 h-8 rounded-[8px]", {
                                    'bg-orange-100 text-orange': vue.unref(editor).isActive('italic'),
                                    'text-indigo-900 hover:bg-gray-100': !vue.unref(editor).isActive('italic'),
                                }])
                        }, _hoisted_6, 2 /* CLASS */),
                        vue.createElementVNode("button", {
                            onClick: _cache[2] || (_cache[2] = ($event) => (vue.unref(editor).chain().focus().toggleBold().run())),
                            class: vue.normalizeClass(["p-1 flex items-center focus:outline-none focus:ring-4 focus:ring-orange-100 justify-center w-8 h-8 rounded-[8px]", {
                                    'bg-orange-100 text-orange': vue.unref(editor).isActive('bold'),
                                    'text-indigo-900 hover:bg-gray-100': !vue.unref(editor).isActive('bold'),
                                }])
                        }, _hoisted_8, 2 /* CLASS */),
                        vue.createElementVNode("button", {
                            onClick: _cache[3] || (_cache[3] = ($event) => (vue.unref(editor).chain().focus().toggleCode().run())),
                            class: vue.normalizeClass(["p-1 flex items-center focus:outline-none focus:ring-4 focus:ring-orange-100 justify-center w-8 h-8 rounded-[8px]", {
                                    'bg-orange-100 text-orange': vue.unref(editor).isActive('code'),
                                    'text-indigo-900 hover:bg-gray-100': !vue.unref(editor).isActive('code'),
                                }])
                        }, _hoisted_10, 2 /* CLASS */),
                        vue.createElementVNode("button", {
                            onClick: _cache[4] || (_cache[4] = ($event) => (setLink())),
                            class: vue.normalizeClass(["p-1 flex items-center focus:outline-none focus:ring-4 focus:ring-orange-100 justify-center w-8 h-8 rounded-[8px]", {
                                    'bg-orange-100 text-orange': vue.unref(editor).isActive('link'),
                                    'text-indigo-900 hover:bg-gray-100': !vue.unref(editor).isActive('link'),
                                }])
                        }, _hoisted_12, 2 /* CLASS */),
                        vue.createElementVNode("button", {
                            onClick: _cache[5] || (_cache[5] = ($event) => (vue.unref(editor).chain().focus().toggleBulletList().run())),
                            class: vue.normalizeClass(["p-1 flex items-center focus:outline-none focus:ring-4 focus:ring-orange-100 justify-center w-8 h-8 rounded-[8px]", {
                                    'bg-orange-100 text-orange': vue.unref(editor).isActive('bulletList'),
                                    'text-indigo-900 hover:bg-gray-100': !vue.unref(editor).isActive('bulletList'),
                                }])
                        }, _hoisted_14, 2 /* CLASS */),
                        vue.createElementVNode("button", {
                            onClick: _cache[6] || (_cache[6] = ($event) => (vue.unref(editor).chain().focus().toggleUnderline().run())),
                            class: vue.normalizeClass(["p-1 flex items-center focus:outline-none focus:ring-4 focus:ring-orange-100 justify-center w-8 h-8 rounded-[8px]", {
                                    'bg-orange-100 text-orange': vue.unref(editor).isActive('underline'),
                                    'text-indigo-900 hover:bg-gray-100': !vue.unref(editor).isActive('underline'),
                                }])
                        }, _hoisted_16, 2 /* CLASS */),
                        vue.createElementVNode("button", {
                            onClick: _cache[7] || (_cache[7] = ($event) => (openTableMenu.value = !openTableMenu.value)),
                            class: vue.normalizeClass(["p-1 flex items-center focus:outline-none focus:ring-4 focus:ring-orange-100 justify-center w-8 h-8 rounded-[8px]", {
                                    'bg-orange-100 text-orange': openTableMenu.value,
                                    'text-indigo-900 hover:bg-gray-100': !openTableMenu.value,
                                }])
                        }, _hoisted_18, 2 /* CLASS */),
                        vue.createVNode(vue.Transition, {
                            name: "slide-open",
                            "enter-from-class": "transition duration-300 -translate-y-3 opacity-0",
                            "enter-to-class": "transition duration-300 translate-y-0 opacity-100",
                            "leave-from-class": "transition duration-300 translate-y-0 opacity-100",
                            "leave-to-class": "transition duration-300 -translate-y-3 opacity-0"
                        }, {
                            default: vue.withCtx(() => [
                                (openTableMenu.value)
                                    ? (vue.openBlock(), vue.createElementBlock("div", _hoisted_19, [
                                        vue.createElementVNode("button", {
                                            onClick: _cache[8] || (_cache[8] = ($event) => (vue.unref(editor)
                                                .chain()
                                                .focus()
                                                .insertTable({
                                                rows: 2,
                                                cols: 2,
                                                withHeaderRow: true,
                                            })
                                                .run())),
                                            "aria-label": "add table",
                                            class: "p-1 flex items-center focus:outline-none focus:ring-4 focus:ring-orange-100 justify-center w-8 h-8 rounded-[8px] text-indigo-900 hover:bg-gray-200"
                                        }, _hoisted_21),
                                        vue.createElementVNode("button", {
                                            onClick: _cache[9] || (_cache[9] = ($event) => (vue.unref(editor).chain().focus().addColumnBefore().run())),
                                            "aria-label": "add column before",
                                            class: "p-1 flex items-center focus:outline-none focus:ring-4 focus:ring-orange-100 justify-center w-8 h-8 rounded-[8px] text-indigo-900 hover:bg-gray-200"
                                        }, _hoisted_23),
                                        vue.createElementVNode("button", {
                                            onClick: _cache[10] || (_cache[10] = ($event) => (vue.unref(editor).chain().focus().addColumnAfter().run())),
                                            "aria-label": "add column after",
                                            class: "p-1 flex items-center focus:outline-none focus:ring-4 focus:ring-orange-100 justify-center w-8 h-8 rounded-[8px] text-indigo-900 hover:bg-gray-200"
                                        }, _hoisted_25),
                                        vue.createElementVNode("button", {
                                            onClick: _cache[11] || (_cache[11] = ($event) => (vue.unref(editor).chain().focus().addRowBefore().run())),
                                            "aria-label": "add row before",
                                            class: "p-1 flex items-center focus:outline-none focus:ring-4 focus:ring-orange-100 justify-center w-8 h-8 rounded-[8px] text-indigo-900 hover:bg-gray-200"
                                        }, _hoisted_27),
                                        vue.createElementVNode("button", {
                                            onClick: _cache[12] || (_cache[12] = ($event) => (vue.unref(editor).chain().focus().addRowAfter().run())),
                                            "aria-label": "add row after",
                                            class: "p-1 flex items-center focus:outline-none focus:ring-4 focus:ring-orange-100 justify-center w-8 h-8 rounded-[8px] text-indigo-900 hover:bg-gray-200"
                                        }, _hoisted_29),
                                        vue.createElementVNode("button", {
                                            onClick: _cache[13] || (_cache[13] = ($event) => (vue.unref(editor).chain().focus().deleteTable().run())),
                                            "aria-label": "delete table",
                                            class: "p-1 flex items-center focus:outline-none focus:ring-4 focus:ring-orange-100 justify-center w-8 h-8 rounded-[8px] text-red-signal hover:bg-red hover:bg-opacity-20"
                                        }, _hoisted_31),
                                        vue.createElementVNode("button", {
                                            onClick: _cache[14] || (_cache[14] = ($event) => (vue.unref(editor).chain().focus().deleteColumn().run())),
                                            "aria-label": "add column before",
                                            class: "p-1 flex items-center focus:outline-none focus:ring-4 focus:ring-orange-100 justify-center w-8 h-8 rounded-[8px] text-red-signal hover:bg-red hover:bg-opacity-20"
                                        }, _hoisted_33),
                                        vue.createElementVNode("button", {
                                            onClick: _cache[15] || (_cache[15] = ($event) => (vue.unref(editor).chain().focus().deleteRow().run())),
                                            "aria-label": "add column after",
                                            class: "p-1 flex items-center focus:outline-none focus:ring-4 focus:ring-orange-100 justify-center w-8 h-8 rounded-[8px] text-red-signal hover:bg-red hover:bg-opacity-20"
                                        }, _hoisted_35)
                                    ]))
                                    : vue.createCommentVNode("v-if", true)
                            ]),
                            _: 1 /* STABLE */
                        })
                    ]))
                    : vue.createCommentVNode("v-if", true),
                vue.createVNode(vue.unref(vue3.EditorContent), {
                    class: vue.normalizeClass({ 'wysiwyg-has-errors': __props.errors.length > 0 }),
                    editor: vue.unref(editor)
                }, null, 8 /* PROPS */, ["class", "editor"])
            ]));
        };
    }
});

var css$1 = "\n.ProseMirror {\n    border: 1px solid #afaeb9;\n    border-radius: 8px;\n    background: white;\n    padding: 20px;\n    height: 350px;\n    overflow-y: auto;\n}\n.wysiwyg-has-errors .ProseMirror {\n    border: 1px solid #f74b6d;\n    border-radius: 8px;\n    background: white;\n    padding: 20px;\n    height: 350px;\n    overflow-y: auto;\n}\n.ProseMirror:focus {\n    outline: none;\n    box-shadow: 0px 0 0 4px #ffeedf;\n}\n.ProseMirror h1 {\n    font-size: 28px;\n    line-height: 38px;\n    font-weight: 600;\n    margin-bottom: 32px;\n}\n.ProseMirror h2 {\n    font-size: 22px;\n    line-height: 30px;\n    font-weight: 600;\n    margin-bottom: 24px;\n}\n.ProseMirror h3 {\n    font-size: 18px;\n    line-height: 24px;\n    font-weight: 600;\n    margin-bottom: 18px;\n}\n.ProseMirror p {\n    margin-bottom: 8px;\n}\n.ProseMirror a {\n    text-decoration: underline;\n    color: #0064fb;\n}\n.ProseMirror ul {\n    padding-inline: 16px;\n}\n.ProseMirror li {\n    position: relative;\n}\n.ProseMirror li::before {\n    content: '';\n    position: absolute;\n    left: -16px;\n    top: 10px;\n    border-radius: 9999px;\n    padding: 3px;\n    background: #fead5e;\n}\n.ProseMirror table {\n    border: 1px solid #120f30;\n    border-collapse: collapse;\n    margin-bottom: 20px;\n}\n.ProseMirror th {\n    border: 1px solid #120f30;\n    text-align: left;\n    padding-inline: 12px;\n    padding-top: 5px;\n    min-width: 50px;\n}\n.ProseMirror td {\n    border: 1px solid #120f30;\n    padding-inline: 12px;\n    padding-top: 5px;\n    min-width: 50px;\n}\n";
n(css$1,{});

script$b.__file = "packages/admin-vue3/src/ui/Wysiwyg.vue";

var script$a = vue.defineComponent({
    name: 'TransitionSlide',
    props: {
        to: {
            type: String,
            default: 'left',
        },
    },
    setup() {
        //
    },
});

function render$8(_ctx, _cache, $props, $setup, $data, $options) {
  return (vue.openBlock(), vue.createBlock(vue.Transition, {
    name: `slide-${_ctx.to}`
  }, {
    default: vue.withCtx(() => [
      vue.renderSlot(_ctx.$slots, "default")
    ]),
    _: 3 /* FORWARDED */
  }, 8 /* PROPS */, ["name"]))
}

var css = "\n.slide-up-enter-active,\n.slide-down-enter-active,\n.slide-left-enter-active,\n.slide-right-enter-active {\n    transition: all 0.1s ease;\n}\n.slide-up-leave-active,\n.slide-down-leave-active,\n.slide-left-leave-active,\n.slide-right-leave-active {\n    transition: all 0.1s ease;\n}\n.slide-up-enter-from,\n.slide-up-leave-to {\n    transform: translateY(100%);\n}\n.slide-down-enter-from,\n.slide-down-leave-to {\n    transform: translateY(-100%);\n}\n.slide-left-enter-from,\n.slide-left-leave-to {\n    transform: translateX(100%);\n}\n.slide-right-enter-from,\n.slide-right-leave-to {\n    transform: translateX(-100%);\n}\n";
n(css,{});

script$a.render = render$8;
script$a.__file = "packages/admin-vue3/src/transitions/TransitionSlide.vue";

var script$9 = vue.defineComponent({
    setup() { },
});

const _hoisted_1$9 = {
  width: "100",
  viewBox: "0 0 889 263",
  xmlns: "http://www.w3.org/2000/svg",
  "xml:space": "preserve",
  "fill-rule": "evenodd",
  "clip-rule": "evenodd",
  "stroke-linejoin": "round",
  "stroke-miterlimit": "2"
};
const _hoisted_2$8 = /*#__PURE__*/vue.createStaticVNode("<g transform=\"translate(-204.96 -204.96)\"><path d=\"M204.96 368.93c0 22.64 18.35 40.99 40.99 40.99s40.99-18.35 40.99-40.99V245.95h-81.98v122.98Z\" fill=\"#4951f2\" fill-rule=\"nonzero\"></path><path d=\"M204.96 327.94c0 22.64 18.35 40.99 40.99 40.99s40.99-18.35 40.99-40.99v-81.98h-81.98v81.98Z\" fill=\"#40ffa4\" fill-opacity=\".42\" fill-rule=\"nonzero\"></path><path d=\"M204.96 286.94c0 22.64 18.35 40.99 40.99 40.99s40.99-18.35 40.99-40.99v-40.99h-81.98v40.99Z\" fill=\"#40ffa4\" fill-opacity=\".42\" fill-rule=\"nonzero\"></path><circle cx=\"245.95\" cy=\"245.95\" r=\"40.99\" fill=\"#40ffa4\"></circle><circle cx=\"332.48\" cy=\"426.66\" r=\"40.99\" fill=\"#4951f2\"></circle><path fill=\"#fff\" d=\"M459.11 237.6h23.11v130.76h-23.11zM507.77 270.29h23.11v98.07h-23.11z\"></path><path d=\"M519.39 231.28c-3.66 0-6.81 1.22-9.45 3.67-2.64 2.45-3.96 5.42-3.96 8.91 0 3.45 1.31 6.4 3.93 8.84 2.62 2.45 5.78 3.67 9.48 3.67 3.66 0 6.8-1.22 9.42-3.67s3.93-5.39 3.93-8.84c0-3.49-1.31-6.46-3.93-8.91s-5.76-3.67-9.42-3.67ZM600.52 349.91c-1.21.22-2.54.32-3.99.32-1.92 0-3.66-.3-5.24-.89-1.57-.59-2.84-1.71-3.8-3.35-.96-1.64-1.44-4.01-1.44-7.12v-50.7h19.35v-17.88h-19.35v-23.5h-23.11v23.5h-13.92v17.88h13.92v54.53c-.04 6.13 1.29 11.24 3.99 15.32 2.7 4.09 6.37 7.1 11.01 9.03 4.64 1.94 9.85 2.82 15.64 2.65 3.28-.08 6.05-.38 8.33-.89 2.28-.51 4.03-.98 5.27-1.4l-3.89-18.07c-.63.16-1.56.35-2.77.57ZM677.12 312.43l-16.73-3.58c-4.98-1.15-8.54-2.62-10.69-4.41-2.15-1.79-3.2-4.11-3.16-6.96-.04-3.32 1.56-6.02 4.82-8.11 3.26-2.09 7.29-3.13 12.1-3.13 3.58 0 6.6.57 9.07 1.72 2.47 1.15 4.44 2.66 5.91 4.53 1.47 1.87 2.5 3.87 3.1 6l21.07-2.3c-1.58-8.34-5.68-14.96-12.29-19.86-6.62-4.89-15.68-7.34-27.17-7.34-7.83 0-14.74 1.22-20.72 3.67-5.98 2.45-10.64 5.9-13.98 10.34-3.34 4.45-4.99 9.7-4.95 15.74-.04 7.15 2.19 13.06 6.7 17.72 4.51 4.66 11.47 7.97 20.88 9.93l16.73 3.51c4.51.98 7.84 2.38 9.99 4.21 2.15 1.83 3.22 4.15 3.22 6.96 0 3.32-1.67 6.11-5.01 8.37-3.34 2.25-7.75 3.38-13.25 3.38-5.32 0-9.64-1.13-12.96-3.38-3.32-2.26-5.49-5.6-6.51-10.03l-22.54 2.17c1.4 9.03 5.77 16.06 13.09 21.1 7.32 5.04 16.99 7.56 28.99 7.56 8.17 0 15.41-1.32 21.7-3.96 6.3-2.64 11.23-6.31 14.78-11.02 3.55-4.7 5.35-10.14 5.4-16.31-.05-7.02-2.33-12.7-6.86-17.05-4.55-4.3-11.45-7.47-20.73-9.47ZM767.87 349.91c-1.21.22-2.54.32-3.99.32-1.91 0-3.66-.3-5.24-.89-1.57-.59-2.84-1.71-3.8-3.35-.96-1.64-1.44-4.01-1.44-7.12v-50.7h19.35v-17.88H753.4v-23.5h-23.1v23.5h-13.92v17.88h13.92v54.53c-.04 6.13 1.29 11.24 3.99 15.32 2.7 4.09 6.37 7.1 11.01 9.03 4.64 1.94 9.86 2.82 15.64 2.65 3.28-.08 6.05-.38 8.33-.89 2.28-.51 4.03-.98 5.27-1.4l-3.89-18.07c-.64.16-1.56.35-2.78.57ZM861.01 276.13c-3.87-2.53-8.15-4.35-12.83-5.46a60.982 60.982 0 0 0-14.11-1.66c-6.86 0-13.11 1.01-18.77 3.03-5.66 2.02-10.45 5.05-14.37 9.07-3.92 4.02-6.73 9.01-8.43 14.97l21.58 3.06c1.15-3.36 3.37-6.28 6.67-8.75 3.3-2.47 7.78-3.7 13.44-3.7 5.36 0 9.47 1.32 12.32 3.96 2.85 2.64 4.28 6.36 4.28 11.17v.38c0 2.21-.82 3.84-2.46 4.88-1.64 1.04-4.25 1.81-7.82 2.3-3.58.49-8.24 1.03-13.98 1.63-4.77.51-9.37 1.33-13.82 2.46-4.45 1.13-8.44 2.78-11.97 4.95-3.53 2.17-6.32 5.07-8.37 8.69-2.04 3.62-3.06 8.19-3.06 13.73 0 6.43 1.44 11.83 4.31 16.22 2.87 4.39 6.79 7.69 11.75 9.93 4.96 2.24 10.55 3.35 16.76 3.35 5.11 0 9.56-.71 13.38-2.14 3.81-1.43 6.98-3.32 9.51-5.68 2.53-2.36 4.5-4.9 5.91-7.63h.76v13.47h22.22v-65.64c0-6.51-1.18-11.94-3.54-16.28-2.37-4.34-5.49-7.78-9.36-10.31Zm-10.16 57.05c0 3.62-.93 6.96-2.78 10.03-1.85 3.06-4.48 5.52-7.88 7.37-3.41 1.85-7.43 2.78-12.07 2.78-4.81 0-8.77-1.08-11.88-3.26-3.11-2.18-4.66-5.38-4.66-9.64 0-2.98.78-5.42 2.36-7.31 1.57-1.89 3.72-3.37 6.45-4.44 2.72-1.06 5.81-1.83 9.26-2.3 1.53-.21 3.34-.47 5.43-.77 2.09-.3 4.19-.64 6.32-1.02s4.06-.83 5.78-1.34c1.72-.51 2.95-1.06 3.67-1.66v11.56ZM929.52 291.45c3.58-2.53 7.73-3.8 12.45-3.8 5.57 0 10.03 1.59 13.38 4.76 3.34 3.17 5.46 7.12 6.35 11.84h22.09c-.51-7.07-2.6-13.25-6.26-18.55-3.66-5.3-8.57-9.41-14.71-12.32-6.15-2.91-13.21-4.37-21.17-4.37-9.58 0-17.87 2.14-24.87 6.42-7 4.28-12.42 10.24-16.25 17.88-3.83 7.64-5.75 16.44-5.75 26.4 0 9.92 1.89 18.68 5.65 26.28 3.77 7.6 9.15 13.55 16.15 17.84 7 4.3 15.4 6.45 25.19 6.45 8.22 0 15.37-1.5 21.45-4.5 6.09-3 10.9-7.17 14.43-12.51 3.53-5.34 5.58-11.48 6.13-18.42H961.7c-.68 3.53-1.94 6.53-3.77 9-1.83 2.47-4.1 4.35-6.8 5.65-2.7 1.3-5.76 1.95-9.16 1.95-4.81 0-8.99-1.29-12.55-3.86-3.55-2.57-6.31-6.26-8.27-11.04-1.96-4.79-2.94-10.52-2.94-17.21 0-6.6.99-12.26 2.97-16.98 1.99-4.74 4.77-8.37 8.34-10.91ZM1066.17 368.36h27.64l-40.25-55.74 38.02-42.33h-27.01l-35.24 39.39h-1.6V237.6h-23.11v130.76h23.11v-32.97l8.41-9.01 30.03 41.98Z\" fill=\"#fff\" fill-rule=\"nonzero\"></path></g>", 1);
const _hoisted_3$6 = [
  _hoisted_2$8
];

function render$7(_ctx, _cache, $props, $setup, $data, $options) {
  return (vue.openBlock(), vue.createElementBlock("svg", _hoisted_1$9, _hoisted_3$6))
}

script$9.render = render$7;
script$9.__file = "packages/admin-vue3/src/svg/Logo.vue";

var script$8 = vue.defineComponent({});

const _hoisted_1$8 = { class: "text-white relative w-5 h-4" };
const _hoisted_2$7 = /*#__PURE__*/vue.createElementVNode("div", { class: "absolute left-0 top-0 w-full h-0.5 bg-white" }, null, -1 /* HOISTED */);
const _hoisted_3$5 = /*#__PURE__*/vue.createElementVNode("div", { class: "absolute left-0 top-1/2 w-full h-0.5 bg-white" }, null, -1 /* HOISTED */);
const _hoisted_4$4 = /*#__PURE__*/vue.createElementVNode("div", { class: "absolute left-0 top-full w-full h-0.5 bg-white" }, null, -1 /* HOISTED */);
const _hoisted_5$2 = [
  _hoisted_2$7,
  _hoisted_3$5,
  _hoisted_4$4
];

function render$6(_ctx, _cache, $props, $setup, $data, $options) {
  return (vue.openBlock(), vue.createElementBlock("button", _hoisted_1$8, _hoisted_5$2))
}

script$8.render = render$6;
script$8.__file = "packages/admin-vue3/src/layouts/default/DefaultLayoutBurger.vue";

var script$7 = vue.defineComponent({
    components: { DefaultLayoutBurger: script$8, Logo: script$9 },
    setup() {
        //
    },
});

const _hoisted_1$7 = { class: "flex items-center pt-2 pb-20 justify-between" };
const _hoisted_2$6 = { class: "flex items-center gap-4" };

function render$5(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_Logo = vue.resolveComponent("Logo");
  const _component_DefaultLayoutBurger = vue.resolveComponent("DefaultLayoutBurger");

  return (vue.openBlock(), vue.createElementBlock("header", null, [
    vue.createElementVNode("div", _hoisted_1$7, [
      vue.renderSlot(_ctx.$slots, "logo", {}, () => [
        vue.createVNode(_component_Logo)
      ]),
      vue.createElementVNode("div", _hoisted_2$6, [
        vue.renderSlot(_ctx.$slots, "default", {}, () => [
          vue.createVNode(_component_DefaultLayoutBurger)
        ])
      ])
    ])
  ]))
}

script$7.render = render$5;
script$7.__file = "packages/admin-vue3/src/layouts/default/DefaultLayoutHeader.vue";

const _hoisted_1$6 = { class: "relative top-0 h-[80px] transition-all border-b border-gray-400 bg-gray-50 z-30" };
const _hoisted_2$5 = { class: "flex items-center justify-between h-full px-10" };
const _hoisted_3$4 = { class: "flex items-baseline space-x-4 font-medium text-gray-800" };
const _hoisted_4$3 = { class: "flex space-x-2" };
const _hoisted_5$1 = { class: "flex items-center justify-end space-x-4 text-sm text-gray-800" };
var script$6 = /*#__PURE__*/ vue.defineComponent({
    setup(__props) {
        vue.ref(false);
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createElementBlock("div", _hoisted_1$6, [
                vue.createElementVNode("div", _hoisted_2$5, [
                    vue.createElementVNode("div", _hoisted_3$4, [
                        vue.renderSlot(_ctx.$slots, "topbar-left")
                    ]),
                    vue.createElementVNode("div", _hoisted_4$3, [
                        vue.renderSlot(_ctx.$slots, "topbar-right")
                    ])
                ]),
                vue.createElementVNode("div", _hoisted_5$1, [
                    vue.renderSlot(_ctx.$slots, "topbar-secondary")
                ])
            ]));
        };
    }
});

script$6.__file = "packages/admin-vue3/src/layouts/default/DefaultLayoutTopbar.vue";

var script$5 = vue.defineComponent({
    components: { TransitionSlide: script$a, DefaultLayoutHeader: script$7, DefaultLayoutTopbar: script$6 },
    name: 'Layout',
    setup() {
        const sidebar = vue.reactive({
            isOpen: false,
            show() {
                this.isOpen = true;
            },
            close() {
                this.isOpen = false;
            },
            toggle() {
                this.isOpen = !this.isOpen;
            },
        });
        return {
            sidebar,
        };
    },
});

const _hoisted_1$5 = { class: "flex w-screen h-screen max-h-screen" };
const _hoisted_2$4 = {
  id: "sidebars",
  class: "flex h-screen shadow"
};
const _hoisted_3$3 = { class: "relative flex flex-col flex-1 h-screen overflow-y-scroll bg-gray-50" };
const _hoisted_4$2 = { class: "relative flex-1 overflow-y-scroll" };

function render$4(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_DefaultLayoutTopbar = vue.resolveComponent("DefaultLayoutTopbar");

  return (vue.openBlock(), vue.createElementBlock("div", _hoisted_1$5, [
    vue.createElementVNode("div", _hoisted_2$4, [
      vue.renderSlot(_ctx.$slots, "sidebar-primary", { sidebar: _ctx.sidebar }),
      vue.renderSlot(_ctx.$slots, "sidebar-secondary")
    ]),
    vue.createElementVNode("div", _hoisted_3$3, [
      vue.createElementVNode("main", _hoisted_4$2, [
        vue.createVNode(_component_DefaultLayoutTopbar, null, {
          "topbar-left": vue.withCtx(() => [
            vue.renderSlot(_ctx.$slots, "topbar-left")
          ]),
          "topbar-right": vue.withCtx(() => [
            vue.renderSlot(_ctx.$slots, "topbar-right")
          ]),
          _: 3 /* FORWARDED */
        }),
        vue.renderSlot(_ctx.$slots, "default")
      ])
    ])
  ]))
}

script$5.render = render$4;
script$5.__file = "packages/admin-vue3/src/layouts/default/DefaultLayout.vue";

var script$4 = vue.defineComponent({
    setup() { },
});

const _hoisted_1$4 = { class: "flex w-screen h-screen" };
const _hoisted_2$3 = { class: "grid w-full h-full grid-cols-12" };
const _hoisted_3$2 = { class: "flex flex-col items-center justify-center col-span-12 gap-16 bg-white md:col-span-6" };
const _hoisted_4$1 = { class: "w-full px-12 lg:w-1/2 lg:px-0" };
const _hoisted_5 = { class: "flex items-center justify-center col-span-12 text-white bg-gray-50 md:col-span-6" };

function render$3(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_Logo = vue.resolveComponent("Logo");

  return (vue.openBlock(), vue.createElementBlock("div", _hoisted_1$4, [
    vue.createElementVNode("div", _hoisted_2$3, [
      vue.createElementVNode("div", _hoisted_3$2, [
        vue.createElementVNode("div", _hoisted_4$1, [
          vue.renderSlot(_ctx.$slots, "default")
        ])
      ]),
      vue.createElementVNode("div", _hoisted_5, [
        vue.createVNode(_component_Logo)
      ])
    ])
  ]))
}

script$4.render = render$3;
script$4.__file = "packages/admin-vue3/src/layouts/guest/GuestLayout.vue";

var script$3 = vue.defineComponent({
    components: { Input: adminVue3.Input, FormField: adminVue3.FormField },
    props: {
        errors: {
            type: [Array, String],
            required: false,
        },
    },
    setup() {
        //
    },
});

const _hoisted_1$3 = { class: "" };

function render$2(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_Input = vue.resolveComponent("Input");
  const _component_FormField = vue.resolveComponent("FormField");

  return (vue.openBlock(), vue.createElementBlock("div", _hoisted_1$3, [
    vue.createVNode(_component_FormField, {
      errors: _ctx.errors,
      "no-label": ""
    }, {
      default: vue.withCtx(() => [
        vue.createVNode(_component_Input, vue.mergeProps({
          errors: typeof _ctx.errors === 'string' ? [_ctx.errors] : _ctx.errors,
          class: "w-full"
        }, _ctx.$attrs), null, 16 /* FULL_PROPS */, ["errors"])
      ]),
      _: 1 /* STABLE */
    }, 8 /* PROPS */, ["errors"])
  ]))
}

script$3.render = render$2;
script$3.__file = "packages/admin-vue3/src/layouts/guest/GuestLayoutInput.vue";

const _hoisted_1$2 = { class: "flex items-center justify-between mt-5" };
const _hoisted_2$2 = { class: "flex items-center justify-center mt-5" };
var script$2 = /*#__PURE__*/ vue.defineComponent({
    props: {
        submitRoute: {
            type: String,
            required: true,
        },
        forgotPasswordRoute: {
            type: String,
        },
        lang: {
            type: Object,
            default: {
                login: 'Login',
                email: 'Email',
                password: 'Password',
                remember: 'Remember Me',
                forgot_password: 'Forgot your password?',
            },
        },
    },
    setup(__props) {
        const props = __props;
        const form = macrameVue3.useForm({
            route: props.submitRoute,
            data: { email: '', password: '', remember: false },
            method: 'post',
        });
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createBlock(script$4, null, {
                default: vue.withCtx(() => [
                    vue.createElementVNode("form", {
                        onSubmit: _cache[3] || (_cache[3] = vue.withModifiers(
                        //@ts-ignore
                        (...args) => (vue.unref(form).submit && vue.unref(form).submit(...args)), ["prevent"])),
                        class: "space-y-4"
                    }, [
                        vue.createVNode(script$3, {
                            autofocus: "",
                            label: __props.lang.email,
                            required: "",
                            type: "email",
                            autocomplete: "username",
                            modelValue: vue.unref(form).email,
                            "onUpdate:modelValue": _cache[0] || (_cache[0] = ($event) => ((vue.unref(form).email) = $event)),
                            errors: vue.unref(form).errors?.email
                        }, null, 8 /* PROPS */, ["label", "modelValue", "errors"]),
                        vue.createVNode(script$3, {
                            required: "",
                            type: "password",
                            label: __props.lang.password,
                            autocomplete: "username",
                            modelValue: vue.unref(form).password,
                            "onUpdate:modelValue": _cache[1] || (_cache[1] = ($event) => ((vue.unref(form).password) = $event)),
                            errors: vue.unref(form).errors?.password
                        }, null, 8 /* PROPS */, ["label", "modelValue", "errors"]),
                        vue.createElementVNode("div", _hoisted_1$2, [
                            vue.createVNode(vue.unref(adminVue3.CheckboxSwitch), {
                                sm: "",
                                label: __props.lang.remember,
                                modelValue: vue.unref(form).remember,
                                "onUpdate:modelValue": _cache[2] || (_cache[2] = ($event) => ((vue.unref(form).remember) = $event)),
                                class: "text-sm uppercase"
                            }, null, 8 /* PROPS */, ["label", "modelValue"]),
                            (__props.forgotPasswordRoute)
                                ? (vue.openBlock(), vue.createBlock(vue.unref(adminVue3.Button), {
                                    key: 0,
                                    href: __props.forgotPasswordRoute,
                                    text: "",
                                    class: "mt-1 text-right"
                                }, {
                                    default: vue.withCtx(() => [
                                        vue.createTextVNode(vue.toDisplayString(__props.lang.forgot_password), 1 /* TEXT */)
                                    ]),
                                    _: 1 /* STABLE */
                                }, 8 /* PROPS */, ["href"]))
                                : vue.createCommentVNode("v-if", true)
                        ]),
                        vue.createElementVNode("div", _hoisted_2$2, [
                            vue.createVNode(vue.unref(adminVue3.Button), {
                                class: vue.normalizeClass({ 'opacity-25': vue.unref(form).processing }),
                                disabled: vue.unref(form).processing
                            }, {
                                default: vue.withCtx(() => [
                                    vue.createTextVNode(vue.toDisplayString(__props.lang.login), 1 /* TEXT */)
                                ]),
                                _: 1 /* STABLE */
                            }, 8 /* PROPS */, ["class", "disabled"])
                        ])
                    ], 32 /* HYDRATE_EVENTS */)
                ]),
                _: 1 /* STABLE */
            }));
        };
    }
});

script$2.__file = "packages/admin-vue3/src/pages/Auth/Login.vue";

var script$1 = vue.defineComponent({
    components: { GuestLayout: script$4, Input: script$3, Checkbox: script$D, Button: script$1k },
    props: {
        submitRoute: {
            type: String,
            required: true,
        },
        lang: {
            type: Object,
            default: {
                message: 'Forgot your password? No problem. Just let us know your email address and we will email you a password reset link that will allow you to choose a new one.',
                email: 'Email',
                send_reset_link: 'Send Password Reset Link',
            },
        },
        status: String,
    },
    setup({ submitRoute }) {
        const form = macrameVue3.useForm({
            route: submitRoute,
            data: { email: '', password: '', remember: false },
            method: 'post',
        });
        return { form };
    },
});

const _hoisted_1$1 = { class: "text-sm text-gray-600" };
const _hoisted_2$1 = {
  key: 0,
  class: "mb-4 text-sm font-medium text-green-600"
};
const _hoisted_3$1 = { class: "flex justify-center mt-5" };

function render$1(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_Input = vue.resolveComponent("Input");
  const _component_Button = vue.resolveComponent("Button");
  const _component_GuestLayout = vue.resolveComponent("GuestLayout");

  return (vue.openBlock(), vue.createBlock(_component_GuestLayout, null, {
    default: vue.withCtx(() => [
      vue.createElementVNode("div", _hoisted_1$1, vue.toDisplayString(_ctx.lang.message), 1 /* TEXT */),
      (_ctx.status)
        ? (vue.openBlock(), vue.createElementBlock("div", _hoisted_2$1, vue.toDisplayString(_ctx.status), 1 /* TEXT */))
        : vue.createCommentVNode("v-if", true),
      vue.createElementVNode("form", {
        onSubmit: _cache[1] || (_cache[1] = vue.withModifiers((...args) => (_ctx.form.submit && _ctx.form.submit(...args)), ["prevent"])),
        class: "mt-4"
      }, [
        vue.createVNode(_component_Input, {
          autofocus: "",
          required: "",
          class: "",
          label: _ctx.lang.email,
          type: "email",
          autocomplete: "username",
          modelValue: _ctx.form.email,
          "onUpdate:modelValue": _cache[0] || (_cache[0] = $event => ((_ctx.form.email) = $event)),
          errors: _ctx.form.errors?.email
        }, null, 8 /* PROPS */, ["label", "modelValue", "errors"]),
        vue.createElementVNode("div", _hoisted_3$1, [
          vue.createVNode(_component_Button, {
            class: vue.normalizeClass({ 'opacity-25': _ctx.form.processing }),
            disabled: _ctx.form.processing
          }, {
            default: vue.withCtx(() => [
              vue.createTextVNode(vue.toDisplayString(_ctx.lang.send_reset_link), 1 /* TEXT */)
            ]),
            _: 1 /* STABLE */
          }, 8 /* PROPS */, ["class", "disabled"])
        ])
      ], 32 /* HYDRATE_EVENTS */)
    ]),
    _: 1 /* STABLE */
  }))
}

script$1.render = render$1;
script$1.__file = "packages/admin-vue3/src/pages/Auth/ForgotPassword.vue";

var script = vue.defineComponent({
    components: { GuestLayout: script$4, Input: script$3, Checkbox: script$D, Button: script$1k },
    props: {
        submitRoute: {
            type: String,
            required: true,
        },
        email: {
            type: String,
            required: true,
        },
        token: {
            type: String,
            required: true,
        },
        lang: {
            type: Object,
            default: {
                password: 'Password',
                password_confirmation: 'Repeat password',
                email: 'Email',
                reset_password: 'Reset Password',
            },
        },
        status: String,
    },
    setup({ submitRoute, token, email }) {
        const form = macrameVue3.useForm({
            route: submitRoute,
            data: {
                token: token,
                email: email,
                password: '',
                password_confirmation: '',
            },
            method: 'post',
        });
        return { form };
    },
});

const _hoisted_1 = { class: "text-sm text-gray-600" };
const _hoisted_2 = {
  key: 0,
  class: "mb-4 text-sm font-medium text-green-600"
};
const _hoisted_3 = {
  key: 0,
  class: "mb-4 text-red"
};
const _hoisted_4 = { class: "flex justify-center mt-5" };

function render(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_Input = vue.resolveComponent("Input");
  const _component_Button = vue.resolveComponent("Button");
  const _component_GuestLayout = vue.resolveComponent("GuestLayout");

  return (vue.openBlock(), vue.createBlock(_component_GuestLayout, null, {
    default: vue.withCtx(() => [
      vue.createElementVNode("div", _hoisted_1, vue.toDisplayString(_ctx.lang.message), 1 /* TEXT */),
      (_ctx.status)
        ? (vue.openBlock(), vue.createElementBlock("div", _hoisted_2, vue.toDisplayString(_ctx.status), 1 /* TEXT */))
        : vue.createCommentVNode("v-if", true),
      vue.createElementVNode("form", {
        onSubmit: _cache[3] || (_cache[3] = vue.withModifiers((...args) => (_ctx.form.submit && _ctx.form.submit(...args)), ["prevent"]))
      }, [
        vue.createVNode(_component_Input, {
          autofocus: "",
          required: "",
          type: "email",
          autocomplete: "username",
          modelValue: _ctx.form.email,
          "onUpdate:modelValue": _cache[0] || (_cache[0] = $event => ((_ctx.form.email) = $event)),
          label: _ctx.lang.email,
          errors: _ctx.form.errors?.email,
          readonly: ""
        }, null, 8 /* PROPS */, ["modelValue", "label", "errors"]),
        vue.createVNode(_component_Input, {
          required: "",
          type: "password",
          autocomplete: "new-password",
          modelValue: _ctx.form.password,
          "onUpdate:modelValue": _cache[1] || (_cache[1] = $event => ((_ctx.form.password) = $event)),
          label: _ctx.lang.password,
          errors: _ctx.form.errors?.password
        }, null, 8 /* PROPS */, ["modelValue", "label", "errors"]),
        vue.createVNode(_component_Input, {
          required: "",
          type: "password",
          autocomplete: "new-password",
          modelValue: _ctx.form.password_confirmation,
          "onUpdate:modelValue": _cache[2] || (_cache[2] = $event => ((_ctx.form.password_confirmation) = $event)),
          label: _ctx.lang.password_confirmation,
          errors: _ctx.form.errors?.password_confirmation
        }, null, 8 /* PROPS */, ["modelValue", "label", "errors"]),
        (_ctx.form.errors?.token)
          ? (vue.openBlock(), vue.createElementBlock("div", _hoisted_3, vue.toDisplayString(_ctx.form.errors.token), 1 /* TEXT */))
          : vue.createCommentVNode("v-if", true),
        vue.createElementVNode("div", _hoisted_4, [
          vue.createVNode(_component_Button, {
            class: vue.normalizeClass({ 'opacity-25': _ctx.form.processing }),
            disabled: _ctx.form.processing
          }, {
            default: vue.withCtx(() => [
              vue.createTextVNode(vue.toDisplayString(_ctx.lang.reset_password), 1 /* TEXT */)
            ]),
            _: 1 /* STABLE */
          }, 8 /* PROPS */, ["class", "disabled"])
        ])
      ], 32 /* HYDRATE_EVENTS */)
    ]),
    _: 1 /* STABLE */
  }))
}

script.render = render;
script.__file = "packages/admin-vue3/src/pages/Auth/ResetPassword.vue";

const AuthPages = {
    'Auth/Login': script$2,
    'Auth/ForgotPassword': script$1,
    'Auth/ResetPassword': script,
};
const Pages = {
    auth: AuthPages,
};

exports.AuthPages = AuthPages;
exports.Badge = script$O;
exports.Button = script$1k;
exports.ButtonRound = script$1i;
exports.Card = script$1h;
exports.Checkbox = script$C;
exports.CheckboxSwitch = script$D;
exports.Chip = script$1f;
exports.ChipInput = script$W;
exports.Content = script$V;
exports.ContentBody = script$U;
exports.ContentSidebar = script$T;
exports.ContextButton = script$P;
exports.ContextMenu = script$S;
exports.ContextMenuDivider = script$R;
exports.ContextMenuItem = script$Q;
exports.DatePicker = script$A;
exports.DateRange = script$z;
exports.DefaultLayout = script$5;
exports.DefaultLayoutBurger = script$8;
exports.DefaultLayoutHeader = script$7;
exports.Drawer = script$N;
exports.DrawerSection = script$M;
exports.FileUpload = script$X;
exports.Form = script$H;
exports.FormField = script$F;
exports.FormFieldLabel = script$G;
exports.GuestLayout = script$4;
exports.GuestLayoutInput = script$3;
exports.Header = script$1j;
exports.IconAddImage = script$19;
exports.IconBlocks = script$Y;
exports.IconBookStack = script$18;
exports.IconCaret = script$1a;
exports.IconDashboard = script$12;
exports.IconDraggable = script$1e;
exports.IconDuplicatePage = script$10;
exports.IconEditPencil = script$1b;
exports.IconList = script$11;
exports.IconLocked = script$15;
exports.IconLogout = script$_;
exports.IconMediaImageFolder = script$17;
exports.IconMoreHorizontal = script$1c;
exports.IconPages = script$13;
exports.IconPartials = script$Z;
exports.IconPlus = script$16;
exports.IconSettings = script$$;
exports.IconTrash = script$1d;
exports.IconUnlocked = script$14;
exports.Index = script$v;
exports.Input = script$B;
exports.InteractionButton = script$u;
exports.Modal = script$E;
exports.Pages = Pages;
exports.Pagination = script$x;
exports.RadioGroup = script$y;
exports.Search = script$w;
exports.Section = script$q;
exports.Sections = script$p;
exports.Select = script$r;
exports.Sidebar = script$o;
exports.SidebarLink = script$n;
exports.SidebarPrimary = script$k;
exports.SidebarSecondary = script$j;
exports.SidebarSecondaryHeader = script$i;
exports.SidebarSecondarySection = script$h;
exports.SidebarSection = script$m;
exports.Tab = script$L;
exports.TabGroup = script$J;
exports.TabList = script$I;
exports.TabPanel = script$K;
exports.Table = script$e;
exports.Td = script$f;
exports.Textarea = script$d;
exports.Th = script$g;
exports.Toggle = script$1g;
exports.Tr = script$c;
exports.Tree = script$t;
exports.TreeItem = script$s;
exports.Wysiwyg = script$b;
